package com.chinaitop.depot.common;

import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author qingsong.han
 * @description: tree conversion
 * @create 2024-05-18 14:46
 */
public class TreeBuilder<T extends ParentTable<T>> {

    public List<T> listToTree(List<T> items) {
        Map<Object, T> itemMap = items.stream().collect(Collectors.toMap(T::getId, Function.identity()));
        List<T> tree = new ArrayList<>();
        for (T item : items) {
            T parent = itemMap.get(item.getParentId());
            if (parent != null) {
                parent.addChild(item);
            } else {
                tree.add(item);
            }
        }
        return tree;
    }

}
