package com.chinaitop.depot.qualityControl.controller;

import com.chinaitop.depot.common.CommonParam;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspection;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspectionPage;
import com.chinaitop.depot.qualityControl.service.QualityInspectionService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.util.ObjectUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Collections;

/**
 * @author qingsong.han
 * @description: 验收质检控制类
 * @create 2024-05-16 14:59
 */
@RestController
@RequestMapping(value = "/qualityInspectionController")
@Api(value = "qualityInspectionController", description = "验收质检")
public class QualityInspectionController {
    @Resource
    private QualityInspectionService qualityInspectionService;

    @RequestMapping(value = "/getPageList", method = RequestMethod.GET)
    @ApiOperation(value = "分页列表", notes = "分页列表")
    public ResponseEntity<PageInfo<BusinessQcQualityInspection>> getPageList(@Validated BusinessQcQualityInspectionPage pageParam) {
        return ResponseEntity.ok(qualityInspectionService.getPageList(pageParam));
    }

    @PostMapping("/save")
    @ApiOperation(value = "新增", notes = "新增")
    public ResponseEntity save(@RequestBody BusinessQcQualityInspection saveParam) {
        return ResponseEntity.ok(qualityInspectionService.save(saveParam));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改", notes = "修改")
    public ResponseEntity update(@RequestBody BusinessQcQualityInspection saveParam) {
        return ResponseEntity.ok(qualityInspectionService.update(saveParam));
    }

    @GetMapping("/getByMasterId/{id}")
    @ApiOperation(value = "详情", notes = "详情")
    public ResponseEntity getByMasterId(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(qualityInspectionService.getByMasterId(id));
    }

    @DeleteMapping("/deleteByMasterId/{id}/{orgId}")
    @ApiOperation(value = "删除", notes = "删除主子表数据")
    public ResponseEntity deleteByMasterId(@PathVariable("id") Integer id,@PathVariable("orgId") Integer orgId) {
        return ResponseEntity.ok(qualityInspectionService.deleteByMasterId(id,orgId));
    }

    @PostMapping("/getByStoreAndWarehouse")
    @ApiOperation(value = "详情带出数据", notes = "库区编码,仓房编码,货位编码")
    public ResponseEntity getByStoreAndWarehouse(@Validated CommonParam param) {
        return ResponseEntity.ok(qualityInspectionService.getByStoreAndWarehouse(param));
    }

    @GetMapping("/getEnumTreeList/{parentId}")
    @ApiOperation(value = "获取子级或树型", notes = "子级或树型")
    public ResponseEntity getEnumTreeList(@PathVariable("parentId") Integer parentId) {
        if (ObjectUtils.isEmpty(parentId))
            return ResponseEntity.ok(Collections.EMPTY_LIST);
        return ResponseEntity.ok(qualityInspectionService.getEnumTreeList(parentId));
    }

}
