package com.chinaitop.depot.qualityControl.service.impl;

import com.chinaitop.depot.common.CommonParam;
import com.chinaitop.depot.common.TreeBuilder;
import com.chinaitop.depot.qualityControl.mapper.BusinessQcQualityInspectionItemMapper;
import com.chinaitop.depot.qualityControl.mapper.BusinessQcQualityInspectionMapper;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspection;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspectionItem;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspectionItemExample;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspectionPage;
import com.chinaitop.depot.qualityControl.service.QualityInspectionService;
import com.chinaitop.depot.utils.DateUtil;
import com.chinaitop.depot.utils.GenerateNumberUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.validation.constraints.NotBlank;
import java.util.*;

/**
 * @author qingsong.han
 * @description:
 * @create 2024-05-16 15:08
 */
@Slf4j
@Service
public class QualityInspectionServiceImpl implements QualityInspectionService {
    @Resource
    private BusinessQcQualityInspectionMapper qualityInspectionMapper;
    @Resource
    private BusinessQcQualityInspectionItemMapper qualityInspectionItemMapper;
    
    @Resource
    private RestTemplate restTemplate;

    @Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;
    

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int save(BusinessQcQualityInspection saveParam) {
        // 生成质检报告单(检验类别+检验日期(yyyyMMdd)+4位顺序号组成)
        saveParam.setZjbgdh(this.GetZjbgdh(saveParam));
        Date date = new Date();
        saveParam.setCreatedate(date);
        saveParam.setUpdatedate(date);
        int insert = qualityInspectionMapper.insert(saveParam);
        Integer id = saveParam.getId();
        log.info("id: {}", id);
        if (insert > 0) {
            // 保存子表数据
            List<BusinessQcQualityInspectionItem> item = saveParam.getItem();
            if (!ObjectUtils.isEmpty(item)) {
                item.forEach(i -> {
                    Date now = new Date();
                    i.setCreatedate(now);
                    i.setUpdatedate(now);
                    i.setQcQualityInspectionId(id);
                    qualityInspectionItemMapper.insert(i);
                });
            }
            
            this.gjjjk(id.toString(),saveParam.getOrgId().toString(),"i");
        }
        return insert;
    }

    // // 生成质检报告单(检验类别+检验日期(yyyyMMdd)+4位顺序号组成)
    private synchronized String GetZjbgdh(BusinessQcQualityInspection saveParam) {
        // 查询最后一个顺序号
//        Map<String, Object> map = new HashMap<>();
//        map.put("orgId", saveParam.getOrgId());
//        map.put("basicStorehouseId", saveParam.getBasicStorehouseId());
//        map.put("warehouseId", saveParam.getWarehouseId());
        String xh = qualityInspectionMapper.selectOnly();
        // 初始化
        int num = 1;
        if (!StringUtils.isEmpty(xh)) {
            String substring = xh.substring(xh.length() - 4);
            int i = Integer.parseInt(substring);
            if (i < 9999)
                num += i;
        }
        return String.format(
                "%s%s%s", saveParam.getJylb(),
                DateUtil.getYMD(saveParam.getJysj()),
                GenerateNumberUtil.integerToString(4, num)
        );
    }

    @Override
    public PageInfo<BusinessQcQualityInspection> getPageList(BusinessQcQualityInspectionPage pageParam) {
        PageHelper.startPage(pageParam.getPageNum(), pageParam.getPageSize());
        List<BusinessQcQualityInspection> list = qualityInspectionMapper.getPageList(pageParam);
        return new PageInfo<>(list);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int update(BusinessQcQualityInspection saveParam) {
        saveParam.setUpdatedate(new Date());
        int i = qualityInspectionMapper.updateByPrimaryKey(saveParam);
        if (i > 0) {
            saveParam.getItem().forEach(it -> {
                it.setUpdatedate(new Date());
                qualityInspectionItemMapper.updateByPrimaryKey(it);
            });
            
            this.gjjjk(saveParam.getId().toString(),saveParam.getOrgId().toString(),"u");
        }
        return i;
    }

    @Override
    public BusinessQcQualityInspection getByMasterId(Integer id) {
        // id查询主表数据
        BusinessQcQualityInspection masterParam = qualityInspectionMapper.selectByPrimaryKey(id);
        // 查询子表数据
        BusinessQcQualityInspectionItemExample example = new BusinessQcQualityInspectionItemExample();
        example.createCriteria().andQcQualityInspectionIdEqualTo(id);
        masterParam.setItem(qualityInspectionItemMapper.selectByExample(example));
        return masterParam;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteByMasterId(Integer id,Integer orgId) {
        // 删除主表数据
        int i = qualityInspectionMapper.deleteByPrimaryKey(id);
        if (i > 0) {
            BusinessQcQualityInspectionItemExample example = new BusinessQcQualityInspectionItemExample();
            example.createCriteria().andQcQualityInspectionIdEqualTo(id);
            qualityInspectionItemMapper.deleteByExample(example);
            
            this.gjjjk(id.toString(),orgId.toString(),"d");
        }
        return i;
    }

    @Override
    public Map<String, Object> getByStoreAndWarehouse(CommonParam param) {
        return qualityInspectionMapper.selectByStoreAndWarehouse(param);
    }

    @Override
    public List<Map<String, Object>> getEnumTreeList(Integer parentId) {
        return qualityInspectionMapper.getEnumTreeList(parentId);
    }
    
    /**
	 * 国家局数据
	 */
    public void gjjjk(String id, String orgId,String czbz) {
    	
		String tableName = "ODS_UP_ZJXXJK";
		/**
         * restTemplate调用
         */
        //String url = "http://localhost:9022/recPublish/sendMessage";//
        //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
		
        MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
		sendMap.add("tableName", tableName);
		sendMap.add("czbz", czbz);
		sendMap.add("ywId", id);
		sendMap.add("orgId", orgId);

        restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
    }

}
