package com.chinaitop.depot.storage.controller;


import com.chinaitop.depot.storage.model.StorageStorehouseBusiness;
import com.github.pagehelper.PageHelper;
import com.chinaitop.depot.storage.model.ClearanceConfirmation;
import com.chinaitop.depot.storage.service.ClearanceConfirmationService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 出清确认单Controller
 *
 * @author User
 *
 */
@SuppressWarnings("all")
@RestController
@RequestMapping(value = "/ClearanceConfirmationController")
@Api(value= "ClearanceConfirmationController", description = "出清确认单控制类")
public class ClearanceConfirmationController {

    final static Logger logger = LoggerFactory.getLogger(ClearanceConfirmation.class);
    @Resource
    private ClearanceConfirmationService clearanceConfirmationService;

    /**
     * 出清确认单信息
     *
     * @param pageNum 页数
     * @param pageSize 每页显示的条数
     * @param storeName 仓房名称
     * @param ajmc 廒间名称
     * @param orgId 单位ID
     * @return
     */
    @RequestMapping(value = "/getCleConList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询出清确认单信息数据列表", notes = "查询出清确认单信息数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "storeName", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "ajmc", value = "廒间名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")

    })
    public PageInfo<ClearanceConfirmation> getCleConList(Integer pageNum, Integer pageSize,
                                                     String storeName,
                                                     Integer warehouseId, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<ClearanceConfirmation> list = null;
        try {

            if (null != storeName && !"".equals(storeName)) {
                modelMap.put("storehouseName", storeName);
            }
            if (null != warehouseId && !"".equals(warehouseId)) {
                modelMap.put("warehouseId", warehouseId);
            }
            /* 只能查询当前单位的数据  */
            if (null != orgId) {
                modelMap.put("orgId", orgId);
            }

            list = clearanceConfirmationService.getList(modelMap);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<ClearanceConfirmation> pageInfo = new PageInfo<ClearanceConfirmation>(list);
        return pageInfo;
    }

    /**
     * 根据ID查找出清确认单信息
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/findByCleCon",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据ID查找出清确认单信息", notes = "根据ID查找出清确认单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
    })
    public ClearanceConfirmation findByUnitAisle(Integer id) {
        ClearanceConfirmation ClearanceConfirmation = null;
        try {
            if (id != null) {
                ClearanceConfirmation = clearanceConfirmationService.findByCleCon(id);
            } else {
                ClearanceConfirmation = new ClearanceConfirmation();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return ClearanceConfirmation;
    }


    @RequestMapping(value = "/edit",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新出清确认单信息", notes = "更新出清确认单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "clearanceConfirmationJson", value = "JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "userInfo", value = "JSON登录对象", paramType = "form")
    })
    public Map<String, Object> edit(HttpServletRequest request, String clearanceConfirmationJson, String userInfo) {
        Map<String, Object> modelMap = null;
        try {
            modelMap = clearanceConfirmationService.saveOrUpdate(request, clearanceConfirmationJson, userInfo);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }
    }

    /**
     * 删除出清确认单
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除出清确认单", notes = "删除出清确认单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // 先查询到这条数据
            ClearanceConfirmation clearanceConfirmation = clearanceConfirmationService.findByCleCon(id);
            clearanceConfirmation.setCzbz("d");
            clearanceConfirmationService.updateBasicStorehouse(clearanceConfirmation);
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "操作失败！");
        }
        return modelMap;
    }


    /**
     * 查询当前库区库存实物为空仓的仓房
     *
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findStorehouse",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    public List<StorageStorehouseBusiness> findStorehouse(Integer orgId) {
        List<StorageStorehouseBusiness> storageStorehouseBusinessList = null;
        try {

            storageStorehouseBusinessList = clearanceConfirmationService.findStorehouse(orgId);

        } catch (Exception e) {
            e.printStackTrace();
        }
        return storageStorehouseBusinessList;
    }

    /**
     * 查询当前库区库存实物为空仓的仓房
     *
     * @param storehouseId
     * @return
     */
    @RequestMapping(value = "/findByWarehouse",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    public List<StorageStorehouseBusiness> findByWarehouse(Integer storehouseId) {
        List<StorageStorehouseBusiness> storageStorehouseBusinessList = null;
        try {

            storageStorehouseBusinessList = clearanceConfirmationService.findByWarehouse(storehouseId);

        } catch (Exception e) {
            e.printStackTrace();
        }
        return storageStorehouseBusinessList;
    }

    

}
