/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspection;
import com.chinaitop.depot.storage.model.GrainSituationCard;
import com.chinaitop.depot.storage.model.vo.GrainSituationCardVO;
import com.chinaitop.depot.storage.param.GrainSituationCardIdParam;
import com.chinaitop.depot.storage.param.GrainSituationCardPageParam;
import com.chinaitop.depot.storage.service.GrainSituationCardService;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;


import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 原粮转卡（粮情卡）控制器
 *
 * @author ZeroLiYi
 * @date  2024/05/24 09:50
 */
@Api(tags = "原粮转卡（粮情卡）控制器")
@RestController
@Validated
public class GrainSituationCardController {

    @Resource
    private GrainSituationCardService grainSituationCardService;

    /**
     * 获取原粮转卡（粮情卡）分页
     *
     * @author ZeroLiYi
     * @date  2024/05/24 09:50
     */

    @ApiOperation("获取原粮转卡（粮情卡）分页")
    @GetMapping("/storage/page")
    public PageInfo<GrainSituationCard> page(GrainSituationCardPageParam grainSituationCardPageParam) {
        List<GrainSituationCard> list= grainSituationCardService.page(grainSituationCardPageParam);
        PageInfo<GrainSituationCard> pageInfo = new PageInfo<GrainSituationCard>(list);
        return pageInfo;
    }

    /**
     * 获取原粮转卡（粮情卡）详情
     *
     * @author ZeroLiYi
     * @date  2024/05/24 09:50
     */

    @ApiOperation("获取原粮转卡（粮情卡）详情")
    @GetMapping("/storage/detail")
    public GrainSituationCardVO detail(GrainSituationCardIdParam grainSituationCardIdParam) {
        return grainSituationCardService.detail(grainSituationCardIdParam);
    }

    /**
     * 根据货位查询粮情卡质检报告
     * @return
     * @throws
     */
    @GetMapping("/storage/getFindByWarehouseId")
    @ApiOperation(value="根据货位查询粮情卡质检报告", notes = "根据货位查询粮情卡质检报告")
    public List<BusinessQcQualityInspection> getFindByWarehouseId(@RequestParam("warehouseId")Integer warehouseId) throws Exception {

        List<BusinessQcQualityInspection> list = grainSituationCardService.getQualityInspectionFindByWarehouseId(warehouseId);
        return list;
    }



    /**
     * 保存原粮转卡（粮情卡）
     *
     * @author ZeroLiYi
     * @date  2024/05/24 09:50
     */

    @ApiOperation("添加原粮转卡（粮情卡）")
    @PostMapping("/storage/add")
    public Map<String, Object> add(@RequestBody GrainSituationCardVO grainSituationCardVO) {
        Map<String, Object> modelMap = null;

        try {
            modelMap = grainSituationCardService.add(grainSituationCardVO);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }

    }

    /**
     * 导出原粮转卡（粮情卡）
     *
     * @author ZeroLiYi
     * @date  2024/05/24 09:50
     */

    @ApiOperation("导出原粮转卡（粮情卡）详情")
    @GetMapping("/storage/export")
    public  Map<String, Object> export(GrainSituationCardIdParam grainSituationCardIdParam) {
        Map<String, Object> modelMap = null;

        try {
            modelMap = grainSituationCardService.exportdetail(grainSituationCardIdParam);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }
    }
}
