package com.chinaitop.depot.storage.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.TCcdata;
import com.chinaitop.depot.storage.model.TCcdataExample;
import com.chinaitop.depot.storage.model.TCcvalue;
import com.chinaitop.depot.storage.service.InsectPestDetectionService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value = "/intelligents/insectPestDetection")
@Api(value = "InsectPestDetectionController", description = "虫害检测记录控制类")
@SuppressWarnings("all")
public class InsectPestDetectionController {

    @Resource
    InsectPestDetectionService insectPestDetectionService;

    /**
     * 虫害信息列表
     *
     * @param pageNum
     * @param pageSize
     * @param iBeginTdh
     * @param iEndTdh
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "查询虫害信息列表", notes = "虫害信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "iBeginTdh", value = "开始通道号", paramType = "query"),
            @ApiImplicitParam(name = "iEndTdh", value = "结束通道号", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public ResponseEntity<PageInfo<TCcdata>> getList(Integer pageNum, Integer pageSize, String vCfCode, Integer iBeginTdh, Integer iEndTdh,String createTime,String orgId) {
        List<TCcdata> list = null;
        try {
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = insectPestDetectionService.getList(vCfCode, iBeginTdh, iEndTdh,createTime,orgId);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询失败");
        }
        PageInfo<TCcdata> pageInfo = new PageInfo<>(list);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/getByCfCode", method = RequestMethod.GET)
    @ApiOperation(value = "查询虫害信息列表", notes = "虫害信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vCfCode", value = "仓房code", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始时间", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束时间", paramType = "query")
    })
    public ResponseEntity getByCfCode(String vCfCode, String searchStartDate, String searchEndDate) {
        ResponseEntity byCfCode = null;
        try {
            byCfCode = insectPestDetectionService.getByCfCode(vCfCode, searchStartDate, searchEndDate);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询图表数据失败");
        }
        return byCfCode;
    }

    @RequestMapping(value = "/getByIdCcData", method = RequestMethod.GET)
    @ApiOperation(value = "查询一条虫害信息", notes = "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "仓房code", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始时间", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束时间", paramType = "query")
    })
    public ResponseEntity<TCcdata> getByIdTCcData(String id) {
        TCcdata tCcdata = null;
        try {
            tCcdata  = insectPestDetectionService.getByIdTCcData(id);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("error");
        }
        return ResponseEntity.ok(tCcdata);
    }

    @RequestMapping(value = "/getOneByCfCode", method = RequestMethod.GET)
    @ApiOperation(value = "查询虫害信息", notes = "虫害信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "库点编码", paramType = "query"),
            @ApiImplicitParam(name = "vCfCode", value = "仓房code", paramType = "query")
    })
    public ResponseEntity getOneByCfCode(String orgId, String vCfCode) {
        TCcvalue ccvalue = null;
        try {
            ccvalue =  insectPestDetectionService.getOneByCfCode(orgId, vCfCode);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询测虫数据失败");
        }
        return ResponseEntity.ok(ccvalue);
    }

    @RequestMapping(value = "/addInsectPestData", method = RequestMethod.POST)
    @ApiOperation(value = "添加或修改虫害", notes = "手工添加或修改虫害数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "insectPests", value = "虫数据", paramType = "form")
    })
    public ResponseEntity addInsectPestData(String insectPests) {

        Map<String, Object> modelMap = new HashMap<String, Object>();
        
        try {
			insectPestDetectionService.saveOrUpdate(insectPests);
			modelMap.put("msg", "保存成功");
		} catch (Exception e) {
			modelMap.put("msg", "保存失败");
			e.printStackTrace();
		}
        return ResponseEntity.ok(modelMap);
    }

    @RequestMapping(value = "/getInsectPestDeatil", method = RequestMethod.POST)
    @ApiOperation(value = "修改虫害单仓手工录入数据", notes = "修改虫害单仓手工录入数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "insectPestId", value = "虫害检测id", paramType = "query")
    })
    public ResponseEntity getInsectPestDeatil(String insectPestId) {
        TCcdata tCcdata = new TCcdata();
        TCcdataExample example = new TCcdataExample();
        TCcdataExample.Criteria criteria = example.createCriteria();
        criteria.andIdEqualTo(insectPestId);
        List<TCcdata> tccdataList = insectPestDetectionService.getInsectPestDeatil(example);
        return ResponseEntity.ok(tccdataList);
    }
}
