package com.chinaitop.depot.storage.controller;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageChangeStoragehouseDefault;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseDefaultExample;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseDefaultExample.Criteria;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseRop;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseRopExample;
import com.chinaitop.depot.storage.service.StorageChangeStoragehouseRopService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value = "/StorageChangeStoragehouseRopController")
@Api(value = "StorageChangeStoragehouseRopController", description = "倒仓作业类")
public class StorageChangeStoragehouseRopController {
	
	@Resource 
	private StorageChangeStoragehouseRopService storageChangeStoragehouseRopService;
	
	final static Logger logger = LoggerFactory.getLogger(StorageChangeStoragehouseRop.class);
	
	@RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓列表", notes = "查询倒仓信息列表，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "changehouseNo", value = "倒仓单号", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeA", value = "申请日期A", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeB", value = "申请日期B", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public PageInfo<StorageChangeStoragehouseDefault> getList(Integer pageNum, Integer pageSize, String changehouseNo,
		String applyTimeA, String applyTimeB, String createTime,Integer orgId,Integer ch,Integer hwh) throws ParseException {
		StorageChangeStoragehouseDefaultExample StorageChangeStoragehouseDefaultExample = new StorageChangeStoragehouseDefaultExample();
		Criteria Criteria = StorageChangeStoragehouseDefaultExample.createCriteria();
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		// 拼接查询条件
		if (changehouseNo != null && !"".equals(changehouseNo)) {
			Criteria.andChangehouseNoLike("%" + changehouseNo + "%");
		}
		
		if (applyTimeA != null && !"".equals(applyTimeA)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeA + " 00:00:00");
			Criteria.andApplyTimeGreaterThanOrEqualTo(starDate);
		}
		if (applyTimeB != null && !"".equals(applyTimeB)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeB + " 23:59:59");
			Criteria.andApplyTimeLessThanOrEqualTo(starDate);
		}
		if (createTime != null && !"".equals(createTime)) {
			SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			Date createDate  = simpleDateFormat.parse(createTime);
			Criteria.andCreateTimeGreaterThanOrEqualTo(createDate);
		}
		if (ch != null && !"".equals(ch)) {
			Criteria.andOutStorehouseEqualTo(ch);
		}
		if (hwh != null && !"".equals(hwh)) {
			Criteria.andOutWarehouseEqualTo(hwh);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		StorageChangeStoragehouseDefaultExample.setOrderByClause("create_time asc");
		List<StorageChangeStoragehouseDefault> list = storageChangeStoragehouseRopService.selectByExample(StorageChangeStoragehouseDefaultExample);
		PageInfo<StorageChangeStoragehouseDefault> pageInfo = new PageInfo<StorageChangeStoragehouseDefault>(list);
		return pageInfo;
	}
	
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/findRopData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓通知单", notes = "查询倒仓通知单")
	@ApiImplicitParams({ @ApiImplicitParam(name = "changehouseNo", value = "倒仓通知单号", paramType = "query"),
		@ApiImplicitParam(name = "applyNo", value = "倒仓申请单号", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public Map<String, Object> findRopData(String changehouseNo, String applyNo, Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageChangeStoragehouseDefaultExample example = new StorageChangeStoragehouseDefaultExample();
		Criteria Criteria = example.createCriteria();
		if (changehouseNo != null && !"".equals(changehouseNo)) {
			Criteria.andChangehouseNoEqualTo(changehouseNo);
		}
		if (applyNo != null && !"".equals(applyNo)) {
			Criteria.andApplyNoEqualTo(applyNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		List<StorageChangeStoragehouseDefault> list = storageChangeStoragehouseRopService.selectByExample(example);
		modelMap.put("ChangeStoragehouseRop", list);
		return modelMap;
	}
	
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/getListRop", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "倒仓进度列表查询", notes = "倒仓进度列表查询，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "changehouseNo", value = "倒仓单号", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeA", value = "申请日期A", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeB", value = "申请日期B", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public PageInfo<StorageChangeStoragehouseRop> getListRop(Integer pageNum, Integer pageSize, String changehouseNo,
		String applyTimeA, String applyTimeB, Integer orgId) {
		StorageChangeStoragehouseRopExample StorageChangeStoragehouseRopExample = new StorageChangeStoragehouseRopExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseRopExample.Criteria Criteria = StorageChangeStoragehouseRopExample.createCriteria();
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		// 拼接查询条件
		if (changehouseNo != null && !"".equals(changehouseNo)) {
			Criteria.andChangehouseNoLike("%" + changehouseNo + "%");
		}
		
		if (applyTimeA != null && !"".equals(applyTimeA)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeA + " 00:00:00");
			Criteria.andApplyTimeGreaterThanOrEqualTo(starDate);
		}
		if (applyTimeB != null && !"".equals(applyTimeB)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeB + " 23:59:59");
			Criteria.andApplyTimeLessThanOrEqualTo(starDate);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		StorageChangeStoragehouseRopExample.setOrderByClause("create_time asc");
		List<StorageChangeStoragehouseRop> list = storageChangeStoragehouseRopService.selectByExample(StorageChangeStoragehouseRopExample);
		PageInfo<StorageChangeStoragehouseRop> pageInfo = new PageInfo<StorageChangeStoragehouseRop>(list);
		return pageInfo;
	}
	
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/showDataR", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "倒仓进度明细查询", notes = "倒仓进度明细查询")
	@ApiImplicitParams({ @ApiImplicitParam(name = "changehouseNo", value = "通知单号", paramType = "query"),
		@ApiImplicitParam(name = "applyNo", value = "申请单号", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public Map<String, Object> showDataR(String changehouseNo, String applyNo, Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageChangeStoragehouseRopExample storageChangeStoragehouseRopExample = new StorageChangeStoragehouseRopExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseRopExample.Criteria Criteria = storageChangeStoragehouseRopExample.createCriteria();
		if (changehouseNo != null && !"".equals(changehouseNo)) {
			Criteria.andChangehouseNoEqualTo(changehouseNo);
		}
		if (applyNo != null && !"".equals(applyNo)) {
			Criteria.andApplyNoEqualTo(applyNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		List<StorageChangeStoragehouseRop> list = storageChangeStoragehouseRopService.selectByExample(storageChangeStoragehouseRopExample);
		modelMap.put("ChangeStoragehouseRopList", list);
		return modelMap;
	}
	
	
	@RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
	  @ApiImplicitParams({
	  @ApiImplicitParam(name = "save", value = "新增数据", paramType = "query") 
	  })
    public Map<String, Object> save(String change){
		Map<String, Object> modelMap = new HashMap<String, Object>();
		logger.info("接收的到仓通知单数据如下：\r\n\t"+change);
		modelMap = storageChangeStoragehouseRopService.add(change);  
        return modelMap;
    }
}
