package com.chinaitop.depot.storage.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseTask;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetail;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskExample;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskExample.Criteria;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseWorkTask;
import com.chinaitop.depot.storage.model.StorageChangeStoragehouseWorkTaskExample;
import com.chinaitop.depot.storage.service.StorageChangeStoragehouseTaskDetailService;
import com.chinaitop.depot.storage.service.StorageChangeStoragehouseTaskService;
import com.chinaitop.depot.storage.service.StorageChangeStoragehouseWorkTaskService;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoService;
import com.chinaitop.depot.storage.utils.DateJsonValueProcessor;
import com.chinaitop.depot.storage.utils.HTTPUtils;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.storage.utils.createKC;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import net.sf.json.JsonConfig;

/**
 * @author liangs
 * @Date 2019/06/14
 */
@RestController
@RequestMapping(value = "/StorageChangeStoragehouseTaskController")
@Api(value = "StorageChangeStoragehouseTaskController", description = "倒仓作业类")
public class StorageChangeStoragehouseTaskController {

	@Resource
	private StorageChangeStoragehouseTaskService storageChangeStoragehouseTaskService;

	@Resource
	private StorageChangeStoragehouseTaskDetailService storageChangeStoragehouseTaskDetailService;

	@Resource
	private StorageFoodbasicInfoService foodbasicInfoService;

	@Resource
	private StorageChangeStoragehouseWorkTaskService storageChangeStoragehouseWorkTaskService;

	// 获取出入库ip地址
	@Value("${crk-webservice}")
	private String url;
	
	// 获取出入库ip地址
	@Value("${report-Url}")
	private String changeUrl;
	/**
	 * 得到当前倒仓主表中数据
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓申请列表", notes = "查询倒仓申请信息列表，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "businessNo", value = "倒仓业务单号", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeA", value = "申请日期A", paramType = "query"),
			@ApiImplicitParam(name = "applyTimeB", value = "申请日期B", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public PageInfo<StorageChangeStoragehouseTask> getList(Integer pageNum, Integer pageSize, String businessNo,
			String applyTimeA, String applyTimeB, Integer orgId) {
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		// 拼接查询条件
		if (businessNo != null && !"".equals(businessNo)) {
			Criteria.andBusinessNoLike("%" + businessNo + "%");
		}
		
		if (applyTimeA != null && !"".equals(applyTimeA)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeA + " 00:00:00");
			Criteria.andApplyTimeGreaterThanOrEqualTo(starDate);
		}
		if (applyTimeB != null && !"".equals(applyTimeB)) {
			Date starDate = ParameterUtil.string2datetime(applyTimeB + " 23:59:59");
			Criteria.andApplyTimeLessThanOrEqualTo(starDate);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		example.setOrderByClause("apply_time asc");
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		PageInfo<StorageChangeStoragehouseTask> pageInfo = new PageInfo<StorageChangeStoragehouseTask>(list);
		return pageInfo;
	}

	/**
	 * 更新倒仓信息
	 *
	 * @param storeChangeStoragehouseJson
	 *            JSON数据对象
	 * @return
	 */
	@SuppressWarnings("unchecked")
	@RequestMapping(value = "/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "新增倒仓信息", notes = "新增倒仓信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "storeChangeStoragehouseJson", value = "JSON数据对象", paramType = "form"),
			@ApiImplicitParam(name = "addDcsl", value = "JSON数据对象", paramType = "form") })
	public Map<String, Object> edit(HttpServletRequest request, Integer change, String crk_ip, String storeChangeStoragehouseJson,
			String storeChangeStorageaddDcsl) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Date date = new Date();
		JSONObject changeStorage = null;
		String businessNo = null;
		String crk_adr = "";
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		if (null != storeChangeStoragehouseJson && !"".equals(storeChangeStoragehouseJson)) {
			changeStorage = JSONObject.parseObject(storeChangeStoragehouseJson);
			businessNo = (changeStorage.get("businessNo") == null ? "" : changeStorage.get("businessNo").toString());
		}
		try {
			// JSON字符串转对象
			ObjectMapper mapper = new ObjectMapper();
			/*
			 * mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
			 */
			// 添加主表字段
			if (change == 0) {
				StorageChangeStoragehouseTask storageChangeStoragehouseTask = (StorageChangeStoragehouseTask) mapper
						.readValue(storeChangeStoragehouseJson, StorageChangeStoragehouseTask.class);
				storageChangeStoragehouseTask.setCreateDate(date);
				storageChangeStoragehouseTask.setOrgId(orgId);
				storageChangeStoragehouseTask.setIsUpload(0);
				storageChangeStoragehouseTaskService.addStorageChangeStoragehouseTask(storageChangeStoragehouseTask);
				// 添加子表字段
				List<StorageChangeStoragehouseTaskDetail> storageChangeStoragehouseTaskDetailList = null;
				if (storeChangeStorageaddDcsl != null) {
					storageChangeStoragehouseTaskDetailList = (List<StorageChangeStoragehouseTaskDetail>) mapper
							.readValue(storeChangeStorageaddDcsl,new TypeReference<List<StorageChangeStoragehouseTaskDetail>>() {
					});
				}
				// 新增仓房货位数量质量标准子表.
				if (storageChangeStoragehouseTaskDetailList != null
						&& storageChangeStoragehouseTaskDetailList.size() > 0) {
					for (StorageChangeStoragehouseTaskDetail storageChangeStoragehouseTaskDetail : storageChangeStoragehouseTaskDetailList) {
						storageChangeStoragehouseTaskDetail.setOrg_id(orgId);
						storageChangeStoragehouseTaskDetail.setUpdateTime(date);
						storageChangeStoragehouseTaskDetail.setBusinessNo(businessNo);
//						Object[] parameters = new Object[10];
//						parameters[0] = storageChangeStoragehouseTaskDetail.getOrg_id() + "";
//						parameters[1] = storageChangeStoragehouseTaskDetail.getLspz() + "";
//						// parameters[2] = null; 明细品种
//						parameters[3] = storageChangeStoragehouseTaskDetail.getStorehouseId() + "";
//						parameters[4] = storageChangeStoragehouseTaskDetail.getWarehouseId() + "";
//						parameters[5] = storageChangeStoragehouseTaskDetail.getHouseId() + "";
//						parameters[6] = storageChangeStoragehouseTaskDetail.getWareId() + "";
//						// parameters[7] = null; 粮食性质
//						parameters[8] = storageChangeStoragehouseTaskDetail.getPourInNum() + "";
//						parameters[9] = 1 + ""; // 1:新增；2：修改；3：删除
//						crk_adr = url;
//						String str = createKC.createKC("ChangeWarehouse", crk_adr, parameters);
//						if ("true".equals(str)) {
//							modelMap.put("status", "success");
//						} else {
//							modelMap.put("status", "error");
//							modelMap.put("msg", "保存失败，倒仓数据同步异常，请联系管理员！");
//						}
						storageChangeStoragehouseTaskDetailService.addStorageChangeStoragehouseTaskDetail(storageChangeStoragehouseTaskDetail);
					}
				}
			} else if (change == 1) {
				StorageChangeStoragehouseTask storageChangeStoragehouseTask = (StorageChangeStoragehouseTask) mapper
						.readValue(storeChangeStoragehouseJson, StorageChangeStoragehouseTask.class);
				storageChangeStoragehouseTask.setCreateDate(date);
				storageChangeStoragehouseTask.setOrgId(orgId);
				storageChangeStoragehouseTaskService.updateStorageChangeStoragehouseTask(storageChangeStoragehouseTask);
				// 添加子表字段
				List<StorageChangeStoragehouseTaskDetail> storageChangeStoragehouseTaskDetailList = null;
				if (storeChangeStorageaddDcsl != null) {
					storageChangeStoragehouseTaskDetailList = (List<StorageChangeStoragehouseTaskDetail>) mapper
							.readValue(storeChangeStorageaddDcsl,
									new TypeReference<List<StorageChangeStoragehouseTaskDetail>>() {
									});
				}
				// 新增仓房货位数量质量标准子表.
				if (storageChangeStoragehouseTaskDetailList != null
						&& storageChangeStoragehouseTaskDetailList.size() > 0) {
					for (StorageChangeStoragehouseTaskDetail storageChangeStoragehouseTaskDetail : storageChangeStoragehouseTaskDetailList) {
						storageChangeStoragehouseTaskDetail.setOrg_id(orgId);
						storageChangeStoragehouseTaskDetail.setUpdateTime(date);
						storageChangeStoragehouseTaskDetail.setBusinessNo(businessNo);
						storageChangeStoragehouseTaskDetailService
								.updateStorageChangeStoragehouseTaskDetail(storageChangeStoragehouseTaskDetail);
					}
				}
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败！");
		}
		return modelMap;
	}

	/**
	 * 查看倒仓数据列表
	 * 
	 * @param businessNo
	 * @param orgId
	 * @return
	 */
	@RequestMapping(value = "/findChangeData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓数据列表", notes = "查询倒仓申请信息列表")
	@ApiImplicitParams({ @ApiImplicitParam(name = "businessNo", value = "倒仓申请单号", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public Map<String, Object> findChangeData(String businessNo, Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		if (businessNo != null && !"".equals(businessNo)) {
			Criteria.andBusinessNoEqualTo(businessNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		modelMap.put("ChangeStoragehouseTask", list);
		StorageChangeStoragehouseTaskDetailExample detailExamle = new StorageChangeStoragehouseTaskDetailExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample.Criteria detailCriteria = detailExamle
				.createCriteria();
		if (businessNo != null && !"".equals(businessNo)) {
			detailCriteria.andBusinessNoEqualTo(businessNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			detailCriteria.andOrg_idEqualTo(orgId);
		}
		List<StorageChangeStoragehouseTaskDetail> detailList = storageChangeStoragehouseTaskDetailService
				.selectByExample(detailExamle);
		modelMap.put("StorageChangeStoragehouseTaskDetail", detailList);
		return modelMap;
	}

	/**
	 * 根据倒仓申请单号删除一条倒仓数据
	 * 
	 * @param businessNo
	 * @return
	 */
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/removeChangeData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "删除一条倒仓数据", notes = "删除一条倒仓数据")
	@ApiImplicitParams({ @ApiImplicitParam(name = "businessNo", value = "倒仓申请单号", paramType = "query"), })
	public Map<String, Object> removeChangeData(HttpServletRequest request, String businessNo) {
		Map<String, Object> map = new HashMap<String, Object>();
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		try {
			StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
			Criteria Criteria = example.createCriteria();
			if (businessNo != null && !"".equals(businessNo)) {
				Criteria.andBusinessNoEqualTo(businessNo);
			}
			if (orgId != null && !"".equals(orgId)) {
				Criteria.andOrgIdEqualTo(orgId);
			}
			storageChangeStoragehouseTaskService.removeChangeData(example);
			StorageChangeStoragehouseTaskDetailExample detailExamle = new StorageChangeStoragehouseTaskDetailExample();
			com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample.Criteria detailCriteria = detailExamle
					.createCriteria();
			if (businessNo != null && !"".equals(businessNo)) {
				detailCriteria.andBusinessNoEqualTo(businessNo);
			}
			if (orgId != null && !"".equals(orgId)) {
				detailCriteria.andOrg_idEqualTo(orgId);
			}
			storageChangeStoragehouseTaskDetailService.removeChangeData(detailExamle);
			map.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			map.put("status", "error");
			map.put("msg", "保存失败！");
		}
		return map;
	}

	/**
	 * 得到当前倒仓主表中数据
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@RequestMapping(value = "/getWorkPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓申请列表", notes = "查询倒仓申请信息列表，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "planStartDateA", value = "计划开始日期A", paramType = "query"),
			@ApiImplicitParam(name = "planStartDateB", value = "计划开始日期B", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public PageInfo<StorageChangeStoragehouseTask> getWorkPageInfo(Integer pageNum, Integer pageSize, Integer orgId,
			String planStartDateA, String planStartDateB) {
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		String planType = "ChangeWork";
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		if (planStartDateA != null && !"".equals(planStartDateA)) {
			Date starDate = ParameterUtil.string2datetime(planStartDateA + " 00:00:00");
			Criteria.andPlanStartDateGreaterThanOrEqualTo(starDate);
		}
		if (planStartDateB != null && !"".equals(planStartDateB)) {
			Date starDate = ParameterUtil.string2datetime(planStartDateB + " 23:59:59");
			Criteria.andPlanStartDateLessThanOrEqualTo(starDate);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		if (planType != null && !"".equals(planType)) {
			Criteria.andPlanTypeLessThanOrEqualTo(planType);
		}
		example.setOrderByClause("apply_time asc");
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		PageInfo<StorageChangeStoragehouseTask> pageInfo = new PageInfo<StorageChangeStoragehouseTask>(list);
		return pageInfo;
	}

	/**
	 * 得到当前倒仓主表中数据
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@RequestMapping(value = "/getChangeDataPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓作业列表", notes = "查询倒仓作业列表，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "applyStatus", value = "审核状态", paramType = "query"), })
	public PageInfo<StorageChangeStoragehouseTaskDetail> getChangeDataPageInfo(HttpServletRequest request,
			Integer pageNum, Integer pageSize, Integer applyStatus) {
		StorageChangeStoragehouseTaskDetailExample detailExamle = new StorageChangeStoragehouseTaskDetailExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample.Criteria Criteria = detailExamle
				.createCriteria();
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrg_idEqualTo(orgId);
		}
		if (applyStatus != null && !"".equals(applyStatus)) {
			Criteria.andApplyStatusEqualTo(applyStatus);
		}
		List<StorageChangeStoragehouseTaskDetail> list = storageChangeStoragehouseTaskDetailService
				.selectByExample(detailExamle);
		PageInfo<StorageChangeStoragehouseTaskDetail> pageInfo = new PageInfo<StorageChangeStoragehouseTaskDetail>(
				list);
		return pageInfo;
	}

	/**
	 * 查看倒仓数据列表
	 * @param request
	 * @param businessNo
	 * @return
	 */
	@RequestMapping(value = "/fandChangeWorkData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询主表数据列表", notes = "查询倒仓工作列表")
	@ApiImplicitParams({ @ApiImplicitParam(name = "businessNo", value = "倒仓申请单号", paramType = "query"), })
	public Map<String, Object> fandChangeWorkData(HttpServletRequest request, String businessNo) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		Criteria Criteria = example.createCriteria();
		if (businessNo != null && !"".equals(businessNo)) {
			Criteria.andBusinessNoEqualTo(businessNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		modelMap.put("ChangeStoragehouseTask", list);
		return modelMap;
	}

	/**
	 * 更新倒仓主表信息，添加倒仓作业表
	 * 
	 * @param storeChangeStoragehouseJson
	 *            JSON数据对象
	 * @return
	 */
	@SuppressWarnings("unchecked")
	@RequestMapping(value = "/updataChangeWork", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "新增倒仓信息", notes = "新增倒仓信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "storeChangeStoragehouseJson", value = "JSON数据对象", paramType = "form"),
			@ApiImplicitParam(name = "storeChangeStorageaddDcsl", value = "JSON数据对象", paramType = "form"),
			@ApiImplicitParam(name = "crk_ip", value = "出入库连接IP", paramType = "form") })
	public Map<String, Object> updataChangeWork(HttpServletRequest request, String storeChangeStoragehouseJson,
			String storeChangeStorageaddDcsl, String crk_ip) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Date date = new Date();
		JSONObject changeStorage = null;
		String workNo = null;
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		if (null != storeChangeStoragehouseJson && !"".equals(storeChangeStoragehouseJson)) {
			changeStorage = JSONObject.parseObject(storeChangeStoragehouseJson);
			workNo = (changeStorage.get("workNo") == null ? "" : changeStorage.get("workNo").toString());
		}
		try {
			// JSON字符串转对象
			ObjectMapper mapper = new ObjectMapper();
			// 添加子表字段
			List<StorageChangeStoragehouseWorkTask> StorageChangeStoragehouseWorkTaskList = null;
			if (storeChangeStorageaddDcsl != null) {
				StorageChangeStoragehouseWorkTaskList = (List<StorageChangeStoragehouseWorkTask>) mapper.readValue(
						storeChangeStorageaddDcsl, new TypeReference<List<StorageChangeStoragehouseWorkTask>>() {
						});
			}
			// 新增仓房货位数量质量标准子表.
			if (StorageChangeStoragehouseWorkTaskList != null && StorageChangeStoragehouseWorkTaskList.size() > 0) {
				for (StorageChangeStoragehouseWorkTask storageChangeStoragehouseWorkTask : StorageChangeStoragehouseWorkTaskList) {
					storageChangeStoragehouseWorkTask.setOrg_id(orgId);
					storageChangeStoragehouseWorkTask.setCreateDate(date);
					storageChangeStoragehouseWorkTask.setWorkNo(workNo);
					// 只有同步出入库数据，才保存
					storageChangeStoragehouseWorkTaskService.addStorageChangeStoragehouseTaskDetail(storageChangeStoragehouseWorkTask);
					// 添加主表字段
					StorageChangeStoragehouseTask storageChangeStoragehouseTask = (StorageChangeStoragehouseTask) mapper
							.readValue(storeChangeStoragehouseJson, StorageChangeStoragehouseTask.class);
					storageChangeStoragehouseTask.setCreateDate(date);
					storageChangeStoragehouseTask.setOrgId(orgId);
					storageChangeStoragehouseTask.setPlanType("ChangeWork");
					storageChangeStoragehouseTask.setWorkNo(workNo);
					storageChangeStoragehouseTaskService.updateStorageChangeStoragehouseTask(storageChangeStoragehouseTask);
				}
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败！");
		}
		return modelMap;
	}

	/**
	 * 查看倒仓数据列表
	 * @param workNo
	 * @param orgId
	 * @return
	 */
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/findWorkData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询倒仓数据列表", notes = "查询倒仓申请信息列表")
	@ApiImplicitParams({ @ApiImplicitParam(name = "workNo", value = "倒仓申请单号", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public Map<String, Object> findWorkData(String workNo, Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		if (workNo != null && !"".equals(workNo)) {
			Criteria.andWorkNoEqualTo(workNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			Criteria.andOrgIdEqualTo(orgId);
		}
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		modelMap.put("ChangeStoragehouseTask", list);
		StorageChangeStoragehouseWorkTaskExample detailExamle = new StorageChangeStoragehouseWorkTaskExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseWorkTaskExample.Criteria detailCriteria = detailExamle
				.createCriteria();
		if (workNo != null && !"".equals(workNo)) {
			detailCriteria.andWorkNoEqualTo(workNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			detailCriteria.andOrg_idEqualTo(orgId);
		}
		List<StorageChangeStoragehouseWorkTask> detailList = storageChangeStoragehouseWorkTaskService
				.selectByExample(detailExamle);
		modelMap.put("StorageChangeStoragehouseWorkTask", detailList);
		return modelMap;
	}

//	/**
//	 * 提交数据到省平台审批
//	 * 
//	 * @param businessNo
//	 * @param orgId
//	 * @return
//	 */
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/present", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "提交数据到省平台审批", notes = "提交数据到省平台审批")
	@ApiImplicitParams({ @ApiImplicitParam(name = "businessNo", value = "倒仓申请单号", paramType = "query") })
	public Map<String, Object> present(HttpServletRequest request, String businessNo) {
		String str = "";
		String jso = "";
		String strs = "";
		JsonConfig config = new JsonConfig(); 
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		//主表
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		//子表
		StorageChangeStoragehouseTaskDetailExample detailExamle = new StorageChangeStoragehouseTaskDetailExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample.Criteria detailCriteria = detailExamle
				.createCriteria();
		if (businessNo != null && !"".equals(businessNo)) {
			detailCriteria.andBusinessNoEqualTo(businessNo);
			Criteria.andBusinessNoEqualTo(businessNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			detailCriteria.andOrg_idEqualTo(orgId);
			Criteria.andOrgIdEqualTo(orgId);
		}
		//获取主表数据
		jso = "{\"ChangeStoragehouseTask\":[";
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		for (StorageChangeStoragehouseTask storageChangeStoragehouseTask : list) {
			config.registerJsonValueProcessor(Date.class, new DateJsonValueProcessor("yyyy-MM-dd"));  
			net.sf.json.JSONObject json = net.sf.json.JSONObject.fromObject(storageChangeStoragehouseTask,config);//将java对象转换为json对象
			strs = strs + json.toString();
		}
		jso = jso + strs + "],";
		//获取子表数据
		List<StorageChangeStoragehouseTaskDetail> detailList = storageChangeStoragehouseTaskDetailService.selectByExample(detailExamle);
		jso = jso+"\"StorageChangeStoragehouseTaskDetail\":[";
		for (StorageChangeStoragehouseTaskDetail storageChangeStoragehouseTaskDetail : detailList) {
			config.registerJsonValueProcessor(Date.class, new DateJsonValueProcessor("yyyy-MM-dd"));  
			net.sf.json.JSONObject json = net.sf.json.JSONObject.fromObject(storageChangeStoragehouseTaskDetail,config);//将java对象转换为json对象
			str = str + json.toString() + ",";
		}
		str = str.substring(0, str.length()-1);
		jso = jso + str + "]}";
		try {
		String url = changeUrl+"/business-management/changeStoragehous/save";
		
        String count= HTTPUtils.doPost(url,jso);
        
        if(count.contains("Success") || count.contains("200")){
            modelMap.put("status", "success");
            modelMap.put("msg", "成功！");
        }
	 } catch (Exception e){
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}

//	/**
//	 * 提交数据到省平台审批
//	 * 
//	 * @param businessNo
//	 * @param orgId
//	 * @return
//	 */
	@SuppressWarnings("unlikely-arg-type")
	@RequestMapping(value = "/up", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "提交数据到省平台审批", notes = "提交数据到省平台审批")
	@ApiImplicitParams({ @ApiImplicitParam(name = "businessNo", value = "倒仓申请单号", paramType = "query") })
	public Map<String, Object> up(HttpServletRequest request, String businessNo) {
		String str = "";
		String jso = "";
		String strs = "";
		JsonConfig config = new JsonConfig(); 
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		//主表
		StorageChangeStoragehouseTaskExample example = new StorageChangeStoragehouseTaskExample();
		Criteria Criteria = example.createCriteria();
		//子表
		StorageChangeStoragehouseTaskDetailExample detailExamle = new StorageChangeStoragehouseTaskDetailExample();
		com.chinaitop.depot.storage.model.StorageChangeStoragehouseTaskDetailExample.Criteria detailCriteria = detailExamle
				.createCriteria();
		if (businessNo != null && !"".equals(businessNo)) {
			detailCriteria.andBusinessNoEqualTo(businessNo);
			Criteria.andBusinessNoEqualTo(businessNo);
		}
		if (orgId != null && !"".equals(orgId)) {
			detailCriteria.andOrg_idEqualTo(orgId);
			Criteria.andOrgIdEqualTo(orgId);
		}
		//获取主表数据
		jso = "{\"ChangeStoragehouseTask\":[";
		List<StorageChangeStoragehouseTask> list = storageChangeStoragehouseTaskService.selectByExample(example);
		for (StorageChangeStoragehouseTask storageChangeStoragehouseTask : list) {
			config.registerJsonValueProcessor(Date.class, new DateJsonValueProcessor("yyyy-MM-dd"));  
			net.sf.json.JSONObject json = net.sf.json.JSONObject.fromObject(storageChangeStoragehouseTask,config);//将java对象转换为json对象
			strs = strs + json.toString();
		}
		jso = jso + strs + "],";
		//获取子表数据
		List<StorageChangeStoragehouseTaskDetail> detailList = storageChangeStoragehouseTaskDetailService.selectByExample(detailExamle);
		jso = jso+"\"StorageChangeStoragehouseTaskDetail\":[";
		for (StorageChangeStoragehouseTaskDetail storageChangeStoragehouseTaskDetail : detailList) {
			config.registerJsonValueProcessor(Date.class, new DateJsonValueProcessor("yyyy-MM-dd"));  
			net.sf.json.JSONObject json = net.sf.json.JSONObject.fromObject(storageChangeStoragehouseTaskDetail,config);//将java对象转换为json对象
			str = str + json.toString() + ",";
		}
		str = str.substring(0, str.length()-1);
		jso = jso + str + "]}";
		try {
		String url = changeUrl+"/business-management/changeStoragehous/save";
		
        String count= HTTPUtils.doPost(url,jso);
        
        if(count.contains("Success") || count.contains("200")){
            modelMap.put("status", "success");
            modelMap.put("msg", "成功！");
        }
	 } catch (Exception e){
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}
}
