package com.chinaitop.depot.storage.controller;


import com.chinaitop.depot.storage.model.StorageDailycheck;
import com.chinaitop.depot.storage.model.StorageDailycheckExample;
import com.chinaitop.depot.storage.service.StorageDailyService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 2020/7/1
 */
@RestController
@RequestMapping(value = {"/daily"})
@Api(value= "StorageDailyController", description = "日常检查")
public class StorageDailyController {

    @Resource
    private StorageDailyService storageDailyService;

    /**
     * 查询日常检查
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param warehouseId
     * @return
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="日常检查", notes = "日常检查")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query")
    })
    public PageInfo<StorageDailycheck> listPage(Integer pageNum, Integer pageSize , Integer houseId, Integer warehouseId, String createTime) {

        StorageDailycheckExample example = new StorageDailycheckExample();
        StorageDailycheckExample.Criteria criteria = example.createCriteria();

        /* 仓房id */
        if (null != houseId) {
            criteria.andHouseIdEqualTo(houseId);
        }
        /* 货位id */
        if (null != warehouseId) {
            criteria.andWarehouseIdEqualTo(warehouseId);
        }
        if (null != createTime) {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andCheckTimeLessThanOrEqualTo(date);
        }

        //查询FlagType为null的，要不然和粮情卡冲突
        criteria.andFlagTypeIsNull();

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        example.setOrderByClause("check_time desc");

        List<StorageDailycheck> list = storageDailyService.findStorageDailycheck(example);
        PageInfo<StorageDailycheck> pageInfo = new PageInfo<StorageDailycheck>(list);
        return pageInfo;
    }


    /**
     * 添加
     * @param dailycheckJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dailycheckJson", value = "日常检查的Json数据", paramType = "form")
    })
    public Map<String, Object> save(String dailycheckJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageDailycheck dailycheck = (StorageDailycheck)mapper.readValue(dailycheckJson, StorageDailycheck.class);
            storageDailyService.save(dailycheck);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * id加载数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载数据", notes = "根据id加载数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public  Map<String, Object> loadDataById(Integer id){
        Map<String, Object> retMap=storageDailyService.loadDataById(id);

        return retMap;
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据", notes = "根据主键id移除数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        if (null != id) {
            storageDailyService.remove(id);
            retMap.put("msg","success");
        } else {
            retMap.put("msg","error");
        }
        return retMap;
    }
}