package com.chinaitop.depot.storage.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageDump;
import com.chinaitop.depot.storage.model.StorageDumpExample;
import com.chinaitop.depot.storage.model.StorageDumpExample.Criteria;
import com.chinaitop.depot.storage.service.StorageDumpService;
import com.chinaitop.depot.storage.utils.ParameterMapUtil;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.storage.utils.createKC;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/StorageDumpController")
@Api(value= "StorageDumpController", description = "转储管理控制类")
public class StorageDumpController {

	@Resource
	private StorageDumpService storageDumpService;
	
	// 获取ip地址
    @Value("${crk-webservice}")
    private String url;
    
	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询转储管理列表", notes = "查询转储管理信息列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
			@ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query"),
			@ApiImplicitParam(name = "ylsxz", value = "原粮食性质", paramType = "query"),
			@ApiImplicitParam(name = "xlsxz", value = "转储后性质", paramType = "query"),
			@ApiImplicitParam(name = "startTime", value = "业务发生起始时间", paramType = "query"),
			@ApiImplicitParam(name = "endTime", value = "业务发生终止时间", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public PageInfo<StorageDump> getList(Integer pageNum, Integer pageSize,
										Integer houseId, Integer wareId, Integer ylsxz, Integer xlsxz, 
										String startTime, String endTime, Integer orgId) {

		StorageDumpExample example = new StorageDumpExample();
		Criteria criteria = example.createCriteria();

		/* 仓房ID */
		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}

		/* 货位id */
		if (null != wareId) {
			criteria.andWareIdEqualTo(wareId);
		}

		/* 原粮食性质 */
		if (null != ylsxz) {
			criteria.andYLsxzEqualTo(ylsxz);
		}

		/* 变动后粮食性质 */
		if (null != xlsxz) {
			criteria.andXLsxzEqualTo(xlsxz);
		}

		/* 变动后粮食性质 */
		if (null != xlsxz) {
			criteria.andXLsxzEqualTo(xlsxz);
		}

		if (null != startTime && !"".equals(startTime)) {
			Date starDate = ParameterUtil.string2datetime(startTime + " 00:00:00");
			criteria.andBusinessCreateTimeGreaterThanOrEqualTo(starDate);
		}

		if (ParameterUtil.isnotnull(endTime)) {
			Date endDate = ParameterUtil.string2datetime(endTime + " 23:59:59");
			criteria.andBusinessCreateTimeLessThanOrEqualTo(endDate);
		}

		/* 单位 */
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		List<StorageDump> list = storageDumpService.findCondition(example);

		PageInfo<StorageDump> pageInfo = new PageInfo<StorageDump>(list);

		return pageInfo;
	}

	@RequestMapping(value = "/edit",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询转储数据详情", notes = "查询转储数据详情")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "数据ID", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public StorageDump edit(Integer id, Integer orgId) {

		StorageDump dump = null;

		if (0 != id) {
			dump = storageDumpService.findByParmaryKey(id);
		} else {
			dump = new StorageDump();
			dump.setBusinessCreateTime(new Date());
		}

		return dump;
	}

	@RequestMapping(value = "/selectYswData",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询验收完的数据", notes = "查询验收完的数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
	public PageInfo<Map<String, Object>> selectYswData(HttpServletRequest request, Integer pageNum, Integer pageSize) {

		List<Map<String, Object>> list = null;
		PageInfo<Map<String, Object>> pageInfo = null;

		Integer orgId = (Integer) request.getSession().getAttribute("orgId");

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		try {
			list = storageDumpService.selectYswData(orgId);
			pageInfo = new PageInfo<Map<String, Object>>(list);
			list = pageInfo.getList();
			if (null != list && list.size() > 0) {
				list = ParameterMapUtil.slashCapitals(list);
				pageInfo.setList(list);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}

		return pageInfo;
	}

	@RequestMapping(value = "/save",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
	@ApiOperation(value="保存转储数数据记录", notes = "保存转储数数据记录")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "dumpJson", value = "数据对象串", paramType = "form"),
			@ApiImplicitParam(name = "crk_ip", value = "出入库连接IP", paramType = "form")
	})
	public Map<String, Object> save(String dumpJson, String crk_ip) {

		Map<String, Object> modelMap = new HashMap<String, Object>();
		String crk_adr = "";

		try {
			/* JSON字符串转对象 */
			ObjectMapper mapper = new ObjectMapper();
			List<StorageDump> storageDumpList = mapper.readValue(dumpJson, new TypeReference<List<StorageDump>>(){});
			for (StorageDump storageDump : storageDumpList) {

				/* 先调用出入库接口生成转储的业务的台账信息，生成失败不可保存转储数据***start */
				Object[] parameters = new Object[9];
				parameters[0] = storageDump.getOrgId() + "";
				parameters[1] = storageDump.getLspz() + "";
				//parameters[2] = null;
				parameters[3] = storageDump.getHouseId() + "";
				parameters[4] = storageDump.getWareId() + "";
				parameters[5] = storageDump.getxLsxz() + "";
				parameters[6] = storageDump.getyLsxz() + "";
				parameters[7] = storageDump.getClsl() + "";
				parameters[8] = 1 + ""; //1:新增；2：修改；3：删除
				crk_adr = crk_ip+url;
				String str = createKC.createKC("ChangeGrainAttribute", crk_adr, parameters);
				/* *****end******/
				//只有成功生成库存才可以保存，否则不可以保存
				if ("true".equals(str)) {
					storageDump.setCreateTime(new Date());  //创建时间
					storageDumpService.save(storageDump);
				} else {
					modelMap.put("status", "error");
					modelMap.put("msg", "保存失败，库存同步异常，请联系管理员！");
					return modelMap;
				}
			}

			modelMap.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败，库存同步异常，请联系管理员！");
		}
		return modelMap;
	}

}
