package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.StorageFoodbasicInfoCheck;
import com.chinaitop.depot.storage.model.StorageFoodbasicInfoCheckExample;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoCheckService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/19
 */
@RestController
@RequestMapping(value={"/foodbasicinfocheck"})
@Api(value= "StorageFoodbasicInfoCheckController", description = "粮情专卡中质量检测记录控制类")
public class StorageFoodbasicInfoCheckController {
    @Resource
    private StorageFoodbasicInfoCheckService foodbasicInfoCheckService;

    /**
     * 粮食质量检测记录,分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询粮食质量检测记录列表", notes = "查询粮食质量检测记录列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情卡Id", paramType = "query")
    })
    public PageInfo<StorageFoodbasicInfoCheck> listPage(Integer pageNum, Integer pageSize, Integer houseId, Integer warehouseId, Integer foodbasicinfoId){

        StorageFoodbasicInfoCheckExample foodbasicInfoCheckExample = new StorageFoodbasicInfoCheckExample();
        StorageFoodbasicInfoCheckExample.Criteria criteria = foodbasicInfoCheckExample.createCriteria();
        if(ParameterUtil.isnotnull(houseId)){
            criteria.andHouseIdEqualTo(houseId);
        }
        if(ParameterUtil.isnotnull(warehouseId)){
            criteria.andWarehouseIdEqualTo(warehouseId);
        }
        if(ParameterUtil.isnotnull(foodbasicinfoId)){
            criteria.andFoodbasicinfoIdEqualTo(foodbasicinfoId);
        }

        PageHelper.startPage(pageNum, pageSize);
        List<StorageFoodbasicInfoCheck> list = foodbasicInfoCheckService.queryByFoodbasicInfoCheck(foodbasicInfoCheckExample);

        PageInfo<StorageFoodbasicInfoCheck> pageInfo = new PageInfo<StorageFoodbasicInfoCheck>(list);
        return pageInfo;
    }

    /**
     * 新增粮食质量检测记录,从第三方检查选择数据保存到粮食质量检测记录中
     * @param houseId
     * @param warehouseId
     * @param foodbasicinfoId
     * @param qualitycheckId
     * @return
     */
    @RequestMapping(value="/saveSelectcheck", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="新增粮食质量检测记录(从第三方检查选择数据保存到粮食质量检测记录中)", notes = "新增粮食质量检测记录,从第三方检查选择数据保存到粮食质量检测记录中")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "form"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "form"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情卡Id", paramType = "form"),
            @ApiImplicitParam(name = "qualitycheckId", value = "对应质量管理信息Id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "orgId", paramType = "form")
    })
    public Map<String, Object> save(Integer houseId,Integer warehouseId,Integer foodbasicinfoId, Integer qualitycheckId,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<>();
        StorageFoodbasicInfoCheck foodbasicInfoCheck = new StorageFoodbasicInfoCheck();
        try {
            foodbasicInfoCheck.setHouseId(houseId);
            foodbasicInfoCheck.setWarehouseId(warehouseId);
            foodbasicInfoCheck.setFoodbasicinfoId(foodbasicinfoId);
            foodbasicInfoCheck.setQualitycheckId(qualitycheckId);
            foodbasicInfoCheck.setOrgId(orgId);

            foodbasicInfoCheckService.save(foodbasicInfoCheck);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载粮食质量检测记录", notes = "根据id加载粮食质量检测记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public StorageFoodbasicInfoCheck loadDataById(int id){
        return foodbasicInfoCheckService.loadDataById(id);
    }
}
