package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.StorageFoodbasicinfo;
import com.chinaitop.depot.storage.model.StorageFoodbasicinfoExample;
import com.chinaitop.depot.storage.model.StorageFoodbasicinfoExample.Criteria;
import com.chinaitop.depot.storage.model.StorageQualitycheckSon;
import com.chinaitop.depot.storage.model.vo.StorageQualitycheckVo;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoService;
import com.chinaitop.depot.storage.service.StorageQualitycheckSonService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/26
 */
@RestController
@RequestMapping(value={"/foodbasicinfo"})
@Api(value= "StorageFoodbasicInfoController", description = "粮情专卡控制类")
public class StorageFoodbasicInfoController {
    @Resource
    private StorageFoodbasicInfoService foodbasicInfoService;

    @Resource
    private StorageQualitycheckSonService qualitycheckSonService;

    /**
     * 得到当前仓的粮情专卡
     * @return
     */
    @RequestMapping(value="/getFoodbasicInfoByHouseId",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号查找对应粮情专卡", notes = "根据仓号,货位号查找对应粮情专卡")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query")
    })
    public List<StorageFoodbasicinfo> getFoodbasicInfoByHouseId(Integer houseId, Integer warehouseId){
    	StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        if(houseId != null) {
            foodbasicinfo.setHouseId(houseId);
        }
        if(warehouseId != null) {
            foodbasicinfo.setWarehouseId(warehouseId);
        }
    	List<StorageFoodbasicinfo>  list = foodbasicInfoService.getByHouseIdAndWarehouseId(foodbasicinfo);
       
    	return list;
    }
    /**
     * 新增粮情专卡的数据进行保存
     * @param foodbasicinfoJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="封仓生成粮情专卡", notes = "封仓生成粮情专卡")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "foodbasicinfoJson", value = "粮情专卡基本信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "storageQualitycheckJson", value = "粮情专卡JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "用户标识", paramType = "orgId")
    })
    public Map<String, Object> save(String foodbasicinfoJson,String storageQualitycheckJson,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<>();
        ObjectMapper objectMapper=new ObjectMapper();
        StorageFoodbasicinfo foodbasicInfo = new StorageFoodbasicinfo();
        StorageQualitycheckVo qualitycheckVo = new StorageQualitycheckVo();
        try {
            //①保存储粮信息
            qualitycheckVo = (StorageQualitycheckVo)objectMapper.readValue(storageQualitycheckJson,StorageQualitycheckVo.class);
            foodbasicInfo = (StorageFoodbasicinfo)objectMapper.readValue(foodbasicinfoJson,StorageFoodbasicinfo.class);
            foodbasicInfoService.save(foodbasicInfo,qualitycheckVo,orgId);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }


    /**
     * 得到粮情专卡列表pageinfo
     */
    @RequestMapping(value = "/basicinfoPageInfo",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询粮情专卡列表", notes = "查询粮情专卡列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query")
    })
    public PageInfo<StorageFoodbasicinfo> basicinfoPageInfo(Integer pageNum, Integer pageSize ,
                                                            Integer houseId, Integer warehouseId){
        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        if(houseId != null){
            foodbasicinfo.setHouseId(houseId);
        }
        if(warehouseId != null){
            foodbasicinfo.setWarehouseId(warehouseId);
        }
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        //0:最新数据   1:历史数据
        foodbasicinfo.setHistoryStatus(0);
        List<StorageFoodbasicinfo>  list = foodbasicInfoService.selectByExample(foodbasicinfo);

        PageInfo<StorageFoodbasicinfo> pageInfo = new PageInfo<StorageFoodbasicinfo>(list);
        return pageInfo;

    }


    /**
     * 根据id加载对应数据
     * @param id
     * @return
     * @throws Exception 
     */
    @RequestMapping(value = "/loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载粮情专卡信息", notes = "根据id加载粮情专卡信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public StorageFoodbasicinfo loadDataById(Integer id) throws Exception{
        if(id != null && !"".equals(id)){
        	StorageFoodbasicinfo foodbasicinfo = foodbasicInfoService.loadDataById(id);
            List<StorageFoodbasicinfo>  list = foodbasicInfoService.getByHouseIdAndWarehouseId(foodbasicinfo);
			if (list.size() > 0 && list != null){

                foodbasicinfo = list.get(0);

                List<StorageQualitycheckSon> SqsList =  qualitycheckSonService.getQualitycheckSonByFoodbasicinfoCheck(list.get(0).getId());
                for(StorageQualitycheckSon sqk : SqsList){
                    if(sqk.getNumbering()== 6996 ){
                        foodbasicinfo.setFatIndex(sqk.getSetValue());
                        continue;
                    }
                    if(sqk.getNumbering() == 6995 ){
                        foodbasicinfo.setPeroxideValue(sqk.getSetValue());
                        continue;
                    }
                }
            }
            return foodbasicinfo;
        }else {
            return new StorageFoodbasicinfo();
        }
    }

    /**
     * 查询粮情转卡数据--粮情分析报告专用
     * @return
     */
    @RequestMapping(value="/getGrainSituation", produces = MediaType.APPLICATION_JSON_VALUE, method= RequestMethod.GET)
    @ApiOperation(value="查询一条粮情专卡数据", notes = "查询一条粮情专卡数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name="houseId", value="仓房ID", paramType="query"),
            @ApiImplicitParam(name="wareId", value="货位ID", paramType="query")
    })
    public Map<String, Object> getGrainSituation(Integer houseId, Integer wareId){
        Map<String, Object> map = new HashMap<>();

        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        if(houseId != null){
            foodbasicinfo.setHouseId(houseId);
        }
        if(wareId != null){
            foodbasicinfo.setWarehouseId(wareId);
        }
        foodbasicinfo.setHistoryStatus(0);
        List<StorageFoodbasicinfo> basicInfo = foodbasicInfoService.selectByExample(foodbasicinfo);

        if (null != basicInfo && basicInfo.size() > 0) {
            map.put("houseType", Integer.parseInt(basicInfo.get(0).getHouseType()));
            map.put("subType", basicInfo.get(0).getSubType());
            map.put("recorder", basicInfo.get(0).getRecorder());
        }
        return map;
    }

    @RequestMapping(value = "/setFoodBasicInfoHistoryStatus", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "根据仓房和货位名称更新当前粮情专卡为历史记录", notes = "根据仓房和货位名称更新当前粮情专卡为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "form"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "form")
    })
    public Map<String, Object> setFoodBasicInfoHistoryStatus(Integer houseId, Integer warehouseId) {
        Map<String, Object> modelMap = new HashMap<>();
        if (ParameterUtil.isnotnull(houseId) &&ParameterUtil.isnotnull(warehouseId) ) {
            foodbasicInfoService.setFoodBasicInfoHistoryStatus(houseId,warehouseId);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    @RequestMapping(value = "/findByCondition", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据条件查询粮情专卡数据", notes = "根据条件查询粮情专卡数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "lsnq", value = "粮食年期", paramType = "query"),
            @ApiImplicitParam(name = "lspz", value = "粮食品种", paramType = "query"),
            @ApiImplicitParam(name = "lsxz", value = "粮食性质", paramType = "query")
    })
    public List<StorageFoodbasicinfo> findByCondition(Integer houseId, Integer warehouseId, Integer lsnq, Integer lspz, Integer lsxz) {

    	List<StorageFoodbasicinfo> list = null;

    	StorageFoodbasicinfoExample example = new StorageFoodbasicinfoExample();
    	Criteria criteria = example.createCriteria();

        if (ParameterUtil.isnotnull(houseId)) {
        	criteria.andHouseIdEqualTo(houseId);
        }
        if (ParameterUtil.isnotnull(warehouseId) ) {
        	criteria.andWarehouseIdEqualTo(warehouseId);
        }
        if (ParameterUtil.isnotnull(lsnq)) {
        	criteria.andGrowYearEqualTo(lsnq);
        }
        if (ParameterUtil.isnotnull(lspz) ) {
        	criteria.andSubTypeDetailedEqualTo(lspz);
        }
        if (ParameterUtil.isnotnull(lsxz)) {
        	criteria.andQualityEqualTo(lsxz.toString());
        }

        list = foodbasicInfoService.findByCondition(example);

        return list;
    }

}
