package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.StorageFoodbasicInfoLocation;
import com.chinaitop.depot.storage.model.StorageFoodbasicinfo;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoLocationService;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/20
 */
@RestController
@RequestMapping(value = {"/foodbasicinfolocation"})
@Api(value= "StorageFoodbasicInfoLocationController", description = "粮情专卡中货位变更控制类")
public class StorageFoodbasicInfoLocationController {
    @Resource
    private StorageFoodbasicInfoLocationService foodbasicInfoLocationService;
    @Resource
    private StorageFoodbasicInfoService foodbasicInfoService;
    /**
     * 粮食基本信息货位变更记录分页获取
     * @throws Exception 
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询粮食基本信息货位变更记录列表", notes = "查询粮食基本信息货位变更记录列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情卡Id", paramType = "query")
    })
    public PageInfo<StorageFoodbasicInfoLocation> listPage(Integer pageNum, Integer pageSize, Integer houseId, Integer warehouseId, Integer foodbasicinfoId) throws Exception{

    	StorageFoodbasicInfoLocation location = new StorageFoodbasicInfoLocation();
        if(houseId != null){
            location.setHouseId(houseId);
        }
        if(warehouseId != null){
        	location.setWarehouseId(warehouseId);
        }
        if(foodbasicinfoId != null){
            location.setFoodbasicinfoId(foodbasicinfoId);
        }
        if(pageNum !=null && pageSize != null){
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageFoodbasicInfoLocation> list = foodbasicInfoLocationService.queryByFoodbasicInfoLocation(location);
        PageInfo<StorageFoodbasicInfoLocation> pageInfo = new PageInfo<StorageFoodbasicInfoLocation>(list);
        return pageInfo;
    }

    /**
     * 新增粮食基本信息货位变更记录
     * @param foodinfoLocationJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="新增粮食基本信息货位变更记录", notes = "新增粮食基本信息货位变更记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "foodinfoLocationJson", value = "货位变更记录JSON数据", paramType = "form"),
            @ApiImplicitParam(name = "warehouseCode", value = "新货位编码", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "登陆者Id", paramType = "form"),
    })
    public Map<String, Object> save(String foodinfoLocationJson,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageFoodbasicInfoLocation foodbasicInfoLocation = null;
        try {
            foodbasicInfoLocation = (StorageFoodbasicInfoLocation)mapper.readValue(foodinfoLocationJson, StorageFoodbasicInfoLocation.class);
            foodbasicInfoLocation.setNewWarehouseCode(foodbasicInfoLocation.getWarehouseCode());
            foodbasicInfoLocation.setOrgId(orgId);

            //关联粮情专卡表
            Integer houseId = foodbasicInfoLocation.getHouseId();
            Integer warehouseId = foodbasicInfoLocation.getWarehouseId();

            if(ParameterUtil.isnotnull(houseId) && ParameterUtil.isnotnull(warehouseId)){
                StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();

                if (houseId != null) {
                    foodbasicinfo.setHouseId(houseId);
                }
                if (warehouseId != null) {
                    foodbasicinfo.setWarehouseId(warehouseId);
                }

                List<StorageFoodbasicinfo>  list = foodbasicInfoService.getByHouseIdAndWarehouseId(foodbasicinfo);

                Integer foodbaseInfoId = null;
                if(list.size() > 0 && list != null){
                    foodbasicinfo = list.get(0);
                }
                if(foodbasicinfo != null){
                    foodbaseInfoId = foodbasicinfo.getId();
                }
                if(foodbaseInfoId != null){
                    foodbasicInfoLocation.setFoodbasicinfoId(foodbaseInfoId);
                }

            }
            foodbasicInfoLocationService.save(foodbasicInfoLocation);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载货位变更记录", notes = "根据id加载货位变更记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public StorageFoodbasicInfoLocation loadDataById(Integer id){
        if(id != null && !"".equals(id)){
            return foodbasicInfoLocationService.loadDataById(id);
        }else {
            return new StorageFoodbasicInfoLocation();
        }
    }
}
