package com.chinaitop.depot.storage.controller;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.storage.model.StorageOverheadSet;
import com.chinaitop.depot.storage.model.StorageOverheadSetExample;
import com.chinaitop.depot.storage.model.StorageOverheadSetExample.Criteria;
import com.chinaitop.depot.storage.service.StorageOverheadSetService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/StorageOverheadSetController")
@Api(value= "StorageOverheadSetController", description = "架空期设置控制类")
public class StorageOverheadSetController {

	@Resource
	private StorageOverheadSetService storageOverheadSetService;

	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询架空期设置列表", notes = "查询架空期设置信息列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
	public PageInfo<StorageOverheadSet> getList(Integer pageNum, Integer pageSize, HttpServletRequest request) {

		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"), "");

		StorageOverheadSetExample example = new StorageOverheadSetExample();
		Criteria criteria = example.createCriteria();

		/* 单位 */
		if (null != orgId) {
			criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
		}

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		List<StorageOverheadSet> list = storageOverheadSetService.findConditions(example);

		PageInfo<StorageOverheadSet> pageInfo = new PageInfo<StorageOverheadSet>(list);

		return pageInfo;
	}

	@RequestMapping(value = "/edit",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询架空期设置数据详情", notes = "查询架空期设置数据详情")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
	})
	public StorageOverheadSet edit(Integer id) {

		StorageOverheadSet overheadSet = null;

		if (0 != id) {
			overheadSet = storageOverheadSetService.findByKeyCondition(id);
		} else {
			overheadSet = new StorageOverheadSet();
		}

		return overheadSet;
	}

	@RequestMapping(value = "/save",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
	@ApiOperation(value="保存架空期设置数据记录", notes = "保存架空期设置数数据记录")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "overheadSetJson", value = "数据对象串", paramType = "form")
	})
	public Map<String, Object> save(String overheadSetJson) {

		Map<String, Object> modelMap = new HashMap<String, Object>();

		try {
			/* JSON字符串转对象 */
			ObjectMapper mapper = new ObjectMapper();
			StorageOverheadSet overheadSet = mapper.readValue(overheadSetJson, StorageOverheadSet.class);
			overheadSet.setCreateDate(new Date());  //创建时间
			if(overheadSet.getId() == null) {
				storageOverheadSetService.insert(overheadSet);
			}else {
				storageOverheadSetService.update(overheadSet);
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败！");
		}
		return modelMap;
	}
	@SuppressWarnings({ "null", "unused" })
	@RequestMapping(value = "/findHwxz",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="查询架空期设置数据详情", notes = "查询架空期设置数据详情")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "hwxz", value = "粮食性质", paramType = "query")
	})
	public PageInfo<Map<String, Object>> findHwxz(HttpServletRequest request, String overheadGetJson, Integer pageNum, Integer pageSize) {
		Date date = null;
		long time1 = 0;
        long time2 = 0;
		Date nowDate = new Date();//获取当前时间
		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MM-dd");
		DateFormat format1 = new SimpleDateFormat("yyyy-MM-dd");
		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
		DateFormat sdf2 = new SimpleDateFormat("yyyy-MM-dd");
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"), "");
		Map<String, Object> map = new HashMap<String, Object>();
		List<Map<String, Object>> lastList = new ArrayList<Map<String, Object>>();
		List<Map<String, Object>> countList = new ArrayList<Map<String, Object>>();
		JSONObject jsonObject = JSONObject.parseObject(overheadGetJson);
		JSONArray array = jsonObject.getJSONArray("list");
		for(int i = 0; i < array.size(); i++){
			JSONObject object = (JSONObject) array.get(i);     //将array中的数据进行逐条转换
			map.put("orgId", orgId);
			map.put("lsxz", object.get("hwxz"));
			map.put("ch", object.getString("ch"));
			map.put("hwh", object.getString("hwh"));
			map.put("executeType", 3156);
	    	List<Map<String, Object>> list = storageOverheadSetService.getOverYqDaysList(map);
	    	if(!list.equals("" ) && !list.isEmpty()) {
        	for (Map<String, Object> lastMap : list) {
        		Integer warningDay = 0;
        		int bw = 4;  //初始化为正常
        		String sqyqtime = null;
        		Integer isUpload = 0;
					try {
						date = format1.parse((String) object.get("jkqEnd"));
						cal.setTime(date);
					} catch (ParseException e) {
						e.printStackTrace();
					}
        		for (Map.Entry<String, Object> lastEntry : lastMap.entrySet()) {
					if (lastEntry.getKey().equals("sqyq_time")) {
						sqyqtime = sdf2.format(lastEntry.getValue());
						break;
					}
				}
        		for (Map.Entry<String, Object> lastEntry : lastMap.entrySet()) {
					if (lastEntry.getKey().equals("is_Upload")) {
						isUpload = (Integer) lastEntry.getValue();
						break;
					}
				}
	    		for (Map.Entry<String, Object> lastEntry : lastMap.entrySet()) {
					if (lastEntry.getKey().equals("overhead_period")) {
						Integer overheadPeriod =(Integer) lastEntry.getValue();
						cal.add(Calendar.MONTH, overheadPeriod);
						break;
					}
				}
						Double zcsl = Double.parseDouble(object.get("zcsl").toString());
						Double srsl = Double.parseDouble(object.get("srsl").toString());
        		for (Map.Entry<String, Object> lastEntry : lastMap.entrySet()) {
					if (lastEntry.getKey().equals("warning_day")) {
						warningDay =(Integer) lastEntry.getValue();
						break;
					}
				}
        		try { 
            		String dateString = format.format(nowDate);
                	String timea= format.format(cal.getTime());
    				cal.setTime(sdf.parse(dateString));
    				time1 = cal.getTimeInMillis();
    		        cal.setTime(sdf.parse(timea));
    		        time2 = cal.getTimeInMillis();
    		        long between_days=(time2-time1)/(1000*3600*24);
    		        Integer rengTime = Integer.parseInt(String.valueOf(between_days));
	        		date = format1.parse((String) object.get("jkqEnd"));
	        		object.replace("jkqEnd", timea);
	        		object.put("bw", bw);
	        		if(srsl < zcsl) {
	        			object.put("srsl", 0);
	        			object.remove("rq");
	        			if(rengTime < 1) {
	        				bw = 2;
	        				object.put("bw", bw);
	        			}else if(sqyqtime != null){
	        					 long sqyq_days=(time2-time1)/(1000*3600*24);
	        	    		       Integer sqTime = Integer.parseInt(String.valueOf(sqyq_days));
	        					if(sqTime < warningDay ) {
	        						if(isUpload == 2) {
	        						bw = 3;
	        						object.put("bw", bw);
	        						object.put("sqyqTime", sqyqtime);
	        						}else if(rengTime < warningDay) {
	    	        					bw = 1;
	    	        					object.put("bw", bw);
	    	        				}else{
	    	        					bw = 0;
	    	            				object.put("bw", bw);
	    	        				}
	        					}else {
	        						bw = 0;
		        					object.put("bw", bw);
	        					}
	        			}else if(rengTime < warningDay) {
	        					bw = 1;
	        					object.put("bw", bw);
	        				}else{
	        					bw = 0;
	            				object.put("bw", bw);
	        				}
	        			}

	        		if(srsl >= zcsl) {
	            		Integer planSp = Integer.parseInt((String) object.get("planSp")) ;
	        			if(isUpload == 2) {
	        				object.put("sqyqTime", sqyqtime);
	        			}
	        			if(planSp != 100) {
	        				object.put("srsl", 0);
		        			object.remove("rq");
		        			bw = 5;
		        			object.put("bw", bw);
	        			} 
	        		}
    			} catch (ParseException e) {
    				// TODO Auto-generated catch block
    				e.printStackTrace();
    			}
			}
        	countList.add(object);
	    	}
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(countList);
		pageInfo.setPageNum(pageNum);
		pageInfo.setPageSize(pageSize); 
        //由于结果是>startRow的，所以实际的需要+1
        if (pageInfo.getSize() == 0) {
        	pageInfo.setStartRow(0);
        	pageInfo.setEndRow(0);
        } else {
        	pageInfo.setStartRow(pageInfo.getStartRow() + 1);
            //计算实际的endRow（最后一页的时候特殊）
        	pageInfo.setEndRow(pageInfo.getStartRow() - 1 +pageInfo.getSize());
        }
		return pageInfo;
	}
}
