package com.chinaitop.depot.storage.controller;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageQualityEvent;
import com.chinaitop.depot.storage.model.StorageQualityEventExample;
import com.chinaitop.depot.storage.model.StorageQualityEventExample.Criteria;
import com.chinaitop.depot.storage.service.StorageQualityEventService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/qualityEvent")
@Api(value= "StorageQualityEventController", description = "质量事件控制类")
public class StorageQualityEventController {

	@Resource
	private StorageQualityEventService eventService;

	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量事件列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位Id", paramType = "query")
    })
	public PageInfo<StorageQualityEvent> getList(Integer pageNum, Integer pageSize, Integer houseId,
			Integer wareId, Integer orgId, String createTime) {

		List<StorageQualityEvent> list = null;
		PageInfo<StorageQualityEvent> pageInfo = null;

		StorageQualityEventExample example = new StorageQualityEventExample();
		Criteria criteria = example.createCriteria();
		
		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}
		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}
		if (null != wareId) {
			criteria.andWareIdEqualTo(wareId);
		}
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}
		if (null != createTime) {
			SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			Date date = null;
			try {
				date = dateFormat.parse(createTime);
			} catch (ParseException e) {
				e.printStackTrace();
			}
			criteria.andInputDateLessThanOrEqualTo(date);
		}

		list = eventService.findByCondition(example);
		String czwt = "";
		for (StorageQualityEvent event : list) {
			czwt = event.getCzwt();
			if (czwt.length() > 10) {
				event.setCzwt(czwt.substring(0, 10)+"......");
			}
		}
		pageInfo = new PageInfo<StorageQualityEvent>(list);

		return pageInfo;
	}

	@RequestMapping(value = "/findByIdObj",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="按ID查询一条安全事件数据(包含附件信息)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键Id", paramType = "query")
    })
	public Map<String, Object> findByIdObj(Integer id) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 查询质量事件主表数据  */
		StorageQualityEvent qualityEvent = eventService.findByPrimaryKey(id);
		if (null == qualityEvent) {
			qualityEvent = new StorageQualityEvent();
			qualityEvent.setInputDate(new Date());
		}
		map.put("qualityEvent", qualityEvent);

		return map;
	}

	@RequestMapping(value = "/update",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新质量事件信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "event", value = "质量事件数据", paramType = "form")
    })
	public Map<String, Object> update(String event) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 插入质量事件主表数据  */
		ObjectMapper objectMapper = new ObjectMapper();
		try {
			StorageQualityEvent qualityEvent = objectMapper.readValue(event, StorageQualityEvent.class);

			if (qualityEvent.getId() == null) {
				eventService.save(qualityEvent);
			} else {
				eventService.update(qualityEvent);
			}
			map.put("status", "success");
			map.put("id", qualityEvent.getId());
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}
}
