package com.chinaitop.depot.storage.controller;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.chinaitop.depot.storage.model.StorageFoodbasicinfo;
import com.chinaitop.depot.storage.model.StorageQualitycheck;
import com.chinaitop.depot.storage.model.StorageQualitycheckExample;
import com.chinaitop.depot.storage.model.StorageQualitycheckInspectionExample;
import com.chinaitop.depot.storage.model.StorageQualitycheckExample.Criteria;
import com.chinaitop.depot.storage.model.StorageQualitycheckSonExample;
import com.chinaitop.depot.storage.model.StorageQualitystandardMainExample;
import com.chinaitop.depot.storage.service.StorageQualitycheckService;
import com.chinaitop.depot.storage.service.StorageQualitycheckSonService;
import com.chinaitop.depot.storage.utils.DataSynchronization;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.utils.HttpUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * Created by product on 2017/10/11.
 */
@RestController
@RequestMapping(value = {"/qualitycheck"})
@Api(value= "StorageQualitycheckController", description = "质量管理控制类")
public class StorageQualitycheckController {
    @Resource
    private StorageQualitycheckService storageQualitycheckService;

    @Resource
    private StorageQualitycheckSonService qualitycheckSonService;
    // 获取ip地址
    @Value("${reportForSPT-Url}")
    private String reportPath;
    /**
     * 封仓管理中查询出未封 仓的质量管理信息，已经封仓的不要展示
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "qualitycheck", value = "实体类", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query"),
            @ApiImplicitParam(name = "depotType", value = "判断是否是代储", paramType = "query"),
    })
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize, StorageQualitycheck qualitycheck,
                                                  String checktype,String checkResult,String depotType,String createTime,
                                                  Integer processState) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();

        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            String[] idArray = checktype.split(",");
            List<Integer> idList = new ArrayList<Integer>();
            for (String id : idArray) {
                idList.add(Integer.parseInt(id));
            }
            qualityCheck.setTypeList(idList);
        }

        // 仓房id.
        if (qualitycheck.getHouseId() != null) {
            qualityCheck.setHouseId(qualitycheck.getHouseId());

        }
        // 货位id.
        if (qualitycheck.getWarehouseId() != null) {
            qualityCheck.setWarehouseId(qualitycheck.getWarehouseId());
        }
        // 粮库id.
        if (qualitycheck.getOrgId() != null) {
            qualityCheck.setOrgId(qualitycheck.getOrgId());
        }
        
        // 明细品种.
        if (qualitycheck.getSubTypeDetailed() != null) {
            qualityCheck.setSubTypeDetailed(qualitycheck.getSubTypeDetailed());
        }
        
        // 等级.
        if (qualitycheck.getLevelUpdate() != null) {
            qualityCheck.setLevelUpdate(qualitycheck.getLevelUpdate());
        }

        //检验结果（0：合格 , 1 :不合格）

        if (StringUtils.isNotBlank(checkResult)) {
            qualityCheck.setCheckResult(checkResult);
        }

        //如果是1则说明是代储点的，则另外查询
        if(ParameterUtil.isequal("1",depotType)){
            qualityCheck.setDepotId(Integer.parseInt(depotType));
        }

        if(processState != null){
        	qualityCheck.setProcessState(processState);
        }
        //归档用时间查询
        if(ParameterUtil.isnotnull(createTime)){
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            qualityCheck.setSealDate(date);
        }

        if(qualitycheck.getHistoryStatus() != null){
        	if(qualitycheck.getHistoryStatus().equals(1)){
        		qualityCheck.setHistoryStatus(1);//0:最新数据  1:历史数据
        	}else if(qualitycheck.getHistoryStatus().equals(0)){
            	qualityCheck.setHistoryStatus(0);
        	}
        }else{
        	qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        }
       
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        //qualityCheck.setSealStatus("0");
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }
    
    /**
     * 获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位).
     * @param qualitycheck
     * @return
     */
    @RequestMapping(value = "/getHouseOrWareList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)", notes = "获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheck", value = "质量管理对象", paramType = "query")
    })
    public List<StorageQualitycheck> getHouseIdList(StorageQualitycheck qualitycheck) {
        List<StorageQualitycheck> list = storageQualitycheckService.getHouseOrWareList(qualitycheck);
        return list;
    }
    
    /**
     * 获取第三方检验的质量标准字符串(手动拼写)
     * @param id
     * @return
     */
    @RequestMapping(value = "/getQualityStandardStr",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取第三方检验的质量标准字符串(手动拼写)", notes = "获取第三方检验的质量标准字符串(手动拼写)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "form"),
    })
    public Map<String, Object> getQualityStandardStr(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id == null) {
            modelMap.put("status", "error");
            modelMap.put("msg", "id为空，查询质量标准失败！");
        } else {
            String qualityStandardStr = storageQualitycheckService.getQualityStandardStr(id);
            modelMap.put("status", "success");
            modelMap.put("qualityStandard", qualityStandardStr);
        }

        return modelMap;
    }

    /**
     * 新增和修改的数据进行保存
     * @param qualitycheckJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheckJson", value = "质量基础信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "qualitycheckInspectionJson", value = "质检JSON数据对象", paramType = "form")
    })
    public Map<String, Object> save(String qualitycheckJson,String qualitycheckInspectionJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageQualitycheck qualitycheck = (StorageQualitycheck)mapper.readValue(qualitycheckJson, StorageQualitycheck.class);
            storageQualitycheckService.save(qualitycheck,qualitycheckInspectionJson);
            try {
                Integer idw = storageQualitycheckService.findId();
                //自检或出库 保存或修改数据 把数据推给市平台
                Map<String, Object> dataMap = storageQualitycheckService.getcheckByIds(qualitycheck.getId());
                if(dataMap==null){
                     dataMap = storageQualitycheckService.getcheckByIds(idw);
                }
                String url = reportPath+"/zjbg/receiveData";//市级接口
                String strResult = HttpUtil.doPost(url, JSON.toJSONString(dataMap));
            }catch (IOException e) {
                e.printStackTrace();
            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                modelMap.put("status", "success");
            }
            modelMap.put("dataid", qualitycheck.getId());
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载质量检查数据", notes = "根据id加载质量检查数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public  Map<String, Object> loadDataById(Integer id){
        Map<String, Object> retMap=storageQualitycheckService.loadDataById(id);

        return retMap;
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按ID删除质量检查信息", notes = "按ID删除质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        storageQualitycheckService.remove(id);

        //删除管理的数据
        StorageQualitycheckSonExample qualitycheckSonExample = new StorageQualitycheckSonExample();
        StorageQualitycheckSonExample.Criteria criteria = qualitycheckSonExample.createCriteria();
        if(id != null){
            criteria.andQualitycheckIdEqualTo(id);
        }
        qualitycheckSonService.removeSon(qualitycheckSonExample);
        retMap.put("msg","success");
        return retMap;
    }

    /**
     * 封仓管理中查询出所有仓已经封仓或者未封仓的质量管理信息
     * @param houseId
     * @param warehouseId
     * @return
     */
    @RequestMapping(value="/getFoodsealList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="封仓管理列表中查询出封仓或未封仓的质量管理信息", notes = "封仓管理列表中查询出封仓或未封仓的质量管理信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize ,
                                                  String houseId, String warehouseId) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
        if(StringUtils.isNoneBlank(houseId)){
            qualityCheck.setHouseId(Integer.valueOf(houseId));

        }
        if(StringUtils.isNoneBlank(warehouseId)){
            qualityCheck.setWarehouseId(Integer.valueOf(warehouseId));
        }
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        List<Integer> idList = new ArrayList<Integer>();
        idList.add(1);
        qualityCheck.setTypeList(idList);

        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 根据仓号,货位号以及类型查找对应质量检查信息
     * @param houseId warehouseId
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应质量检查信息", notes = "根据仓号,货位号以及类型查找对应质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "sealStatus", value = "封仓类型", paramType = "query")
    })
    public StorageQualitycheck findByStoreWarehouse(Integer houseId, Integer warehouseId, String type,String sealStatus) {
    	StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageQualitycheck qualitycheck = null;
        try {
            if (houseId != null && !"".equals(houseId)) {
                qualityCheckExample.setHouseId(houseId);

            }
            if(warehouseId != null && !"".equals(warehouseId)){
                qualityCheckExample.setWarehouseId(warehouseId);
            }
            if(StringUtils.isNotBlank(type)){
            	//根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
                String[] idArray = type.split(",");
                List<Integer> idList = new ArrayList<Integer>();
                for (String id : idArray) {
                    idList.add(Integer.parseInt(id));
                }
                qualityCheckExample.setTypeList(idList);
            }

            if(StringUtils.isNotBlank(sealStatus)){
                qualityCheckExample.setSealStatus(sealStatus);//传入查找的质量类型
            }
            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheckExample);
            if (null != list && list.size() > 0) {
            	qualitycheck = list.get(0);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return qualitycheck;
    }

    /**
     * 根据仓号,货位号以及类型查找对应封仓信息
     * @param houseId warehouseId
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouseData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应信息", notes = "根据仓号,货位号以及类型查找对应信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "检查id", paramType = "query")
    })
    public StorageFoodbasicinfo findByStoreWarehouseData(Integer houseId, Integer warehouseId, String type , Integer id) {
        StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        try {
            if (houseId != null && !"".equals(houseId)) {
                qualityCheckExample.setHouseId(houseId);
            }
            if(warehouseId != null && !"".equals(warehouseId)){
                qualityCheckExample.setWarehouseId(warehouseId);
            }
            if(StringUtils.isNotBlank(type)){
                qualityCheckExample.setTypeUpdate(type);//传入查找的质量类型
            }

            if (id != null && !"".equals(id)) {
                qualityCheckExample.setId(id);
            }

            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
            qualityCheckExample.setSealStatus("0");

            //查看business_store_ware_detail中价格是否有
            List<StorageQualitycheck> businessList = storageQualitycheckService.queryByQualitycheckusiness(qualityCheckExample);
            if(null != businessList && businessList.size() > 0){
                qualityCheckExample.setNotice(1);
            }

            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheckData(qualityCheckExample);
            if (null != list && list.size() > 0) {
                foodbasicinfo.setHeight(list.get(0).getHeight());
                foodbasicinfo.setDisperseCapacity(list.get(0).getDisperseCapacity());
                foodbasicinfo.setKeepMethod(list.get(0).getKeepMethod());
                foodbasicinfo.setPrice(list.get(0).getPrice());
                foodbasicinfo.setStorageLocation(list.get(0).getDepotName());
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return foodbasicinfo;
    }

    /**
     * 查询第三方检查
     * @param  foodbasicinfoId
     * @return getThirdCheckList
     */
    @RequestMapping(value="/getThirdCheckList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询获得第三方检查列表", notes = "查询获得第三方检查列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public PageInfo<StorageQualitycheck> getThirdCheckList(Integer pageNum, Integer pageSize , Integer houseId, Integer warehouseId,
                                                           Integer foodbasicinfoId) {
        StorageQualitycheck qualityCheck = new StorageQualitycheck();

        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }
        if(houseId != null){
            qualityCheck.setHouseId(houseId);
        }
        if(warehouseId != null){
            qualityCheck.setWarehouseId(warehouseId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.getThirdCheckList(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录(该记录包含当前仓房的验收信息和选择的第三方检验信息)
     * @param houseId
     * @param warehouseId
     * @param foodbasicinfoId
     * @return
     */
    @RequestMapping(value = "/getQualitycheckListByFoodbasicinfoCheck",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录", notes = "该记录包含当前仓房的验收信息和选择的第三方检验信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public List<StorageQualitycheck> getQualitycheckListByFoodbasicinfoCheck(Integer houseId, Integer warehouseId, Integer foodbasicinfoId){
        StorageQualitycheck qualityCheck = new StorageQualitycheck();
        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }
        if(houseId != null){
            qualityCheck.setHouseId(houseId);
        }
        if(warehouseId != null){
            qualityCheck.setWarehouseId(warehouseId);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.getQualitycheckListByFoodbasicinfoCheck(qualityCheck,foodbasicinfoId);

        return list;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    
    @RequestMapping(value = "/getStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据", notes = "获取第三方检查的不宜存的可用数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "粮库id", paramType = "query")

    })
    public List<Map<String,Object>> getStoreQualityList(Integer orgId){
        List<Map<String,Object>> listQuality=storageQualitycheckService.getStoreQualityList(orgId);
        return listQuality;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    @RequestMapping(value = "/getTrdStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据(集合格式)", notes = "获取第三方检查的不宜存的可用数据(集合格式)")
    public List<Map<String,Object>> getTrdStoreQualityList(){
    	List<Map<String,Object>> listQuality=storageQualitycheckService.getTrdStoreQualityList();    
        return listQuality;
    }
    
    
    @RequestMapping(value = "/setQualityCheckByHistoryStatus", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "根据仓房和货位名称更新当前质量管理为历史记录", notes = "根据仓房和货位名称更新当前质量管理为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
    })
    public Map<String, Object> setQualityCheckByHistoryStatus(Integer houseId, Integer warehouseId) {
        Map<String, Object> modelMap = new HashMap<>();
        if (ParameterUtil.isnotnull(houseId) &&ParameterUtil.isnotnull(warehouseId) ) {
            storageQualitycheckService.setQualityCheckByHistoryStatus(houseId,warehouseId);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 根据id查询质检信息
     * @param ZZid
     * @return
     */
    @RequestMapping(value="/getDataByZJId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value = "根据id查询质检信息", notes = "根据id查询质检信息,计划验收模块用到。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ZZid", value = "质检id", paramType = "query")
    })
    public Map<String,Object> getDataByZJId(Integer id ,Integer ZZid) {
        Map<String,Object> map = new HashMap<String, Object>();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        paramMap.put("ZZid", ZZid);
        paramMap.put("id", id);
        List<StorageQualitycheck> list = storageQualitycheckService.getDataByZJId(paramMap);
        map.put("qualitycheck", list);
        return map;
    }
    
    
    
    /**
     * 根据仓房和货位获取第三方检查的数据
     * 分页获取
     */
    @RequestMapping(value = "/getListByhouseId",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据仓房和货位获取第三方检查的数据", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseIds", value = "仓房id(数组)", paramType = "query"),
            @ApiImplicitParam(name = "warehouseIds", value = "货位id(数组)", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> getListByhouseId(Integer pageNum, Integer pageSize,
            Integer[] houseIds, Integer[] warehouseIds , String checktype) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
    	List<List<StorageQualitycheck>> list = new ArrayList<List<StorageQualitycheck>>();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
    	if (StringUtils.isNotBlank(checktype)){
            String[] idArray = checktype.split(",");
            List<Integer> idList = new ArrayList<Integer>();
            for (String id : idArray) {
                idList.add(Integer.parseInt(id));
            }
            qualityCheck.setTypeList(idList);
        }

        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        qualityCheck.setSealStatus("0");
        
        List<StorageQualitycheck> qualityCheckList =null;
        for (int i = 0; i < houseIds.length; i++) {
        	for (int j = 0; j < warehouseIds.length; j++) {
            	if(i==j){
            		Integer houseId = houseIds[i];
            		Integer warehouseId = warehouseIds[j];
            		 	//仓房id.
            	        if (qualityCheck.getHouseId() == null) {
            	            qualityCheck.setHouseId(houseId);

            	        }
            	        // 货位id.
            	        if (qualityCheck.getWarehouseId() == null) {
            	            qualityCheck.setWarehouseId(warehouseId);
            	        }
            	        if (pageNum!=null && pageSize!=null) {
            	            PageHelper.startPage(pageNum, pageSize);
            	        }
            	        
            	        qualityCheckList = storageQualitycheckService.queryByQualitycheck(qualityCheck);
            	}
    		}
		}
        
       
       
        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(qualityCheckList);
        return pageInfo;
    }

    @RequestMapping(value = "/getNewList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query"),
            @ApiImplicitParam(name = "historyStatus", value = "数据状态", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> newListPage(Integer pageNum, Integer pageSize, Integer houseId, Integer wareId,
                                                  String checkType, String checkResult, Integer historyStatus, Integer orgId) {
    	StorageQualitycheckExample example = new StorageQualitycheckExample();
    	Criteria criteria = example.createCriteria();

        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checkType)){
        	//criteria.andTypeEqualTo(checkType);
        	criteria.andCheckTypeEqualTo(checkType);
        }
        // 仓房id.
        if (houseId != null) {
        	criteria.andHouseIdEqualTo(houseId);
        }
        // 货位id.
        if (wareId != null) {
        	criteria.andWarehouseIdEqualTo(wareId);
        }
        // 粮库id.
        if (orgId != null) {
        	criteria.andOrgIdEqualTo(orgId);
        }

        //检验结果（0：合格 , 1 :不合格）
        if (StringUtils.isNotBlank(checkResult)) {
        	criteria.andCheckResultEqualTo(checkResult);
        }
        //数据状态
        if (null != historyStatus) {
        	//0:最新数据  1:历史数据
        	criteria.andHistoryStatusEqualTo(historyStatus);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.findByCondition(example);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    @RequestMapping(value="/getHouseIdAll", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取全部仓房", notes = "获取全部仓房")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "数据ID", paramType = "query")
    })
    public JSONArray getHouseIdAll(Integer orgId) {

        JSONArray list = null;
        try {
            list = storageQualitycheckService.getHouseIdAll(orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return list;
    }

    //质检信息主表同步
    @RequestMapping("/qualityMainSynchronization")
    public void qualityMainSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityMain(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQualityMain(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQualityMain(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //质检信息明细同步
    @RequestMapping("/qualityInfoSynchronization")
    public void qualityInfoSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityInfo(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQuality(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQuality(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //粮食库存同步
    @RequestMapping("/foodStocksSynchronization")
    public void foodStocksSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> foodStocksList = storageQualitycheckService.getAllFoodStocks(paramMap);
        for(Map foodStocksMap:foodStocksList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String fcid = ObjectUtils.toString(map.get("fcid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(fcid.equals(ObjectUtils.toString(foodStocksMap.get("fcid"),""))) {
                    if(!refreshTime.equals(format.format(foodStocksMap.get("updatetime")))) {
                        DataSynchronization.updateFoodStocks(map, foodStocksMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertFoodStocks(foodStocksMap);
                }else {
                    num = num+1;
                }
            }
        }
    }
    
    
    @RequestMapping(value="/updateDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="化验删除数据", notes = "修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheckJson", value = "质量基础信息JSON数据对象", paramType = "form")
    })
    public Map<String, Object> updateDate(String qualitycheckJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageQualitycheck qualitycheck = (StorageQualitycheck)mapper.readValue(qualitycheckJson, StorageQualitycheck.class);
            
            StorageQualitycheck qk = new StorageQualitycheck();
            qk.setOrgId(qualitycheck.getOrgId());
            qk.setHouseId(qualitycheck.getHouseId());
            qk.setWarehouseId(qualitycheck.getWarehouseId());
            qk.setSubType(qualitycheck.getSubType());
            qk.setSubTypeDetailed(qualitycheck.getSubTypeDetailed());
            qk.setNumberUpdate(qualitycheck.getNumberUpdate());
            qk.setLocation(qualitycheck.getLocation());
            qk.setHarvestTime(qualitycheck.getHarvestTime());
            qk.setInputTime(qualitycheck.getInputTime());
            qk.setZhycsj(qualitycheck.getZhycsj());
            qk.setKeeper(qualitycheck.getKeeper());
            qk.setChooseTime(qualitycheck.getChooseTime());
            qk.setChooser(qualitycheck.getChooser());
            qk.setQyqy(qualitycheck.getQyqy());
            qk.setQydbh(qualitycheck.getQydbh());
            qk.setYpbh(qualitycheck.getYpbh());
            qk.setYpsl(qualitycheck.getYpsl());
            qk.setDbsl(qualitycheck.getDbsl());
            qk.setTypeUpdate(qualitycheck.getTypeUpdate());
            qk.setQuality(qualitycheck.getQuality());
            qk.setCheckResult(qualitycheck.getCheckResult());
            qk.setStoreQuality(qualitycheck.getStoreQuality());
            qk.setInspectionStandardBasis(qualitycheck.getInspectionStandardBasis());
            qk.setProcessState(1);
            String qualitycheckInspectionJson = "";
            storageQualitycheckService.save(qk,qualitycheckInspectionJson);
            /**
             * 
             * 删除 之前推给市平台的数据 todo
             * 
             * 
             */
            storageQualitycheckService.remove(qualitycheck.getId());
            StorageQualitycheckInspectionExample example = new StorageQualitycheckInspectionExample();
            StorageQualitycheckInspectionExample.Criteria criteria = example.createCriteria();
            criteria.andQualitycheckIdEqualTo(qualitycheck.getId());
            int i = storageQualitycheckService.deleteStorageQualitycheckInspection(example);
            if(i>0){
            	 modelMap.put("msg", "success");
            }
        } catch (IOException e) {
            modelMap.put("msg", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
    

}