package com.chinaitop.depot.storage.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageQualitystandardMain;
import com.chinaitop.depot.storage.service.StorageQualitystandardMainService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="StorageQualitystandardMainController")
@Api(value= "StorageQualitystandardMainController", description = "质量标准配置控制类")
public class StorageQualitystandardMainController {

	@Autowired
	private StorageQualitystandardMainService storageQualitystandardMainService;

	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="质量标准配置数据列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "lspz", value = "粮食品种ID", paramType = "query")
    })
	public PageInfo<StorageQualitystandardMain> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer lspz) {
		PageInfo<StorageQualitystandardMain> pageInfo = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			List<StorageQualitystandardMain> list = storageQualitystandardMainService.getList(request, lspz);
			pageInfo = new PageInfo<StorageQualitystandardMain>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}

	@RequestMapping(value = "/findByIdObj",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询一条质量标准配置数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
    })
	public Map<String, Object> findByIdObj(String id) {
		Map<String, Object> map = new HashMap<String, Object>();

		try {
			map = storageQualitystandardMainService.findByIdObj(id);
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}

	@RequestMapping(value = "/initObj",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="初始化品种化验项数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "lspz", value = "粮油品种", paramType = "query")
    })
	public Map<String, Object> initObj(Integer lspz) {
		Map<String, Object> map = null;
		try {
			map = storageQualitystandardMainService.initObj(lspz);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return map;
	}

	@RequestMapping(value = "/saveOrUpdate",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="保存或更新一条质量标准配置数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "obj_main", value = "主表数据", paramType = "form"),
        @ApiImplicitParam(name = "obj", value = "子表数据", paramType = "form")
    })
	public Map<String, Object> saveOrUpdate(HttpServletRequest request, String obj_main, String obj) {
		Map<String, Object> map = new HashMap<String, Object>();

		try {
			storageQualitystandardMainService.saveOrUpdate(request, obj_main, obj);
			map.put("status", "200");
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}

	@RequestMapping(value = "/delete",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除一条质量标准配置数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
	public Map<String, Object> delete(String id) {
		Map<String, Object> map = new HashMap<String, Object>();

		try {
			storageQualitystandardMainService.delete(id);
			map.put("status", "200");
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}

	@RequestMapping(value = "/findLspzObjs",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="删除一条质量标准配置数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "lspz", value = "适用品种", paramType = "query")
    })
	public Map<String, Object> findLspzObjs(Integer lspz) {
		Map<String, Object> map = null;

		try {
			map = storageQualitystandardMainService.findLspzObjs(lspz);
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}
}
