package com.chinaitop.depot.storage.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageSet;
import com.chinaitop.depot.storage.model.StorageSetExample;
import com.chinaitop.depot.storage.service.StorageSetService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/storageSet")
@Api(value= "StorageSetController", description = "粮食质量功能设置控制类")
public class StorageSetController {

	@Resource
	private StorageSetService storageSetService;

	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="粮食质量功能设置数据列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "lspz", value = "粮食品种ID", paramType = "query")
    })
	public PageInfo<StorageSet> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer lspz) {
		
		List<StorageSet> list = null;
		PageInfo<StorageSet> pageInfo = null;
		
		StorageSetExample example = new StorageSetExample();
		StorageSetExample.Criteria criteria = example.createCriteria();

		if (null != lspz) {
			criteria.andLspzEqualTo(lspz);
		}

		int org_id = Integer.parseInt(ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0"));
		criteria.andOrgIdEqualTo(org_id);

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}

		list = storageSetService.findCondition(example);
		pageInfo = new PageInfo<StorageSet>(list);
		
		return pageInfo;
	}

	@RequestMapping(value = "/findByIdObj",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="按ID查询一条粮食质量功能设置数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键Id", paramType = "query")
    })
	public Map<String, Object> findByIdObj(String id) {

		Map<String, Object> map = new HashMap<String, Object>();

		StorageSet storageSet = null;
		/* 查询粮食质量功能设置数据  */
		if (null == id || "".equals(id)) {
			storageSet = new StorageSet();
			storageSet.setCreateTime(new Date());
			storageSet.setIsOpen(true);
		} else {
			storageSet = storageSetService.findbyidStorageSet(id);
		}
		map.put("storageSet", storageSet);

		return map;
	}

	@RequestMapping(value = "/update",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新粮食质量功能设置信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "storageSetJson", value = "粮食质量功能设置数据", paramType = "form")
    })
	public Map<String, Object> update(String storageSetJson) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 更新粮食质量功能设置数据  */
		ObjectMapper objectMapper = new ObjectMapper();
		try {
			StorageSet storageSet = objectMapper.readValue(storageSetJson, StorageSet.class);

			if (storageSet.getId() == null) {
				String uuid = UUID.randomUUID().toString().replaceAll("-", "");
				storageSet.setId(uuid);
				storageSetService.insert(storageSet);
			} else {
				storageSetService.updateStorageSet(storageSet);
			}
			map.put("status", "success");
		} catch (Exception e) {
			map.put("status", "error");
			e.printStackTrace();
		}

		return map;
	}

	@RequestMapping(value = "/deleteStorageSet",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除一条粮食质量功能设置数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键Id", paramType = "form")
    })
	public Map<String, Object> deleteStorageSet(String id) {

		Map<String, Object> map = new HashMap<String, Object>();

		if (null != id && !"".equals(id)) {
			storageSetService.delete(id);
		}
		map.put("status", "success");
		map.put("msg", "删除成功！");

		return map;
	}
	
	@RequestMapping(value = "/getDistinctLspz",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询一条配置数据是否重复")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "lspz", value = "粮油品种Id", paramType = "query"),
        @ApiImplicitParam(name = "checkType", value = "数据类型", paramType = "query")
    })
	public Map<String, Object> getDistinctLspz(HttpServletRequest request, Integer lspz, Integer checkType) {

		Map<String, Object> map = new HashMap<String, Object>();

		int count = 0;
		int org_id = Integer.parseInt(ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0"));
		if (null != lspz && org_id != 0 && null != checkType) {
			StorageSetExample example = new StorageSetExample();
			StorageSetExample.Criteria criteria = example.createCriteria();
			criteria.andLspzEqualTo(lspz);
			criteria.andOrgIdEqualTo(org_id);
			criteria.andCheckTypeEqualTo(checkType);
			count = storageSetService.getDistinckLspz(example);
		} else {
			map.put("status", "error");
			map.put("msg", "数据异常！");
		}
		
		//如果条数大于0，那就是已经存在了
		if (count > 0) {
			map.put("status", "error");
			map.put("msg", "当前品种的配置已存在！");
		} else {
			map.put("status", "success");
		}

		return map;
	}
}
