package com.chinaitop.depot.storage.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.storage.model.StorageWarterFixedPoint;
import com.chinaitop.depot.storage.model.StorageWarterMobilePoint;
import com.chinaitop.depot.storage.model.StorageWaterCheck;
import com.chinaitop.depot.storage.model.StorageWaterCheckExample;
import com.chinaitop.depot.storage.service.StorageWarterCheckService;
import com.chinaitop.depot.storage.service.StorageWarterFixedPointService;
import com.chinaitop.depot.storage.service.StorageWarterMobilePointService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/storageWaterCheck")
@Api(value= "StorageWarterCheckController", description = "粮油水分检验控制类")
public class StorageWarterCheckController {

	@Resource
	private StorageWarterCheckService storageWaterCheckService;

	@Resource
	private StorageWarterFixedPointService storageWarterFixedPointService;

	@Resource
	private StorageWarterMobilePointService storageWarterMobilePointService;

	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="粮食质量功能设置数据列表", notes = "支持分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
        @ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query")
    })
	public PageInfo<StorageWaterCheck> getList(HttpServletRequest request, 
			Integer pageNum, Integer pageSize, Integer houseId, Integer wareId) {
		
		List<StorageWaterCheck> list = null;
		PageInfo<StorageWaterCheck> pageInfo = null;
		
		StorageWaterCheckExample example = new StorageWaterCheckExample();
		StorageWaterCheckExample.Criteria criteria = example.createCriteria();

		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}
		
		if (null != wareId) {
			criteria.andWareIdEqualTo(wareId);
		}

		int org_id = Integer.parseInt(ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0"));
		criteria.andOrgIdEqualTo(org_id);

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}

		example.setOrderByClause(" hy_date desc ");
		list = storageWaterCheckService.findCondition(example);
		
		pageInfo = new PageInfo<StorageWaterCheck>(list);
		
		return pageInfo;
	}

	@RequestMapping(value = "/findByIdObj",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="按ID查询一条水分检验数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键Id", paramType = "query")
    })
	public Map<String, Object> findByIdObj(String id) {

		Map<String, Object> map = new HashMap<String, Object>();

		StorageWaterCheck storageWaterCheck = null;
		List<StorageWarterFixedPoint> storageWarterFixedPoint_list = null;
		List<StorageWarterMobilePoint> storageWarterMobilePoint_list = null;
		/* 查询水分检验相关数据  */
		if (null == id || "".equals(id)) {
			storageWaterCheck = new StorageWaterCheck();
			storageWaterCheck.setHyDate(new Date());
			storageWarterFixedPoint_list = new ArrayList<StorageWarterFixedPoint>();
			storageWarterMobilePoint_list = new ArrayList<StorageWarterMobilePoint>();
			StorageWarterFixedPoint fixedPoint = new StorageWarterFixedPoint();
			fixedPoint.setInputTime(new Date());
			storageWarterFixedPoint_list.add(fixedPoint);
			StorageWarterMobilePoint mobilePoint = new StorageWarterMobilePoint();
			mobilePoint.setInputTime(new Date());
			storageWarterMobilePoint_list.add(mobilePoint);
		} else {
			storageWaterCheck = storageWaterCheckService.findbyidStorageWaterCheck(id);
			storageWarterFixedPoint_list = storageWarterFixedPointService.findCondition(id);
			storageWarterMobilePoint_list = storageWarterMobilePointService.findCondition(id);
		}
		map.put("storageWaterCheck", storageWaterCheck);
		map.put("storageWarterFixedPoint", storageWarterFixedPoint_list);
		map.put("storageWarterMobilePoint", storageWarterMobilePoint_list);

		return map;
	}

	@RequestMapping(value = "/update",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新水分检验信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "storageWaterCheckJson", value = "水分检验主数据", paramType = "form"),
        @ApiImplicitParam(name = "storageWarterFixedPointJson", value = "水分检验固定点信息数据", paramType = "form"),
        @ApiImplicitParam(name = "storageWarterMobilePointJson", value = "水分检验机动点信息表数据", paramType = "form")
    })
	@Transactional(rollbackFor = Exception.class)
	public Map<String, Object> update(HttpServletRequest request, String storageWaterCheckJson, 
			String storageWarterFixedPointJson, String storageWarterMobilePointJson) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 更新粮食质量功能设置数据  */
		
		try {
			map = storageWaterCheckService.update(request, storageWaterCheckJson, storageWarterFixedPointJson, storageWarterMobilePointJson);
			map.put("status", "success");
		} catch (Exception e) {
			map.put("status", "error");
			e.printStackTrace();
			TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
			throw new RuntimeException();
		}

		return map;
	}

	@RequestMapping(value = "/deleteStorageWaterCheck",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除一条粮食质量功能设置数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键Id", paramType = "form")
    })
	@Transactional(rollbackFor = Exception.class)
	public Map<String, Object> deleteStorageWaterCheck(String id) {

		Map<String, Object> map = new HashMap<String, Object>();

		if (null != id && !"".equals(id)) {
			storageWaterCheckService.delete(id);
		}
		map.put("status", "success");
		map.put("msg", "删除成功！");

		return map;
	}
	
	@RequestMapping(value = "/deleteStorageWaterFlt",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除一条粮食质量功能设置数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键Id", paramType = "form"),
        @ApiImplicitParam(name = "dataType", value = "数据类型", paramType = "form")
    })
	@Transactional(rollbackFor = Exception.class)
	public Map<String, Object> deleteStorageWaterFlt(String id, Integer dataType) {

		Map<String, Object> map = new HashMap<String, Object>();

		if (null != id && !"".equals(id)) {
			storageWaterCheckService.deleteFlt(id, dataType);
		}
		map.put("status", "success");
		map.put("msg", "删除成功！");

		return map;
	}

	@RequestMapping(value = "/findWarterData",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="原粮粮情-水分检测", notes = "支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "storehouse", value = "仓房", paramType = "query"),
			@ApiImplicitParam(name = "warehouse", value = "货位", paramType = "query")
	})
	public PageInfo<StorageWaterCheck> findWarterData(HttpServletRequest request, Integer pageNum, Integer pageSize,  Integer storehouse, Integer warehouse) {

		List<StorageWaterCheck> list = null;
		PageInfo<StorageWaterCheck> pageInfo = null;
		Integer orgId = (Integer) request.getSession().getAttribute("orgId");
		StorageWaterCheckExample example = new StorageWaterCheckExample();
		StorageWaterCheckExample.Criteria criteria = example.createCriteria();
		example.setOrderByClause(" hy_date desc");

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}

		if (null != storehouse){
			criteria.andHouseIdEqualTo(storehouse);
		}
		if (null != warehouse){
			criteria.andWareIdEqualTo(warehouse);
		}
		 
		
		list = storageWaterCheckService.findWarterData(example);

		pageInfo = new PageInfo<StorageWaterCheck>(list);
		return pageInfo;

		}
	
	@RequestMapping(value = "/selectWaterData",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="原粮粮情-水分检测-查询水分数据表")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "warterId", value = "storage_water_check表主键ID", paramType = "query")
	})
	public Map<String, Object> selectWaterData(String warterId) {

		Map<String, Object> modelMap = new HashMap<String, Object>(); //水分主表
		StorageWaterCheck storageWaterCheck = storageWaterCheckService.findbyidStorageWaterCheck(warterId);
		modelMap.put("StorageWaterCheck", storageWaterCheck); //水分检验机动点信息表
		
		List<StorageWarterFixedPoint> list = storageWarterFixedPointService.findCondition(warterId);
		modelMap.put("StorageWarterFixedPoint", list); //水分检验固定点信息表
		
		
		List<StorageWarterMobilePoint> mobileList = storageWarterMobilePointService.findCondition(warterId);
		modelMap.put("StorageWarterMobilePoint", mobileList); //水分检验机动点信息表
		return modelMap;

		}
	}
