package com.chinaitop.depot.storage.controller;


import com.chinaitop.depot.storage.model.ClearanceConfirmation;
import com.chinaitop.depot.storage.model.StorageStorehouseBusiness;
import com.chinaitop.depot.storage.model.WarehouseSealingRecord;
import com.chinaitop.depot.storage.model.vo.WareHouseVO;
import com.chinaitop.depot.storage.model.vo.kcswVO;
import com.chinaitop.depot.storage.service.WarehouseSealingRecordService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 封仓确认单控制类
 *
 * @author User
 *
 */
@SuppressWarnings("all")
@RestController
@RequestMapping(value = "/WarehouseSealingRecordController")
@Api(value= "WarehouseSealingRecordController", description = "封仓确认单控制类")
public class WarehouseSealingRecordController {

    final static Logger logger = LoggerFactory.getLogger(WarehouseSealingRecord.class);
    @Resource
    private WarehouseSealingRecordService WarehouseSealingRecordService;

    /**
     * 封仓确认单信息
     *
     * @param pageNum 页数
     * @param pageSize 每页显示的条数
     * @param storeName 仓房名称
     * @param ajmc 廒间名称
     * @param orgId 单位ID
     * @return
     */
    @RequestMapping(value = "/getCleConList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询封仓确认单信息数据列表", notes = "查询封仓确认单数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "storeName", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "ajmc", value = "廒间名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")

    })
    public PageInfo<WarehouseSealingRecord> getCleConList(Integer pageNum, Integer pageSize,
                                                     String storeName,
                                                     String ajmc, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<WarehouseSealingRecord> list = null;
        try {

            if (null != storeName && !"".equals(storeName)) {
                modelMap.put("storehouseName", storeName);
            }
            if (null != ajmc && !"".equals(ajmc)) {
                modelMap.put("ajmc", ajmc);
            }
            /* 只能查询当前单位的数据  */
            if (null != orgId) {
                modelMap.put("orgId", orgId);
            }

            list = WarehouseSealingRecordService.getList(modelMap);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<WarehouseSealingRecord> pageInfo = new PageInfo<WarehouseSealingRecord>(list);
        return pageInfo;
    }

    /**
     * 根据ID查找封仓确认单信息
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/findByCleCon",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据ID查找封仓确认单信息", notes = "根据ID查找封仓确认单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
    })
    public WarehouseSealingRecord findByUnitAisle(Integer id) {
        WarehouseSealingRecord WarehouseSealingRecord = null;
        try {
            if (id != null) {
                WarehouseSealingRecord = WarehouseSealingRecordService.findByWarehouseSea(id);
            } else {
                WarehouseSealingRecord = new WarehouseSealingRecord();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return WarehouseSealingRecord;
    }


    @RequestMapping(value = "/edit",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新封仓确认单信息", notes = "更新封仓确认单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "warehouseSealingRecordJson", value = "JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "userInfo", value = "JSON登录对象", paramType = "form")
    })
    public Map<String, Object> edit(@RequestParam("warehouseSealingRecordJson")String warehouseSealingRecordJson,@RequestParam("userInfo") String userInfo) {
        Map<String, Object> modelMap = null;
        try {
            modelMap = WarehouseSealingRecordService.saveOrUpdate(null, warehouseSealingRecordJson, userInfo);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }
    }

    /**
     * 删除封仓确认单
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除封仓确认单", notes = "删除封仓确认单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // 先查询到这条数据
            WarehouseSealingRecord WarehouseSealingRecord = WarehouseSealingRecordService.findByWarehouseSea(id);
           Date date=new Date();
            WarehouseSealingRecord.setCzbz("d");
            WarehouseSealingRecord.setUpdatedate(date);
            WarehouseSealingRecord.setZhgxsj(date);
            WarehouseSealingRecordService.updateBasicStorehouse(WarehouseSealingRecord);
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "操作失败！");
        }
        return modelMap;
    }
    /**
     * 查询当前库区做过检验的仓房
     *
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findStorehouse",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    public List<StorageStorehouseBusiness> findStorehouse(Integer orgId) {
        List<StorageStorehouseBusiness> storageStorehouseBusinessList = null;
        try {

                storageStorehouseBusinessList = WarehouseSealingRecordService.findStorehouse(orgId);

        } catch (Exception e) {
            e.printStackTrace();
        }
        return storageStorehouseBusinessList;
    }

    /**
     * 根据basicStorehouseId查询货位
     * @param storehouseId
     * @return
     */
    @RequestMapping(value = "/findWareHouse",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    public List<WareHouseVO> findWareHouse(Integer storehouseId) {
        List<WareHouseVO> wareHouseVOList = null;
        try {

           wareHouseVOList = WarehouseSealingRecordService.findWareHouse(storehouseId);

        } catch (Exception e) {
            e.printStackTrace();
        }
        return wareHouseVOList;
    }
    /**
     * 根据货位查询库存
     * @param warehouseId
     * @return
     */
    @RequestMapping(value = "/findkcsw",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    public kcswVO findkcsw(Integer warehouseId) {
        kcswVO kcswVO = null;
        try {
            kcswVO = WarehouseSealingRecordService.findkcsw(warehouseId);

        } catch (Exception e) {
            e.printStackTrace();
        }
        return kcswVO;
    }




}
