package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.XwkZljc;
import com.chinaitop.depot.storage.service.impl.XwkZljcServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 吉东杰
 * 2020/8/4
 */
@RestController
@RequestMapping(value = {"/xwkZljc"})
@Api(value= "XwkZljcController", description = "质量管理控制类")
public class XwkZljcController {
    @Resource
    private XwkZljcServiceImpl xwkZljcServiceImpl;

    /**
     * 查询市平台的强检、第三方检验
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseName", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "warehouseName", value = "货位名称", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "companyOrgCode", value = "组织机构代码", paramType = "query"),
    })
    public PageInfo<XwkZljc> listPage(Integer pageNum, Integer pageSize,String houseId,String warehouseId,String checktype,String companyOrgCode) {

        XwkZljc xwkZljc = new XwkZljc();

        //类型
        if(StringUtils.isNotBlank(checktype)){
            if(checktype.equals("2")){
                xwkZljc.setJclx("强检");
            }else{
                xwkZljc.setJclx("入库质检");
            }
        }

        //组织机构
        if(StringUtils.isNotBlank(companyOrgCode)){
            xwkZljc.setKqmc(companyOrgCode);
        }

        //仓房
        if(StringUtils.isNotBlank(houseId)){
            xwkZljc.setHouseId(houseId);
        }

        if(StringUtils.isNotBlank(warehouseId)){
            xwkZljc.setWarehouseId(warehouseId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<XwkZljc> list = xwkZljcServiceImpl.queryXwkZljc(xwkZljc);

        PageInfo<XwkZljc> pageInfo = new PageInfo<XwkZljc>(list);
        return pageInfo;
    }


    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载质量检查数据", notes = "根据id加载质量检查数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public ConcurrentHashMap<String, Object> loadDataById(String id){

        ConcurrentHashMap<String, Object> retMap= xwkZljcServiceImpl.loadDataById(id);

        return retMap;
    }

}