/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.chinaitop.depot.storage.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 原粮转卡（粮情卡）编辑参数
 *
 * @author ZeroLiYi
 * @date  2024/05/24 09:50
 **/
@Getter
@Setter
public class GrainSituationCardEditParam {

    /** 主键ID */
    @ApiModelProperty(value = "主键ID", required = true, position = 1)
    @NotNull(message = "id不能为空")
    private Integer id;

    /** CREATENAME */
    @ApiModelProperty(value = "CREATENAME", position = 2)
    private String createname;

    /** 创建日期 */
    @ApiModelProperty(value = "创建日期", position = 3)
    private Date createdate;

    /** UPDATENAME */
    @ApiModelProperty(value = "UPDATENAME", position = 4)
    private String updatename;

    /** 更新日期 */
    @ApiModelProperty(value = "更新日期", position = 5)
    private Date updatedate;

    /** warehouse_sealing_record的id； */
    @ApiModelProperty(value = "warehouse_sealing_record的id；", position = 6)
    private Integer warehouseSealingRecordId;

    /** 填卡库区id；org_info的id； */
    @ApiModelProperty(value = "填卡库区id；org_info的id；", position = 7)
    private Integer fillOrgId;

    /** 保管库区id；org_info的id； */
    @ApiModelProperty(value = "保管库区id；org_info的id；", position = 8)
    private Integer keepOrgId;

    /** basic_storehouse的id；仓房id； */
    @ApiModelProperty(value = "basic_storehouse的id；仓房id；", position = 9)
    private Integer basicStorehouseId;

    /** basic_unit_aisle的id；廒间id； */
    @ApiModelProperty(value = "basic_unit_aisle的id；廒间id；", position = 10)
    private Integer basicUnitAisleId;

    /** basic_warehouse的id；货位id; */
    @ApiModelProperty(value = "basic_warehouse的id；货位id;", position = 11)
    private Integer warehouseId;

    /** 仓房类型编号（立筒仓等） */
    @ApiModelProperty(value = "仓房类型编号（立筒仓等）", position = 12)
    private Integer storehouseType;

    /** 设计容量（数字，单位吨） */
    @ApiModelProperty(value = "设计容量（数字，单位吨）", position = 13)
    private BigDecimal designCapacity;

    /** 粮食品种；basic_enum的id； */
    @ApiModelProperty(value = "粮食品种；basic_enum的id；", position = 14)
    private Integer grainVarietyId;

    /** 粮食性质；basic_enum的id； */
    @ApiModelProperty(value = "粮食性质；basic_enum的id；", position = 15)
    private Integer grainNatureId;

    /** 粮食数量，单位：公斤 */
    @ApiModelProperty(value = "粮食数量，单位：公斤", position = 16)
    private BigDecimal lssl;

    /** 粮食产地；basic_enum的id； */
    @ApiModelProperty(value = "粮食产地；basic_enum的id；", position = 17)
    private Integer grainAreaId;

    /** 收获年度，格式：YYYY，货位（油罐）状态为2、3、4时必填 */
    @ApiModelProperty(value = "收获年度，格式：YYYY，货位（油罐）状态为2、3、4时必填", position = 18)
    private Date shnd;

    /** 入仓日期；第一车粮食入仓时间； */
    @ApiModelProperty(value = "入仓日期；第一车粮食入仓时间；", position = 19)
    private Date rcsj;

    /** 出库数量 */
    @ApiModelProperty(value = "出库数量", position = 20)
    private BigDecimal outQuantity;

    /** 入库财政核定 */
    @ApiModelProperty(value = "入库财政核定", position = 21)
    private String inFinancialVerification;

    /** 出库财政核定 */
    @ApiModelProperty(value = "出库财政核定", position = 22)
    private String outFinancialVerification;

    /** 存储损耗 */
    @ApiModelProperty(value = "存储损耗", position = 23)
    private BigDecimal excessLossQuantity;

    /** 形成货位时间；生成粮情卡的时间； */
    @ApiModelProperty(value = "形成货位时间；生成粮情卡的时间；", position = 24)
    private Date formWarehouseTime;

    /** 粮食等级；basic_enum的id； */
    @ApiModelProperty(value = "粮食等级；basic_enum的id；", position = 25)
    private Integer grainGradeId;

    /** 测温方式 1：电子测温；2：手动测温； */
    @ApiModelProperty(value = "测温方式 1：电子测温；2：手动测温；", position = 26)
    private Integer temperatureMeasureType;

    /** 通风方式 */
    @ApiModelProperty(value = "通风方式", position = 27)
    private Integer drafttype;

    /** 管理方式 01 直储；02 代储；03 租仓；04 委托； */
    @ApiModelProperty(value = "管理方式 01 直储；02 代储；03 租仓；04 委托；", position = 28)
    private String glfs;

    /** 存储地点库区id；org_info的id； */
    @ApiModelProperty(value = "存储地点库区id；org_info的id；", position = 29)
    private Integer storageOrgId;

    /** 保管方式 */
    @ApiModelProperty(value = "保管方式", position = 30)
    private Integer keepingWay;

    /** 散存粮体积(立方米) */
    @ApiModelProperty(value = "散存粮体积(立方米)", position = 31)
    private BigDecimal volume;

    /** 长（米） */
    @ApiModelProperty(value = "长（米）", position = 32)
    private BigDecimal length;

    /** 宽（米） */
    @ApiModelProperty(value = "宽（米）", position = 33)
    private BigDecimal width;

    /** 梯形粮堆-上底长 */
    @ApiModelProperty(value = "梯形粮堆-上底长", position = 34)
    private BigDecimal trapezoidUpperLength;

    /** 梯形粮堆-下底长 */
    @ApiModelProperty(value = "梯形粮堆-下底长", position = 35)
    private BigDecimal trapezoidLowerLength;

    /** 梯形粮堆-上底宽 */
    @ApiModelProperty(value = "梯形粮堆-上底宽", position = 36)
    private BigDecimal trapezoidUpperWidth;

    /** 梯形粮堆-下底宽 */
    @ApiModelProperty(value = "梯形粮堆-下底宽", position = 37)
    private BigDecimal trapezoidLowerWidth;

    /** 平房仓粮堆（高） */
    @ApiModelProperty(value = "平房仓粮堆（高）", position = 38)
    private BigDecimal flatStorageHeight;

    /** 梯形高 */
    @ApiModelProperty(value = "梯形高", position = 39)
    private BigDecimal trapezoidHeight;

    /** 筒仓内直径 */
    @ApiModelProperty(value = "筒仓内直径", position = 40)
    private BigDecimal siloInnerDiameter;

    /** 筒仓内粮堆高 */
    @ApiModelProperty(value = "筒仓内粮堆高", position = 41)
    private BigDecimal siloGrainHeight;

    /** 包装散存包数 */
    @ApiModelProperty(value = "包装散存包数", position = 42)
    private Integer packagedCount;

    /** 平均包重 */
    @ApiModelProperty(value = "平均包重", position = 43)
    private BigDecimal averageWeight;

    /** 检查记录id；business_qc_quality_inspection的id；数组","分隔； */
    @ApiModelProperty(value = "检查记录id；business_qc_quality_inspection的id；数组 逗号分隔；", position = 44)
    private String checkRecordIds;

}
