package com.chinaitop.depot.storage.service;

import com.chinaitop.depot.storage.model.StorageStorehouseBusiness;
import com.chinaitop.depot.storage.model.StorageStorehouseBusinessExample;
import com.chinaitop.depot.storage.utils.OnOffEnum;
import com.chinaitop.depot.storage.utils.TaskEnum;


import java.util.List;
import java.util.Map;

public interface StorageStorehouseBusinessService {

	/**
	 * 新增数据
	 * 
	 * @param storageStorehouseBusiness 数据对象
	 * @throws Exception
	 */
	void add(StorageStorehouseBusiness storageStorehouseBusiness) throws Exception;

	/**
	 * 删除数据
	 * 
	 * @param id 数据ID
	 * @throws Exception
	 */
	void remove(Integer id) throws Exception;

	/**
	 * 修改数据
	 * 
	 * @param storageStorehouseBusiness 数据对象
	 * @throws Exception
	 */
	void update(StorageStorehouseBusiness storageStorehouseBusiness) throws Exception;

	/**
	 * 按ID查询一条数据
	 * 
	 * @param id 数据ID
	 * @return
	 * @throws Exception
	 */
	StorageStorehouseBusiness findById(Integer id) throws Exception;

	/**
	 * 按条件查询多条数据
	 * 
	 * @param example
	 * @return
	 * @throws Exception
	 */
	List<StorageStorehouseBusiness> findCondition(StorageStorehouseBusinessExample example) throws Exception;

	/**
	 * 根据分仓保管账中的仓房名称
	 *
	 * @return
	 */
	public Map<String, Object> getStorehouseData();

	/**
	 * 根据分仓保管账中的仓房ID得到货位
	 *
	 * @return
	 */
	public Map<String, Object> getWarehouseData(Integer ch);

	/**
	 * 从分仓保管账中查数据插入到仓房业务表
	 */
	void saveStorehouseBusinessFromFcbgz();

	/**
	 * 更新仓房业务表的通风状态
	 *
	 * @param houseId 仓房ID
	 * @param wareId 货位ID
	 * @param orgId 单位ID
	 * @param aerationStatus 通风状态
	 */
	void updateAerationStatus(Integer houseId, Integer wareId, Integer orgId, String aerationStatus);

    /**
     * 作业状态修改接口
     * 主要作业：入库、出库、通风、熏蒸、内环流
     * @param task 枚举类型，对对应枚举进行作业状态修改，可参考TaskEnum
     * @param type 类型，ON 状态开启，OFF 状态关闭,可参考OnOffEnum
     * @param cfid 仓房id
     */
    public void setStatusForTask(TaskEnum task, OnOffEnum type, int cfid);

}
