/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.chinaitop.depot.storage.service.impl;


import com.chinaitop.depot.qualityControl.mapper.BusinessQcQualityInspectionItemMapper;
import com.chinaitop.depot.qualityControl.mapper.BusinessQcQualityInspectionMapper;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspection;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspectionItem;
import com.chinaitop.depot.storage.mapper.GrainSituationCardMapper;
import com.chinaitop.depot.storage.mapper.GrainSituationCardWarehouseRecordMapper;
import com.chinaitop.depot.storage.model.GrainSituationCard;
import com.chinaitop.depot.storage.model.GrainSituationCardWarehouseRecord;
import com.chinaitop.depot.storage.model.vo.GrainSituationCardVO;
import com.chinaitop.depot.storage.param.GrainSituationCardIdParam;
import com.chinaitop.depot.storage.param.GrainSituationCardPageParam;
import com.chinaitop.depot.storage.service.GrainSituationCardService;
import com.chinaitop.depot.storage.utils.ExcelExporter;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;


import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 原粮转卡（粮情卡）Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/05/24 09:50
 **/
@Service
public class GrainSituationCardServiceImpl implements GrainSituationCardService {

    @Resource
    private BusinessQcQualityInspectionItemMapper businessQcQualityInspectionItemMapper;

    @Resource
    private BusinessQcQualityInspectionMapper businessQcQualityInspectionMapper;

    @Resource
    private GrainSituationCardMapper grainSituationCardMapper;

    @Resource
    private GrainSituationCardWarehouseRecordMapper grainSituationCardWarehouseRecordMapper;

    @Override
    public List<GrainSituationCard> page(GrainSituationCardPageParam grainSituationCardPageParam) {
        if (grainSituationCardPageParam.getPageNum() != null && grainSituationCardPageParam.getPageSize() != null) {
            PageHelper.startPage(grainSituationCardPageParam.getPageNum(), grainSituationCardPageParam.getPageSize());
        }
        List<GrainSituationCard> list= grainSituationCardMapper.selectCardList(grainSituationCardPageParam);
        return list;
    }

    @Override
    public GrainSituationCardVO detail(GrainSituationCardIdParam grainSituationCardIdParam) {
        GrainSituationCardVO grainSituationCardVO =grainSituationCardMapper.selectByGrainsituationId(grainSituationCardIdParam);
        if(grainSituationCardVO!=null){
            List<GrainSituationCardWarehouseRecord> grainSituationCardWarehouseRecordList =
                    grainSituationCardWarehouseRecordMapper.findByCardId(grainSituationCardIdParam);
            if(grainSituationCardWarehouseRecordList!=null){
                grainSituationCardVO.setGrainSituationCardWarehouseRecordList(grainSituationCardWarehouseRecordList);
            }
        }

        if(grainSituationCardVO.getCheckRecordIds()!=null){
            String[] ids=grainSituationCardVO.getCheckRecordIds().split(",");
            List<BusinessQcQualityInspection> businessQcQualityInspectionList =new ArrayList<>();
            for (int i = 0; i < ids.length; i++) {
                //查询导检验类型，建议时间。。
                BusinessQcQualityInspection businessQcQualityInspection=  businessQcQualityInspectionMapper.findByqualityId(ids[i]);
                //查询质检明细
                List<Map<String,Object>> itm =businessQcQualityInspectionItemMapper.findByqualityId(ids[i]);
                Map<Integer, List<String>> transformedData =    cat(itm);
                if(businessQcQualityInspection != null &&transformedData!=null){
                    businessQcQualityInspection.setMaps(transformedData);
                }
                if(businessQcQualityInspection!=null){
                    businessQcQualityInspectionList.add(businessQcQualityInspection);
                }

            }
            if(businessQcQualityInspectionList!=null){
                grainSituationCardVO.setBusinessQcQualityInspectionList(businessQcQualityInspectionList);
            }

        }



        return grainSituationCardVO;
    }

    private Map<Integer, List<String>> cat(List<Map<String, Object>> itm) {
        // 使用Stream API进行转换
        // 使用Stream API进行转换
        Map<Integer, List<String>> transformedData = itm.stream()
                .collect(Collectors.groupingBy(
                        item -> (Integer) item.get("qcQualityInspectionId"),
                        Collectors.mapping(
                                item -> (String) item.get("inspectionItemName") + ": " + (String) item.get("inspectionValue"),
                                Collectors.toList()
                        )
                ));

        // 打印转换后的数据结构，这里为了简化展示，只打印keySet
        transformedData.forEach((id, inspections) ->
                System.out.println("qcQualityInspectionId: " + id + ", Inspections: " + inspections)
        );
        return transformedData;
    }


    @Override
    public List<BusinessQcQualityInspection> getQualityInspectionFindByWarehouseId(Integer warehouseId) {
        Map<String,Object> map = new HashMap<String,Object>();
        map.put("warehouseId", warehouseId);
        BusinessQcQualityInspection businessQcQualityInspection=new BusinessQcQualityInspection();
        List<BusinessQcQualityInspection> list =businessQcQualityInspectionMapper.getQualityInspectionFindByWarehouseId(map);
        for (BusinessQcQualityInspection b:list) {
            //查询质检明细
            List<Map<String,Object>> itm =businessQcQualityInspectionItemMapper.findByqualityId(b.getId()+"");
            Map<Integer, List<String>> transformedData =    cat(itm);

            b.setMaps(transformedData);
        }

        return list;
    }

    @Override
    public Map<String, Object> add(GrainSituationCardVO grainSituationCardVO) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        grainSituationCardMapper.updateByPrimaryKey(grainSituationCardVO);
        List<GrainSituationCardWarehouseRecord> grainSituationCardWarehouseRecordList =
        grainSituationCardVO.getGrainSituationCardWarehouseRecordList();

        if(grainSituationCardWarehouseRecordList!=null){
            grainSituationCardWarehouseRecordMapper.delete(grainSituationCardVO.getId());
            for (GrainSituationCardWarehouseRecord record:grainSituationCardWarehouseRecordList) {
                record.setGrainSituationCardId(grainSituationCardVO.getId());
                record.setCreatedate(new Date());
                record.setUpdatedate(new Date());
                grainSituationCardWarehouseRecordMapper.insert(record);
            }
        }else{
            grainSituationCardWarehouseRecordMapper.delete(grainSituationCardVO.getId());
        }

        modelMap.put("status", "success");
        return modelMap;
    }

    @Override
    public Map<String, Object> exportdetail(GrainSituationCardIdParam grainSituationCardIdParam) throws IOException, NoSuchFieldException {
        GrainSituationCardVO grainSituationCardVO =grainSituationCardMapper.selectByGrainsituationId(grainSituationCardIdParam);
        List<GrainSituationCardWarehouseRecord> grainSituationCardWarehouseRecordList =
                grainSituationCardWarehouseRecordMapper.findByCardId(grainSituationCardIdParam);
        List<BusinessQcQualityInspection> businessQcQualityInspectionList = new ArrayList<>();
        List<BusinessQcQualityInspection> bqqs =new ArrayList<>();
        BusinessQcQualityInspection businessQcQualityInspection=new BusinessQcQualityInspection();
        Map<Integer, List<String>> date =new HashMap<>();
        Map<String,String> MAP=new HashMap<>();
        if(grainSituationCardVO.getCheckRecordIds()!=null) {
            String[] ids = grainSituationCardVO.getCheckRecordIds().split(",");
            for (int i = 0; i < ids.length; i++) {
                //查询导检验类型，建议时间。。
                businessQcQualityInspection=  businessQcQualityInspectionMapper.findByqualityId(ids[i]);
                MAP.put("zjbgdh",businessQcQualityInspection.getZjbgdh());
                MAP.put("jylb",businessQcQualityInspection.getJylb());
                //查询质检明细
                List<Map<String,Object>> itm =businessQcQualityInspectionItemMapper.findByqualityId(ids[i]);
                date =    cat(itm);


                businessQcQualityInspection.setMaps(date);
                businessQcQualityInspectionList.add(businessQcQualityInspection);
            }
        }
        List<Map<String, String>> dataList = new ArrayList<>();
        dataList.add(MAP);


        String fileName = "D:\\Temp\\aaa.xlsx";
        List<GrainSituationCardVO> data=new ArrayList<>();
        data.add(grainSituationCardVO);
        ExcelExporter.exportToExcel(data,grainSituationCardWarehouseRecordList,dataList,date,fileName);


        return null;
    }

}
