package com.chinaitop.depot.storage.service.impl;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.storage.mapper.TCcdataMapper;
import com.chinaitop.depot.storage.mapper.TCcvalueMapper;
import com.chinaitop.depot.storage.model.TCcdata;
import com.chinaitop.depot.storage.model.TCcdataExample;
import com.chinaitop.depot.storage.model.TCcvalue;
import com.chinaitop.depot.storage.model.TCcvalueExample;
import com.chinaitop.depot.storage.service.InsectPestDetectionService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.storage.utils.UuidUtils;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

@Service
public class InsectPestDetectionServiceImpl implements InsectPestDetectionService {

    @Resource
    private TCcdataMapper tCcdataMapper;

    @Resource
    private TCcvalueMapper tCcvalueMapper;

    @Resource
    private UuidUtils uuidUtils;

    /**
     * 列表
     *
     * @param iBeginTdh
     * @param iEndTdh
     * @return
     */
    @Override
    public List<TCcdata> getList(String vCfCode, Integer iBeginTdh, Integer iEndTdh,String createTime,String orgId) {
    	TCcdataExample example = new TCcdataExample();
        TCcdataExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        if (StringUtils.isNotBlank(vCfCode)) {
            criteria.andVCcCodeEqualTo(vCfCode);
        }
        if (null != iBeginTdh && null != iEndTdh) {
            criteria.andITdhBetween(iBeginTdh, iEndTdh);
        }
        if (null != createTime) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andVUpdateTimeLessThan(date);
        }
        example.setOrderByClause("v_update_time DESC");
        return tCcdataMapper.selectByExample(example);
    }

    @Override
    public ResponseEntity getByCfCode(String cfCode, String searchStartDate, String searchEndDate) {
        HashMap<String, String> map = Maps.newHashMap();
        if (StringUtils.isNotBlank(cfCode)) {
            map.put("vCfCode", cfCode);
        }
        if (StringUtils.isNotBlank(searchStartDate) && StringUtils.isNotBlank(searchEndDate)) {
            map.put("searchStartDate", searchStartDate + ParameterUtil.startTime);
            map.put("searchEndDate", searchEndDate + ParameterUtil.endTime);
        }
        List<Map<String, Object>> byCfCode = tCcvalueMapper.getByCfCode(map);

        if (byCfCode.size() > 0) {
            String[] legend = {"最大值(只)", "最小值(只)", "平均值(只)"};
            ArrayList<String> xAxis = Lists.newArrayList();
            ArrayList<Integer> maxs = Lists.newArrayList();
            ArrayList<Integer> mins = Lists.newArrayList();
            ArrayList<Double> avgs = Lists.newArrayList();
            JSONArray series = new JSONArray();
            for (Map<String, Object> maps : byCfCode) {
                int max = Integer.parseInt(maps.get("max").toString());
                int min = Integer.parseInt(maps.get("min").toString());
                double avg = Double.parseDouble(maps.get("avg").toString());
                String string = maps.get("vUpdateTime").toString();
                maxs.add(max);
                mins.add(min);
                avgs.add(avg);
                xAxis.add(string);
            }
            for (String leg : legend) {
                JSONObject json = new JSONObject();
                json.put("name", leg);
                json.put("type", "line");
                json.put("stack", "bars");
//                json.put("data", new JSONArray());
                series.add(json);
            }
            JSONObject jsonx = series.getJSONObject(0);
            jsonx.put("data", maxs);
            JSONObject jsonn = series.getJSONObject(1);
            jsonn.put("data", mins);
            JSONObject jsong = series.getJSONObject(2);
            jsong.put("data", avgs);

            JSONObject result = new JSONObject();
            result.put("xAxis", xAxis);
            result.put("legend", legend);
            result.put("series", series);
            System.out.println(result);
            return ResponseEntity.ok(result);
        }
        return null;
    }

    @Override
    public Map<String, Map<String, Object>> getByCfCodes(Map<String, Object> mapDate) {
        List<Map<String, Object>> byCfCodes = tCcvalueMapper.getByCfCodes(mapDate);
        if (byCfCodes.size() > 0) {
            HashMap<String, Map<String, Object>> map = Maps.newHashMap();
            for (Map<String, Object> objectMap : byCfCodes) {
                map.put(objectMap.get("vCfCode").toString(), objectMap);
            }
            return map;
        }
        return null;
    }

    @Transactional
    @Override
    public void insertBatch(List<TCcdata> tCcdata) {
        tCcdataMapper.insertBatch(tCcdata);
    }

    @Override
    public List<TCcdata> getByCodeAndTimes(List<String> cDcsCodes, List<Date> cTimes, List<Integer> tdhs) {
        TCcdataExample example = new TCcdataExample();
        TCcdataExample.Criteria criteria = example.createCriteria();
        if ((cDcsCodes != null && cDcsCodes.size() > 0) && (cTimes != null && cTimes.size() > 0) && (tdhs != null && tdhs.size() > 0)) {
            criteria.andVCcCodeIn(cDcsCodes);
            criteria.andVUpdateTimeIn(cTimes);
            criteria.andITdhIn(tdhs);
            List<TCcdata> tCcdata = tCcdataMapper.selectByExample(example);
            return tCcdata;
        }
        return null;
    }

    @Override
    public TCcvalue getOneByCfCode(String orgId, String vCfCode) {
        Map<String, Object> map = new HashMap<>();
        if (StringUtils.isNotBlank(vCfCode) && StringUtils.isNotBlank(orgId)) {
            map.put("orgId",orgId);
            map.put("vCfCode", vCfCode);
            return tCcvalueMapper.getOneByCfCode(map);
        }
        return null;
    }

	@Override
	public String getJcd(Map<String, Object> map, String jcsj) {
		String jcdh = "";
		List<Map<String, Object>> list = tCcdataMapper.getJcd(map);
		jcdh = list.get(0).get("jcd").toString();
		jcsj = jcsj.substring(0, 12);
		StringBuffer sbf = new StringBuffer(50);
		sbf.append(jcdh).append(jcsj);
		jcdh = sbf.toString().trim();
		return jcdh;
	}

    @Override
    public void add(TCcdata tCcdata,TCcvalue tCcvalue) {
        //tCcvalueMapper.insert(tCcvalue);
        tCcdataMapper.insert(tCcdata);
    }

    @Override
    public void update(TCcdata tCcdata,TCcvalue tCcvalue) {
        TCcdataExample tCcdataExample = new TCcdataExample();
        TCcdataExample.Criteria criteria = tCcdataExample.createCriteria();
        criteria.andIdEqualTo(tCcdata.getId());
        tCcdataMapper.updateByExampleSelective(tCcdata,tCcdataExample);

        TCcvalueExample tCcvalueExample = new TCcvalueExample();
        TCcvalueExample.Criteria criteria1 = tCcvalueExample.createCriteria();
        criteria1.andIdEqualTo(tCcvalue.getId());
        tCcvalueMapper.updateByExampleSelective(tCcvalue,tCcvalueExample);
    }

    @Override
    public List<TCcdata> getInsectPestDeatil(TCcdataExample example) {
        return tCcdataMapper.selectByExample(example);
    }

    @Override
    public TCcdata getByIdTCcData(String id) {

        TCcdataExample example = new TCcdataExample();
        TCcdataExample.Criteria criteria = example.createCriteria();
        criteria.andIdEqualTo(id);
        List<TCcdata> list  = tCcdataMapper.selectByExample(example);

        TCcdata tCcdata = null;

        if (null != list) tCcdata = list.get(0);

        return tCcdata;
    }

	@Override
	public void saveOrUpdate(String insectPests) throws Exception {
		//先把传过来的json转换
    	ObjectMapper mapper = new ObjectMapper();
    	TCcdata tCcdata = mapper.readValue(insectPests, TCcdata.class);
    	if (null == tCcdata.getId() || "".equals(tCcdata)) {
    		tCcdata.setId(uuidUtils.getCodeId(tCcdata.getOrgId(), "t_ccdata"));
    		tCcdata.setDataSource("1");//数据来源0是自动检测，1是手工录入
            tCcdata.setJchcff("0");
            //害虫检测单号
            Map<String,Object> map = new HashMap<String, Object>();
            map.put("warehouseId", tCcdata.getvHwCode());
            String jcd = getJcd(map, ParameterUtil.getDateYMDHMS(tCcdata.getvUpdateTime()));
            tCcdata.setHcjcdh(jcd);
            tCcdata.setUpdatetime(new Date());
    		tCcdataMapper.insert(tCcdata);
    	} else {
    		tCcdata.setUpdatetime(new Date());
    		tCcdataMapper.updateByPrimaryKeyWithBLOBs(tCcdata);
    	}
	}

}
