package com.chinaitop.depot.storage.service.impl;


import com.chinaitop.depot.storage.mapper.StorageFoodbasicInfoCheckMapper;
import com.chinaitop.depot.storage.mapper.StorageFoodbasicinfoMapper;
import com.chinaitop.depot.storage.mapper.StorageQualitycheckMapper;
import com.chinaitop.depot.storage.model.*;
import com.chinaitop.depot.storage.model.vo.StorageQualitycheckVo;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoLocationService;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.storage.utils.ZxingHandler;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * @author sunhongbing
 * @Date 2017/10/26
 */
@Service
@Transactional
public class StorageFoodbasicInfoServiceImpl implements StorageFoodbasicInfoService {
    @Resource
    private StorageFoodbasicinfoMapper foodbasicInfoMapper;
    @Resource
    private StorageQualitycheckMapper qualitycheckMapper;
    @Resource
    private StorageFoodbasicInfoCheckMapper foodbasicInfoCheckMapper;
    @Resource
    private StorageFoodbasicInfoLocationService foodbasicInfoLocationService;

    @Value("${web.upload-path}")
    private String rootPath;

    /**
     * 根据仓号得到对应的粮情专卡
     * @param foodbasicInfo
     * @return
     */
    @Override
    public List<StorageFoodbasicinfo> selectByExample(StorageFoodbasicinfo foodbasicInfo) {
        //对list进行处理获取仓房名称和货位名称
       return  foodbasicInfoMapper.queryByExample(foodbasicInfo);
    }

    @Override
    public List<StorageFoodbasicinfo> getByHouseIdAndWarehouseId(StorageFoodbasicinfo foodbasicInfo) {
        //设置保管员的名字
        List<StorageFoodbasicinfo> list = foodbasicInfoMapper.getFoodbasicInfoByHouseIdAndWarehouseId(foodbasicInfo);
        return list;
    }

    @Override
    public void save(StorageFoodbasicinfo foodbasicInfo, StorageQualitycheckVo qualitycheckVo,Integer orgId){
        StorageQualitycheck qualitycheck = new StorageQualitycheck();
        //获得仓房id和货位ID
        Integer houseId = foodbasicInfo.getHouseId();
        Integer wareHouseId = foodbasicInfo.getWarehouseId();
        // 组织机构信息.
        foodbasicInfo.setOrgId(orgId);
        foodbasicInfo.setHouseType(qualitycheckVo.getStorehouseType());
        foodbasicInfo.setDesignHouseCapacity(qualitycheckVo.getDesignCapacity());//设计仓容
//              foodbasicInfo.setLineHeight(storehouse.getLadeLineHeight());//装粮线高度(m)
        foodbasicInfo.setLength(qualitycheckVo.getLength());//长
        foodbasicInfo.setWidth(qualitycheckVo.getWidth());//宽

        //保存该仓房对应的保管员
        foodbasicInfo.setKeeperIds(qualitycheckVo.getKeeperNames());

        foodbasicInfo.setLocationNum(qualitycheckVo.getWarehouseCode());//货位编号
        //③保存验收的信息  qualitycheckService   var houseId=2;  var warehouseId=2;
        StorageQualitycheckExample qualityCheckExample = new StorageQualitycheckExample();
        StorageQualitycheckExample.Criteria qualityCriteria = qualityCheckExample.createCriteria();
        qualityCriteria.andHouseIdEqualTo(houseId);
        qualityCriteria.andWarehouseIdEqualTo(wareHouseId);
        qualityCriteria.andTypeEqualTo("1");//查询验收的粮食
        qualityCheckExample.setOrderByClause("id desc");
        if(houseId !=null){
           /* List<StorageQualitycheck> list = qualitycheckMapper.selectByExample(qualityCheckExample);
            if (null != list && list.size() > 0) {
                qualitycheck = list.get(0);
            }*/
            StorageQualitycheck qualitycheckData =qualitycheckMapper.queryPrimaryKey(qualitycheckVo.getQualitycheckId());
            qualitycheck = qualitycheckData;
        }
        if(qualitycheck != null){
            foodbasicInfo.setWater(qualitycheck.getWater());//水分
            foodbasicInfo.setImpurity(qualitycheck.getImpurity());//杂质
            foodbasicInfo.setUnsound(qualitycheck.getBadpart());//不完善粒
            foodbasicInfo.setWeight(qualitycheck.getCapacity());//容重
            foodbasicInfo.setLevel(String.valueOf(qualitycheck.getLevelUpdate()));//粮食等级
            foodbasicInfo.setInputYear(qualitycheck.getInputTime());//入仓时间
            foodbasicInfo.setGlutenWaterCount(qualitycheck.getGlutenWaterCount());//面筋吸水量
            foodbasicInfo.setEatScore(qualitycheck.getEatScore());//品尝评分值
            foodbasicInfo.setFatIndex(qualitycheck.getFatIndex());//酸值
            foodbasicInfo.setPeroxideValue(qualitycheck.getPeroxideValue());//过氧化值
        }

        //④保存分仓保管账
        //储粮性质，品种，实际数量，折合标准数量，产地，收货年度
        //1.1储粮性质
        foodbasicInfo.setQuality(qualitycheckVo.getHwxz());
        //1.2品种
        foodbasicInfo.setSubType(Integer.valueOf(qualitycheckVo.getPz()));
        //明细品种
        foodbasicInfo.setSubTypeDetailed(Integer.valueOf(qualitycheckVo.getMxpz()));

        //1.3实际数量(kg)
        foodbasicInfo.setNumber(qualitycheckVo.getKcsl());
        //1.4折合标准数量(吨) 将实际数量kg转换成折合标准数量吨
        foodbasicInfo.setStandNumber(qualitycheckVo.getKcsl()*0.001);

        //1.5产地hwcd
        if(StringUtils.isNoneBlank(qualitycheckVo.getHwcd())){
            foodbasicInfo.setPlaceOfOrigin(qualitycheckVo.getHwcd());
        }
        //1.6收货年度scnf
        if(StringUtils.isNoneBlank(qualitycheckVo.getScnf())){
            foodbasicInfo.setGrowYear(Integer.valueOf(qualitycheckVo.getScnf()));
        }
        //⑤其他
        foodbasicInfo.setKeepUnite(qualitycheckVo.getDepotName());//所属库点名称
        foodbasicInfo.setSealStatus("1");//代表已经封仓

        // ⑥更新粮食验收
        //1.1状态已封仓

        qualitycheck.setSealStatus("1");
        //1.2封仓时间
        Date date=new Date();
        qualitycheck.setSealDate(date);
        //⑦更新货位的状态
      //  warehouse.setWarehouseStatus(2965);//满货位


        //⑧更新仓房的状态
        //1.1先查看该仓房下所有的货位是不是都已经满货位 是：更新仓房的状态  否：不更新
  /*      BasicWarehouseExample wareExample = new BasicWarehouseExample();
        BasicWarehouseExample.Criteria criteria = wareExample.createCriteria();
        criteria.andStorehouseIdEqualTo(houseId);
        criteria.andWarehouseStatusNotEqualTo(2965);
        //如果list个数为零 说明该仓下所有货物都已经满仓 可以更新仓房状态
        List<BasicWarehouse> warehouseList=warehouseService.findCondition(wareExample);
        if(warehouseList.size()==0){
            storehouse.setStorehouseState(2965);//满货位
            try{
                storehouseService.updateBasicStorehouse(storehouse);//更新仓房状态
            }catch (Exception ex){
                ex.printStackTrace();
            }

        }*/

        //⑨更新货位状态
        //warehouseService.update(warehouse);
        //生成库存识别码
        this.generateStockIDcode(foodbasicInfo, qualitycheck, houseId, wareHouseId,qualitycheckVo,date);

        foodbasicInfo.setHistoryStatus(0);//0:最新数据  1:历史数据
        //保存粮食专卡
        foodbasicInfoMapper.insertSelective(foodbasicInfo);

        qualitycheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //更新验收信息
        qualitycheckMapper.updateByPrimaryKeySelective(qualitycheck);

        //在粮情检测表中保存当前验收的信息用于在粮情卡中进行显示
        //获取刚刚保存的专卡的Id
        Integer foodbasicInfoId = foodbasicInfo.getId();
        if(foodbasicInfoId != null){
            StorageFoodbasicInfoCheck check = new StorageFoodbasicInfoCheck();
            check.setFoodbasicinfoId(foodbasicInfoId);
            check.setQualitycheckId(qualitycheck.getId());
            check.setHouseId(houseId);
            check.setWarehouseId(wareHouseId);
            check.setOrgId(orgId);

            foodbasicInfoCheckMapper.insertSelective(check);
        }
    }

    /**
     * 生成库存识别码方法
     * @param foodbasicInfo
     * @param qualitycheck
     * @param houseId
     * @param wareHouseId
     * @param date
     * @throws Exception
     */
    /**
     * 生成库存识别码方法
     * @param foodbasicInfo
     * @param qualitycheck
     * @param houseId
     * @param wareHouseId
     * @param date
     * @throws Exception
     */
    public void generateStockIDcode(StorageFoodbasicinfo foodbasicInfo, StorageQualitycheck qualitycheck, Integer houseId,Integer wareHouseId,
                                    StorageQualitycheckVo qualitycheckVo,Date date){
        //1.3生成库存识别码(二维码)
        // 服务器路径
        //   String rootPath = request.getSession().getServletContext().getRealPath("");
        // 文件相对路径
        String relativePath = "upload/img";
        // 如路径不存在，则创建它
        //File directory = new File(rootPath + relativePath);
        //if (!directory.exists()) {
        //    directory.mkdirs();
        //}

        //图片的命名
        String authcodeName=houseId+""+wareHouseId+".png";
        //图片完整路径
        String filePath=relativePath+"/"+authcodeName;//于是二维码需要保存的地方
        String fullPath=rootPath+"/"+filePath;
        int width2 = 300, height2 = 300;

          /*  var neirong="组织代码：163837911；货位编码："+$("#HWBH").text()+"00100101；货位封仓时间：201511010955；根码标志：0；
            组织代码：163837911；货位编码："+$("#HWBH").text()+"00100101；货位封仓时间："+currentTime+"；
            粮食性质：110；业务号：001；数量："+$("#ZHBZSL").text()+"；品种代码：1141001；产地代码：220112；
            生产年份："+rcsjYear+"；等级代码：01";*/
        StringBuffer sb = new StringBuffer();
        //根据登录人的组织机构查找信息
        String orgCode="";
        String currentWareCode="";

        //①组织机构代码(9位代码)
        String companyNature = qualitycheckVo.getCompanyNature();
        sb.append("组织代码:"+companyNature);
        //②货位编码：当前粮食所在货位的编码（组织代码+仓房代码+000+货位代码）
        orgCode = qualitycheckVo.getOrgCode();//当前组织的组织代码

        // String storehouseCode = storehouse.getStorehouseCode();//当前仓房的仓房编码
        //String granary = "000";//因为没有廒间代码 就用3个0替代
        //根据当前货位id获得货位记录
        // String warehouseCode=warehouse.getWarehouseCode();//货位编码
        currentWareCode=orgCode+qualitycheckVo.getStorehouseCode()+qualitycheckVo.getStorehouseCode()+qualitycheckVo.getWarehouseCode();
        sb.append(";货位编码:"+currentWareCode);

        //③货位封仓时间：粮食封仓日期
        SimpleDateFormat myFmt1=new SimpleDateFormat("yyyyMMddHHmm");
        String sealDate=myFmt1.format(date);
        sb.append(";货位封仓时间:"+sealDate);
        // ④根码标志：0(固定的)
        String mark="0";
        sb.append(";根码标志:"+mark);
        // ⑤组织机构代码：当前粮食所在库的编码
        String companyNature2=companyNature;
        sb.append(";组织代码:"+companyNature2);
        //⑥货位编码：变更前的货位(从前台传来的是当前货位也就是变更后的) 从货位变更表中查找是否有该货位的变更记录   有：变更前的货位   无：还是原来的货位 ，）
        List<StorageFoodbasicInfoLocation> location=foodbasicInfoLocationService.getFoodbasicInfoLocationByWarehouseCode(houseId, wareHouseId);
        String oldwarehouseCode="";
        Integer warehouseId;
        String changSsealDate="";
        StorageFoodbasicInfoLocation infoLocation = new StorageFoodbasicInfoLocation();
        SimpleDateFormat myFmt2=new SimpleDateFormat("yyyyMMddHHmm");

        if(location.size()>0 && location != null) {
            infoLocation = location.get(0);//得到当前货位的初始货位
            oldwarehouseCode = infoLocation.getWarehouseCode();//初始的货位编码
            warehouseId=infoLocation.getWarehouseId();//初始的货位Id
            Integer firstHouseId=infoLocation.getHouseId();//初始的仓房id
            StorageQualitycheckExample exple = new StorageQualitycheckExample();
            StorageQualitycheckExample.Criteria criteria1=exple.createCriteria();
            if(firstHouseId != null){
                criteria1.andHouseIdEqualTo(firstHouseId);
            }
            if(warehouseId != null){
                criteria1.andWarehouseIdEqualTo(warehouseId);
            }
            exple.setOrderByClause("id desc");
            //根据初始的货位id和仓房id得到粮情专卡 从粮情专卡中取出建卡的日期就是封仓的日期
            List<StorageQualitycheck>  basicInfo  = qualitycheckMapper.selectByExample(exple);
            StorageQualitycheck qualitycheck1=null;
            if(basicInfo.size()>0 &&basicInfo != null){
                qualitycheck1=basicInfo.get(0);
            }
            if(qualitycheck1 != null){
                Date sealDate1=qualitycheck1.getSealDate();//得到初始货位的封仓日期
                if(sealDate1 != null){
                    changSsealDate=myFmt2.format(sealDate1);
                }
            }
            //变更的货位编码
            oldwarehouseCode =orgCode+qualitycheckVo.getStorehouseCode()+qualitycheckVo.getStorehouseCode()+oldwarehouseCode;
        }else{
            oldwarehouseCode=currentWareCode;//没变更 还是原来的货位编码
            changSsealDate=myFmt1.format(date);//没变更  还是原来的封仓时间
        }

        sb.append(";货位编码:"+oldwarehouseCode);

        sb.append(";货位封仓时间:"+changSsealDate);

        //遍历仓房保管账对象

        //粮食性质  从分仓保管账带出
        //1.1储粮性质
        sb.append(";粮食性质:"+qualitycheckVo.getHwxz());
        //业务号：分仓保管账的文件号（粮情卡带出）（粮情卡增加这个字段  保存粮情卡的时候直接从分仓保管账取出）
        if(ParameterUtil.isnotnull(qualitycheckVo.getWjh())){
            sb.append(";业务号:"+qualitycheckVo.getWjh());
        }else{
            sb.append(";业务号:");
        }

        //数量：粮情卡带出
        sb.append(";数量:"+qualitycheckVo.getKcsl());

        //  品种代码：粮情卡带出(enumCode)
        sb.append(";品种代码:"+qualitycheckVo.getPzCode());
        //产地代码：粮情卡带出
        sb.append(";产地代码:"+qualitycheckVo.getPlaceCode());

        // 生产年份：粮情卡带出
        sb.append(";收获年份:"+qualitycheckVo.getScnfName());

        //等级代码：粮情卡带出
        Integer level=qualitycheck.getLevelUpdate();
        sb.append(";等级代码:"+level);

        // 生产年份：粮情卡带出
        sb.append(";代码标识:"+companyNature+qualitycheckVo.getWarehouseCode()+changSsealDate);
        String contents2=sb.toString();

        //生成二维码
        ZxingHandler.encode2(contents2, width2, height2, fullPath);


        qualitycheck.setAuthCode(filePath);//质量检查中保存库存识别码用于在封仓列表中展示
        foodbasicInfo.setAuthCode(filePath);//粮情专卡中保存库存识别码用于在粮情卡页面展示
    }


    @Override
    public StorageFoodbasicinfo loadDataById(int id) {
        StorageFoodbasicinfo foodbasicinfo = foodbasicInfoMapper.selectByPrimaryKey(id);
        return foodbasicinfo;
    }

    /**
     * 更新粮情专卡为历史数据
     * @param houseId
     * @return
     */
    @Override
    public void setFoodBasicInfoHistoryStatus(Integer houseId,Integer warehouseId) {

        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        //0:最新数据  1:历史数据
        foodbasicinfo.setHistoryStatus(1);

        StorageFoodbasicinfoExample foodbasicinfoExample = new StorageFoodbasicinfoExample();
        StorageFoodbasicinfoExample.Criteria qualityCriteria = foodbasicinfoExample.createCriteria();
        if(ParameterUtil.isnotnull(houseId)){
            qualityCriteria.andHouseIdEqualTo(houseId);
        }
        if(ParameterUtil.isnotnull(warehouseId)){
            qualityCriteria.andWarehouseIdEqualTo(warehouseId);
        }

        //更新粮情专卡状态为历史数据
        foodbasicInfoMapper.updateByExampleSelective(foodbasicinfo,foodbasicinfoExample);

    }

	@Override
	public List<StorageFoodbasicinfo> findByCondition(StorageFoodbasicinfoExample example) {
		return foodbasicInfoMapper.selectByExample(example);
	}
}
