package com.chinaitop.depot.storage.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.chinaitop.depot.storage.mapper.StorageQualitystandardMainMapper;
import com.chinaitop.depot.storage.mapper.StorageQualitystandardPreparationMapper;
import com.chinaitop.depot.storage.model.StorageQualitystandardMain;
import com.chinaitop.depot.storage.model.StorageQualitystandardMainExample;
import com.chinaitop.depot.storage.model.StorageQualitystandardPreparation;
import com.chinaitop.depot.storage.model.StorageQualitystandardPreparationExample;
import com.chinaitop.depot.storage.service.StorageQualitystandardMainService;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

@Service
public class StorageQualitystandardMainServiceImpl implements StorageQualitystandardMainService {

	@Autowired
	private StorageQualitystandardMainMapper storageQualitystandardMainMapper;

	@Autowired
	private StorageQualitystandardPreparationMapper storageQualitystandardPreparationMapper;
	
	@Override
	public List<StorageQualitystandardMain> getList(HttpServletRequest request, Integer lspz) throws Exception {

		/* 获取单位 */
		int org_id = Integer.parseInt(ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0"));

		/* 组装查询 */
		StorageQualitystandardMainExample example = new StorageQualitystandardMainExample();
		StorageQualitystandardMainExample.Criteria criteria = example.createCriteria();

		/* 粮食品种 */
		if (null != lspz) {
			criteria.andSubTypeEqualTo(lspz);
		}

		/* 单位ID */
		criteria.andOrgIdEqualTo(org_id);

		/* 按照最后修改时间倒序排序 */
		example.setOrderByClause(" updatetime desc");

		/* 查询 */
		List<StorageQualitystandardMain> list = storageQualitystandardMainMapper.selectByExample(example);

		return list;
	}

	@Override
	public Map<String, Object> findByIdObj(String id) throws Exception {
		Map<String, Object> map = new HashMap<String, Object>();

		/* 查询主表数据  */
		StorageQualitystandardMain main = storageQualitystandardMainMapper.selectByPrimaryKey(id);
		List<StorageQualitystandardPreparation> list = null;

		if (null != main) {
			String zid = main.getId();
			StorageQualitystandardPreparationExample example = new StorageQualitystandardPreparationExample();
			StorageQualitystandardPreparationExample.Criteria criteria = example.createCriteria();
			criteria.andZIdEqualTo(zid);
			list = storageQualitystandardPreparationMapper.selectByExample(example);

		} else {
			main = new StorageQualitystandardMain();
			main.setCreatetime(new Date());
			
		}
		map.put("obj_main", main);
		map.put("obj", list);

		return map;
	}

	@Override
	public Map<String, Object> initObj(Integer lspz) throws Exception {

		String lypz = lspz+"";

		List<StorageQualitystandardPreparation> list = new ArrayList<StorageQualitystandardPreparation>();

		if ("3164".equals(lypz) || "3165".equals(lypz) || "2777".equals(lypz) || "3166".equals(lypz) || "0".equals(lypz)) {

			StorageQualitystandardPreparation obj = null;
			for (int i = 3271; i < 3276; i++) {
				obj = new StorageQualitystandardPreparation();
				obj.setLevelUpdate(i);;
				list.add(obj);
			}

		} else if ("7107".equals(lypz)) {//大米

			/**
			 * 初始化数据中的十条数据等级的等级
			 * 规则，分别对应品种籼米(1~3级)、粳米(1~3级)、籼糯米(1~2级)、粳糯米(1~2级)，共十个值
			 */
			int []dj = {3271, 3272, 3273, 3271, 3272, 3273, 3271, 3272, 3271, 3272};

			StorageQualitystandardPreparation obj = null;
			for (int i = 0; i < 10; i++) {

				obj = new StorageQualitystandardPreparation();

				if (i < 3) {//数组0~2是籼米

					obj.setSubTypeDetailed(7047);

				} else if (i > 2 && i < 6) {//数组3~5是粳米

					obj.setSubTypeDetailed(7048);

				} else if (i > 5 && i < 8) {//数组6~7是籼糯米

					obj.setSubTypeDetailed(7105);

				} else if (i > 7 && i < 10) {//数组8~9是粳糯米

					obj.setSubTypeDetailed(7106);

				}

				obj.setLevelUpdate(dj[i]);

				list.add(obj);
			}

		} else if ("7038".equals(lypz)) {//小麦粉
			StorageQualitystandardPreparation obj = null;
			for (int i = 3271; i < 3275; i++) {
				obj = new StorageQualitystandardPreparation();
				obj.setLevelUpdate(i);;
				list.add(obj);
			}
		} else if ("7072".equals(lypz)) {//成品大豆油
			StorageQualitystandardPreparation obj = null;
			for (int i = 3271; i < 3274; i++) {
				obj = new StorageQualitystandardPreparation();
				obj.setLevelUpdate(i);;
				list.add(obj);
			}
		}

		Map<String, Object> map = new HashMap<String, Object>();
		map.put("initdata", list);

		return map;
	}

	@Override
	@Transactional
	public void saveOrUpdate(HttpServletRequest request, String obj_main, String obj) throws Exception {
		String org_id = ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0");
		ObjectMapper mapper = new ObjectMapper();
		StorageQualitystandardMain storageQualitystandardMain = mapper.readValue(obj_main, StorageQualitystandardMain.class);
		List<StorageQualitystandardPreparation> obj_list = mapper.readValue(obj, new TypeReference<List<StorageQualitystandardPreparation>>(){});
		String id = storageQualitystandardMain.getId();
		if (StringUtils.isNotBlank(id)) {//修改
			storageQualitystandardMain.setUpdatetime(new Date());
			storageQualitystandardMainMapper.updateByPrimaryKeySelective(storageQualitystandardMain);
			for (StorageQualitystandardPreparation main : obj_list) {
				storageQualitystandardPreparationMapper.updateByPrimaryKeySelective(main);
			}
		} else {//新增
			id = ParameterUtil.getUuid();
			storageQualitystandardMain.setId(id);
			storageQualitystandardMain.setOrgId(Integer.parseInt(org_id));
			storageQualitystandardMain.setUpdatetime(new Date());
			storageQualitystandardMainMapper.insertSelective(storageQualitystandardMain);
			for (StorageQualitystandardPreparation main : obj_list) {
				main.setId(ParameterUtil.getUuid());
				main.setzId(id);
				main.setOrgId(Integer.parseInt(org_id));
				storageQualitystandardPreparationMapper.insertSelective(main);
			}
		}
	}

	@Override
	@Transactional
	public void delete(String id) throws Exception {

		/* 删除主表数据  */
		storageQualitystandardMainMapper.deleteByPrimaryKey(id);

		/* 删除子表数据  */
		StorageQualitystandardPreparationExample example = new StorageQualitystandardPreparationExample();
		StorageQualitystandardPreparationExample.Criteria criteria = example.createCriteria();
		criteria.andZIdEqualTo(id);
		storageQualitystandardPreparationMapper.deleteByExample(example);
	}

	@Override
	public Map<String, Object> findLspzObjs(Integer lspz) throws Exception {
		Map<String, Object> map = new HashMap<String, Object>();

		StorageQualitystandardMainExample main_example = new StorageQualitystandardMainExample();
		StorageQualitystandardMainExample.Criteria main_criteria = main_example.createCriteria();
		main_criteria.andSubTypeEqualTo(lspz);
		main_example.setOrderByClause(" updatetime desc");
		List<StorageQualitystandardMain> main_list = storageQualitystandardMainMapper.selectByExample(main_example);
		String zid = "";
		if (null != main_list && main_list.size() > 0) {
			zid = main_list.get(0).getId();
		}

		StorageQualitystandardPreparationExample example = new StorageQualitystandardPreparationExample();
		StorageQualitystandardPreparationExample.Criteria criteria = example.createCriteria();
		criteria.andZIdEqualTo(zid);
		List<StorageQualitystandardPreparation> obj_list = storageQualitystandardPreparationMapper.selectByExample(example);
		map.put("obj_list", obj_list);

		return map;
	}


}
