package com.chinaitop.depot.storage.service.impl;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.storage.mapper.StorageStorehouseBusinessMapper;
import com.chinaitop.depot.storage.model.StorageStorehouseBusiness;
import com.chinaitop.depot.storage.model.StorageStorehouseBusinessExample;
import com.chinaitop.depot.storage.service.StorageStorehouseBusinessService;

import com.chinaitop.depot.storage.utils.OnOffEnum;
import com.chinaitop.depot.storage.utils.TaskEnum;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class StorageStorehouseBusinessServiceImpl implements StorageStorehouseBusinessService {

	@Resource
	private StorageStorehouseBusinessMapper mapper;

	@Override
	public void add(StorageStorehouseBusiness storageStorehouseBusiness) throws Exception {
		mapper.insertSelective(storageStorehouseBusiness);
	}

	@Override
	public void remove(Integer id) throws Exception {
		mapper.deleteByPrimaryKey(id);
	}

	@Override
	public void update(StorageStorehouseBusiness storageStorehouseBusiness) throws Exception {
		mapper.updateByPrimaryKeySelective(storageStorehouseBusiness);
	}

	@Override
	public StorageStorehouseBusiness findById(Integer id) throws Exception {
		return mapper.selectByPrimaryKey(id);
	}

	@Override
	public List<StorageStorehouseBusiness> findCondition(StorageStorehouseBusinessExample example) throws Exception {
		return mapper.selectByExample(example);
	}


	@Override
	public Map<String, Object> getStorehouseData() {
		Map<String, Object> modelMap = new HashMap<String, Object>();

		List<StorageStorehouseBusiness> houselist = null;
		try {
			houselist = mapper.selectStorehouseData();
		} catch (Exception e) {
			e.printStackTrace();
		}
		modelMap.put("houseList", houselist);
		return modelMap;
	}

	@Override
	public Map<String, Object> getWarehouseData(Integer ch) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		List<StorageStorehouseBusiness> wareList = null;
		try {
			wareList = mapper.selectWarehouseData(ch);
		} catch (Exception e) {
			e.printStackTrace();
		}
		modelMap.put("wareList", wareList);
		return modelMap;
	}

	@Override
	@Transactional
	public void saveStorehouseBusinessFromFcbgz() {

		//执行插入数据之前先清空该表中的数据  以防止添加重复数据
		mapper.truncateStorehouseBusiness();
        Map<String,Object> map = new HashMap<>();
        map.put("byId",0);
		List<Map<String,Object>> list= mapper.selectLsreport(map);
		for(int i=0;i<list.size();i++) {
			StorageStorehouseBusiness storageStorehouseBusiness = JSON.parseObject(JSON.toJSONString(list.get(i)), StorageStorehouseBusiness.class);
			mapper.insert(storageStorehouseBusiness);
		}
	}

	@Override
	public void updateAerationStatus(Integer houseId, Integer wareId, Integer orgId, String aerationStatus) {
		// 查询看下有没有对应仓房的业务数据
		StorageStorehouseBusinessExample cfExample = new StorageStorehouseBusinessExample();
		StorageStorehouseBusinessExample.Criteria CfCriteria = cfExample.createCriteria();
		CfCriteria.andStorehouseIdEqualTo(houseId);
		if (null != wareId) {
			CfCriteria.andWarehouseIdEqualTo(wareId);
		}
		List<StorageStorehouseBusiness> list = mapper.selectByExample(cfExample);

		StorageStorehouseBusiness storageStorehouseBusiness = new StorageStorehouseBusiness();
		storageStorehouseBusiness.setStorehouseId(houseId);
		storageStorehouseBusiness.setOrgId(orgId);
		storageStorehouseBusiness.setAerationStatus(aerationStatus);
		if (null != list && list.size() > 0) {
			for (StorageStorehouseBusiness object : list) {
				storageStorehouseBusiness.setId(object.getId());
				mapper.updateByPrimaryKeySelective(storageStorehouseBusiness);
			}
		} else {
			mapper.insertSelective(storageStorehouseBusiness);
		}
	}

    /**
     * 作业状态修改接口
     * 主要作业：入库、出库、通风、熏蒸、内环流
     * @param task 枚举类型，对对应枚举进行作业状态修改，可参考TaskEnum
     * @param type 类型，ON 状态开启，OFF 状态关闭,可参考OnOffEnum
     * @param cfid 仓房id
     */
    public void setStatusForTask(TaskEnum task, OnOffEnum type, int cfid){

        //判断当前仓房id在作业表里是否存在，不存在则insert
        Map<String,Object> map = new HashMap<>();
        map.put("byId",1);
        map.put("cfId",cfid);

		List<Map<String,Object>> list= mapper.selectLsreport(map);
		for(int i=0;i<list.size();i++) {
			StorageStorehouseBusiness storageStorehouseBusiness = JSON.parseObject(JSON.toJSONString(list.get(i)), StorageStorehouseBusiness.class);
			mapper.insert(storageStorehouseBusiness);
		}

        //根据仓房id更新作业状态
        StringBuilder sql = new StringBuilder("UPDATE STORAGE_STOREHOUSE_BUSINESS SET");
        switch (task){
            case CK: sql.append(" ck_status ");break;
            case RK: sql.append(" rk_status ");break;
            case AERATION: sql.append(" aeration_status ");break;
            case FUMIGATION: sql.append(" fumigation_status ");break;
            case NHL: sql.append(" nhl_status ");break;
        }
        sql.append(" = '"+type.getEnName()+"'");
        sql.append(" where storehouse_id='"+cfid+"'");
        map.put("SQL",sql);
        mapper.updateTaskStatusForCf(map);

        //根据仓房id修改满仓状态

    }

}
