package com.chinaitop.depot.storage.service.impl;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.storage.mapper.StorageSetMapper;
import com.chinaitop.depot.storage.mapper.StorageWarterFixedPointMapper;
import com.chinaitop.depot.storage.mapper.StorageWarterMobilePointMapper;
import com.chinaitop.depot.storage.mapper.StorageWaterCheckMapper;
import com.chinaitop.depot.storage.model.StorageSet;
import com.chinaitop.depot.storage.model.StorageSetExample;
import com.chinaitop.depot.storage.model.StorageWarterFixedPoint;
import com.chinaitop.depot.storage.model.StorageWarterFixedPointExample;
import com.chinaitop.depot.storage.model.StorageWarterMobilePoint;
import com.chinaitop.depot.storage.model.StorageWarterMobilePointExample;
import com.chinaitop.depot.storage.model.StorageWaterCheck;
import com.chinaitop.depot.storage.model.StorageWaterCheckExample;
import com.chinaitop.depot.storage.service.StorageWarterCheckService;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

@Service
@SuppressWarnings("all")
public class StorageWarterCheckServiceImpl implements StorageWarterCheckService {

	@Resource
	private StorageWaterCheckMapper storageWaterCheckMapper;
	@Resource
	private StorageWarterFixedPointMapper storageWarterFixedPointMapper;
	@Resource
	private StorageWarterMobilePointMapper storageWarterMobilePointMapper;
	@Resource
	private StorageSetMapper storageSetMapper;

	@Override
	public List<StorageWaterCheck> findCondition(StorageWaterCheckExample example) {
		List<StorageWaterCheck> list = storageWaterCheckMapper.selectByExample(example);
		if (null != list && list.size() > 0) {
			for (int i = 0; i < list.size(); i++) {
				StorageWaterCheck storageWaterCheck = list.get(i);

				/* 查询当前数据的品种有没有设置阈值报警数据 */
				Map<String, Object> param_map = paramMap(storageWaterCheck);

				//查询水分检验固定点信息表和水分检验机动点信息表中有没有超过水分高限的数据，有的话需要将当前数据标红
				String sfh = ObjectUtils.toString(param_map.get("sf_h"), "");
				if (!"".equals(sfh)) {
					BigDecimal sf_h = new BigDecimal(sfh);
					String redAlert = getRedAlertData(sf_h, storageWaterCheck.getId());
					storageWaterCheck.setRedAlert(redAlert);
					if ("Y".equals(redAlert)) {
						continue;
					}
				} else {
					storageWaterCheck.setRedAlert("N");
				}

				//查询水分检验固定点信息表和水分检验机动点信息表中有没有超过水分低限的数据，有的话需要将当前数据标蓝
				String sfd = ObjectUtils.toString(param_map.get("sf_d"), "");
				if (!"".equals(sfd)) {
					BigDecimal sf_d = new BigDecimal(sfd);
					String blueAlert = getBlueAlertData(sf_d, storageWaterCheck.getId());
					storageWaterCheck.setBlueAlert(blueAlert);
					if ("Y".equals(blueAlert)) {
						continue;
					}
				} else {
					storageWaterCheck.setBlueAlert("N");
				}

			}
		}

		return list;
	}

	private String getBlueAlertData(BigDecimal sf_d, String zid) {
		String blueAlert = "N";

		Map<String, Object> param_map = new HashMap<String, Object>();
		param_map.put("sf_d", sf_d);
		param_map.put("zid", zid);

		int count = storageWarterFixedPointMapper.selectCountBlueData(param_map);
		if (count > 0) {
			blueAlert = "Y";
			return blueAlert;
		}

		count = storageWarterMobilePointMapper.selectCountBlueData(param_map);
		if (count > 0) {
			blueAlert = "Y";
			return blueAlert;
		}

		return blueAlert;
	}

	private String getRedAlertData(BigDecimal sf_h, String zid) {
		String redAlert = "N";

		Map<String, Object> param_map = new HashMap<String, Object>();
		param_map.put("sf_h", sf_h);
		param_map.put("zid", zid);

		int count = storageWarterFixedPointMapper.selectCountRedData(param_map);
		if (count > 0) {
			redAlert = "Y";
			return redAlert;
		}

		count = storageWarterMobilePointMapper.selectCountRedData(param_map);
		if (count > 0) {
			redAlert = "Y";
			return redAlert;
		}

		return redAlert;
	}
	private Map<String, Object> paramMap(StorageWaterCheck storageWaterCheck) {
		Map<String, Object> param_map = new HashMap<String, Object>();
		if (null != storageWaterCheck.getLspz()) {
			StorageSetExample set_example = new StorageSetExample();
			StorageSetExample.Criteria set_criteria = set_example.createCriteria();
			set_criteria.andLspzEqualTo(storageWaterCheck.getLspz());
			set_criteria.andStartDateLessThanOrEqualTo(storageWaterCheck.getHyDate());
			set_criteria.andEndDateGreaterThanOrEqualTo(storageWaterCheck.getHyDate());
			set_criteria.andIsOpenEqualTo(true);
			List<StorageSet> set_list = storageSetMapper.selectByExample(set_example);
			if (null != set_list && set_list.size() > 0) {
				param_map.put("sf_h", ObjectUtils.toString(set_list.get(0).getSfH(), ""));
				param_map.put("sf_d", ObjectUtils.toString(set_list.get(0).getSfD(), ""));
			} else {
				param_map.put("sf_h", "");
				param_map.put("sf_d", "");
			}
		}
		return param_map;
	}

	@Override
	public StorageWaterCheck findbyidStorageWaterCheck(String id) {
		return storageWaterCheckMapper.selectByPrimaryKey(id);
	}

	@Override
	public Map<String, Object> update(HttpServletRequest request, String storageWaterCheckJson, String storageWarterFixedPointJson,
			String storageWarterMobilePointJson) {
		Map<String, Object> map = new HashMap<String, Object>();
		ObjectMapper mappers = new ObjectMapper();

		try {
			// 更新表数据
			StorageWaterCheck waterCheck = mappers.readValue(storageWaterCheckJson, StorageWaterCheck.class);
			List<StorageWarterFixedPoint> gddList = mappers.readValue(storageWarterFixedPointJson, new TypeReference<List<StorageWarterFixedPoint>>(){});
			List<StorageWarterMobilePoint> jddList = mappers.readValue(storageWarterMobilePointJson, new TypeReference<List<StorageWarterMobilePoint>>(){});
			if (null != waterCheck.getId() && !"".equals(waterCheck.getId())) {//修改
				//保存主表
				waterCheck.setEditTime(new Date());
				storageWaterCheckMapper.updateByPrimaryKeySelective(waterCheck);

				//保存固定点数据和机动点数据
				editEducation(gddList, jddList, waterCheck.getId(), waterCheck.getOrgId());
			} else {//新增
				String uuid = UUID.randomUUID().toString().replaceAll("-", "");
				int orgId = Integer.parseInt(ObjectUtils.toString(request.getSession().getAttribute("orgId"), "0"));
				waterCheck.setId(uuid);
				waterCheck.setOrgId(orgId);
				waterCheck.setInputTime(new Date());

				//保存主表
				storageWaterCheckMapper.insertSelective(waterCheck);

				//保存固定点数据和机动点数据
				editEducation(gddList, jddList, uuid, orgId);
			}
		} catch (Exception e) {
			e.printStackTrace();
		} 

		return map;
	}
	
	/**
	 * 更新固定点和机动点信息
	 * 
	 * @param edcationList
	 * @param id
	 */
	private void editEducation(List<StorageWarterFixedPoint> gddList, List<StorageWarterMobilePoint> jddList,
			String zid, Integer orgId) {

		//主键UUID
		String uuid = null;

		//固定点数据
		for (StorageWarterFixedPoint fixedPoint : gddList) {
			if (null == fixedPoint.getId() || "".equals(fixedPoint.getId())) {
				uuid = UUID.randomUUID().toString().replaceAll("-", "");
				fixedPoint.setId(uuid);
				fixedPoint.setzId(zid);
				fixedPoint.setOrgId(orgId);
				fixedPoint.setInputTime(new Date());
				storageWarterFixedPointMapper.insertSelective(fixedPoint);
			} else {
				fixedPoint.setEditTime(new Date());
				storageWarterFixedPointMapper.updateByPrimaryKeySelective(fixedPoint);
			}
		}
		//机动点数据
		for (StorageWarterMobilePoint mobilePoint : jddList) {
			if (null == mobilePoint.getId() || "".equals(mobilePoint.getId())) {
				uuid = UUID.randomUUID().toString().replaceAll("-", "");
				mobilePoint.setId(uuid);
				mobilePoint.setzId(zid);
				mobilePoint.setOrgId(orgId);
				mobilePoint.setInputTime(new Date());
				storageWarterMobilePointMapper.insertSelective(mobilePoint);
			} else {
				mobilePoint.setEditTime(new Date());
				storageWarterMobilePointMapper.updateByPrimaryKeySelective(mobilePoint);
			}
		}
	}

	@Override
	public void delete(String id) {
		//删除水分检验固定点表数据
		StorageWarterFixedPointExample fixed_example = new StorageWarterFixedPointExample();
		StorageWarterFixedPointExample.Criteria fixed_criteria = fixed_example.createCriteria();
		fixed_criteria.andZIdEqualTo(id);
		storageWarterFixedPointMapper.deleteByExample(fixed_example);

		//删除水分检验机动点表数据
		StorageWarterMobilePointExample mobile_example = new StorageWarterMobilePointExample();
		StorageWarterMobilePointExample.Criteria mobile_criteria = mobile_example.createCriteria();
		mobile_criteria.andZIdEqualTo(id);
		storageWarterMobilePointMapper.deleteByExample(mobile_example);

		//删除水分检验主表数据
		storageWaterCheckMapper.deleteByPrimaryKey(id);
	}

	@Override
	public void deleteFlt(String id, Integer dataType) {
		if (null != dataType && dataType == 1) {//删除固定点
			storageWarterFixedPointMapper.deleteByPrimaryKey(id);
		}
		if (null != dataType && dataType == 2) {//删除机定点
			storageWarterMobilePointMapper.deleteByPrimaryKey(id);
		}
	}
	@Override
	public List<StorageWaterCheck> findWarterData(StorageWaterCheckExample example) {
		List<StorageWaterCheck> list = storageWaterCheckMapper.selectByExample(example);
		return list;
	}
}
