package com.chinaitop.depot.storage.utils;
import com.chinaitop.depot.qualityControl.model.BusinessQcQualityInspection;
import com.chinaitop.depot.storage.model.GrainSituationCardWarehouseRecord;
import com.chinaitop.depot.storage.model.vo.GrainSituationCardVO;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.format.DateTimeFormatter;
import java.util.*;

public class ExcelExporter {


        public static void exportToExcel(List<GrainSituationCardVO> data, List<GrainSituationCardWarehouseRecord> records, List<Map<String, String>> dataList, Map<Integer, List<String>> inspectionItems, String fileName) throws IOException{
            XSSFWorkbook workbook = new XSSFWorkbook();
            XSSFSheet sheet = workbook.createSheet("原粮专卡");

            // 设置列标题和样式
            int rowIndex;
            rowIndex= 0;

            Row headerRow = sheet.createRow(0);
            CellStyle headerCellStyle = workbook.createCellStyle();
            headerCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            headerCellStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);

            int columnIndex = 0;
            // 创建日期格式化对象，根据需要调整日期格式字符串
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            for (String field : getFields()) { // 假设getFields()返回字段列表
                Cell cell = headerRow.createCell(columnIndex++);
                ((Cell) cell).setCellValue(field);
                cell.setCellStyle(headerCellStyle);
            }

            // 添加数据行


            // 假设是LocalDateTime类型，如果不是请相应调整
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

            rowIndex++;
            for (GrainSituationCardVO card : data) {
                if (card == null) {
                    continue; // 如果card是null，直接跳过当前循环迭代
                }
                Row row = sheet.createRow(rowIndex++);
                columnIndex = 0;
                for (String field : getFields()) {
                    Cell cell = row.createCell(columnIndex++);
                    if ("填卡库区".equals(field)){
                        cell.setCellValue(card.getOrgName() != null ? card.getOrgName() : "无");
                    } else if(("保管库区".equals(field))){
                        cell.setCellValue(card.getOrgName() != null ? card.getOrgName() : "无");
                    } else if ("仓房名称".equals(field)) {
                        cell.setCellValue(card.getStorehouseName() != null ? card.getStorehouseName() : "无");
                    } else if ("货位名称".equals(field)) {
                        cell.setCellValue(card.getWarehouseName() != null ? card.getWarehouseName() : "无");
                    }else if ("仓房类型".equals(field)) {
                        cell.setCellValue(card.getStorehouseTypeName() != null ? card.getStorehouseTypeName() : "无");
                    }else if ("设计仓容".equals(field)) {
                        cell.setCellValue(card.getDesignCapacity() == null ? 0:card.getDesignCapacity().doubleValue());
                    } else if ("品种".equals(field)) {
                        cell.setCellValue(card.getGrainVarietyName() != null ? card.getGrainVarietyName() : "无");
                    } else if ("廒间名称".equals(field)) {
                        cell.setCellValue(card.getAjmc() != null ? card.getAjmc() : "无");
                    } else if ("储粮性质".equals(field)) {
                        cell.setCellValue(card.getGrainNatureName() != null ? card.getGrainNatureName() : "无");
                    } else if ("等级".equals(field)) {
                        cell.setCellValue(card.getGrainGradeName() != null ? card.getGrainGradeName() : "无");
                    } else if ("产地".equals(field)) {
                        cell.setCellValue(card.getProducerName() != null ? card.getProducerName() : "无");
                    } else if ("收获年度".equals(field)) {
                        cell.setCellValue(card.getShndName() != null ? card.getShndName() : "无");
                    } else if ("实际数量".equals(field)) {
                        cell.setCellValue(card.getLssl() == null ? 0 : card.getLssl().doubleValue());
                    }else if ("出库数量".equals(field)) {
                        cell.setCellValue(card.getOutQuantity() == null ? 0 : card.getOutQuantity().doubleValue());
                    }else if ("入库财政核定价格".equals(field)) {
                        cell.setCellValue(card.getInFinancialVerification() != null ? card.getInFinancialVerification():"无");
                    }else if ("出库财政核定价格".equals(field)) {
                        cell.setCellValue(card.getOutFinancialVerification() != null ? card.getOutFinancialVerification():"无");
                    }else if ("入仓日期".equals(field)) {
                        cell.setCellValue(card.getRcsj() == null ? "" : sdf.format(card.getRcsj()));
                    }else if ("形成货位时间".equals(field)) {
                        cell.setCellValue(card.getFormWarehouseTime() == null ? "" : sdf.format(card.getFormWarehouseTime()));
                    }else if ("测温方式".equals(field)) {
                        cell.setCellValue(card.getOutFinancialVerification() != null ? card.getOutFinancialVerification():"无");
                    } else if ("管理方式".equals(field)) {
                        cell.setCellValue(card.getKeepingWayName() != null ? card.getKeepingWayName() : "无");
                    } else if ("通风方式".equals(field)) {
                        cell.setCellValue(card.getDrafttypeName() != null ? card.getDrafttypeName() : "无");
                    } else if ("存储地点".equals(field)) {
                        cell.setCellValue(card.getOrgName() != null ? card.getOrgName() : "无");
                    }else if ("存储方式".equals(field)) {
                        cell.setCellValue(card.getKeepingWay() == null ? 0 : card.getKeepingWay());
                    }else if ("修改时间".equals(field)) {
                        cell.setCellValue(card.getUpdatedate() == null ? "" : sdf.format(card.getUpdatedate()));
                    }
                }
            }


            // 处理 GrainSituationCardWarehouseRecord 数据之前的表头
            rowIndex++; // 新增一行作为记录变更的表头行
            columnIndex = 0; // 重置列索引
            Row headerForRowRecords = sheet.createRow(rowIndex);
            for (String field : getFieldsss()) {
                Cell cell = headerForRowRecords.createCell(columnIndex++);
                cell.setCellValue(field);
                cell.setCellStyle(headerCellStyle);
            }
            // 填充 GrainSituationCardWarehouseRecord 数据
            for (GrainSituationCardWarehouseRecord record : records) {
                if (record == null) {
                    continue;
                }

                rowIndex++; // 新增一行用于记录数据
                columnIndex = 0;
                Row rowForRecord = sheet.createRow(rowIndex);
                for (String field : getFieldsss()) {
                    Cell cell = rowForRecord.createCell(columnIndex++);

                    if ("变更时间".equals(field)) {
                        cell.setCellValue(record.getChangeTime() == null ? "" : sdf.format(record.getChangeTime()));
                    } else if ("新货位号".equals(field)) {
                        cell.setCellValue(record.getNewWarehouseNumber() != null ? record.getNewWarehouseNumber() : "无");
                    } else if ("原货位号".equals(field)) {
                        cell.setCellValue(record.getOldWarehouseNumber() != null ? record.getOldWarehouseNumber() : "无");
                    } else if ("变更原因".equals(field)) {
                        cell.setCellValue(record.getChangeReason() != null ? record.getChangeReason() : "无");
                    }
                    // 根据GrainSituationCardWarehouseRecord类的实际属性添加更多处理逻辑
                }
            }

            rowIndex++; // 新增一行作为记录变更的表头行
            columnIndex = 0; // 重置列索引
            // 确定所有可能的检验项目
            Set<String> allInspectionCategories = new HashSet<>();
            for (List<String> values : inspectionItems.values()) {
                for (String item : values) {
                    String category = item.split(":")[0].trim(); // 假设项目名称在冒号前
                    allInspectionCategories.add(category);
                }
            }
            rowIndex++;
            // 创建表头
            Row headerRow1 = sheet.createRow(0);
            headerRow1.createCell(0).setCellValue("质检报告单号");
            headerRow1.createCell(1).setCellValue("检验类别");
            int colIndex = 2; // 从第三列开始放置动态检验项目
            for (String category : allInspectionCategories) {
                headerRow1.createCell(colIndex++).setCellValue(category);
            }
            // 检查inspectionItems是否只有一个键，如果是，则获取该键
            Integer singleKeyId = inspectionItems.keySet().iterator().next();

             rowIndex ++; // 从第二行开始写入数据
            for (Map<String, String> data2 : dataList) {
                Row dataRow = sheet.createRow(rowIndex++);
                dataRow.createCell(0).setCellValue(data2.getOrDefault("zjbgdh", ""));
                dataRow.createCell(1).setCellValue(data2.getOrDefault("jylb", ""));


                // 填充动态检验项目值，这里直接根据单个键获取其值列表
                List<String> items = inspectionItems.get(singleKeyId);

                // 填充动态检验项目值
                for (int i = 0; i < items.size(); i++) {
                    String[] keyValue = items.get(i).split(": ");
                    dataRow.createCell(i + 2).setCellValue(keyValue.length > 1 ? keyValue[1] : "");
                }
            }


//            rowIndex++; // 新增一行作为质量检验的表头行
//            columnIndex = 0; // 重置列索引
//            Row rowForRecord = sheet.createRow(rowIndex);
//            for (String field : getFieldss()) {
//                Cell cell = sheet.createRow(rowIndex).createCell(columnIndex++);
//                cell.setCellValue(field);
//                cell.setCellStyle(headerCellStyle);
//            }
////            // 填充数据
//            Row row = sheet.createRow(rowIndex++);
//            for (Map<String, String> data2 : dataList) {
//                if (data2 == null) {
//                    continue;
//                }
//                row.createCell(0).setCellValue(data2.getOrDefault("zjbgdh", ""));
//                row.createCell(1).setCellValue(data2.getOrDefault("jylb", ""));
//                for (Map<Integer, Object> jd : jsonData) {
//                    // 填充动态检验项目值
//                    Map<String, Object> maps = (Map<String, Object>) jd.get("maps");
//                    if (maps != null) {
//                        List<String> items = (List<String>) maps.get(id.get("id").toString());
//                        if (items != null) {
//                            int col = 2; // 从第2列开始填充动态数据
//                            for (String item : allInspectionItems) {
//                                String value = "";
//                                for (String checkItem : items) {
//                                    if (checkItem.startsWith(item + ":")) {
//                                        value = checkItem.split(": ")[1];
//                                        break;
//                                    }
//                                }
//                            }
//                            row.createCell(col++).setCellValue(value);
//                        }
//                    }
//                }
//            }
//
//        }



            // 关闭并保存Excel文件
            try (FileOutputStream outputStream = new FileOutputStream(fileName)) {
                workbook.write(outputStream);
            }
        }

    private static CellStyle createCenteredCellStyle(XSSFWorkbook workbook) {
        CellStyle centeredStyle = workbook.createCellStyle();
        centeredStyle.setAlignment(HorizontalAlignment.CENTER); // 水平居中
        centeredStyle.setVerticalAlignment(VerticalAlignment.CENTER); // 垂直居中，如果需要的话
        return centeredStyle;
    }

    private static String[] getFieldsss() {
        return new String[]{"变更时间","新货位号","原货位号","变更原因"};
    }
    private static String[] getFieldss() {
        return new String[]{"检验类型","质检报告单号","容重","水分","杂质","不完善粒","色泽,气味","硬度指数",
                "面筋质","面筋吸水量","品尝分值"};
    }
    private static String[] getFields() {
        return new String[]{"填卡库区","保管库区","仓房名称","廒间名称","货位名称","仓房类型","设计仓容","储粮性质","品种","产地","收获年度", "等级", "实际数量", "出库数量", "入库财政核定价格",
                " 出库财政核定价格", "入仓日期", "形成货位时间", "存储损耗",
                "测温方式", "通风方式", "管理方式","存储地点","存储方式","修改时间"};
    }

}
